@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "bookmarkPlugin.h"
@@ -20,12 +20,11 @@ bookmarkPlugin::bookmarkPlugin(QWidget* parentw) : QMenu(parentw)
     setTitle(QApplication::translate("c2bEditor", "&Bookmarks", 0));
     connect(c2bSettingsP, SIGNAL(newSettings()), this, SLOT(init()));
     _fsw = new c2bFileSystemWatcher(this);
-    connect(_fsw, SIGNAL(fileChanged(const QString&)), this, SLOT(parseBookmarks()));
+    connect(_fsw, SIGNAL(fileChanged(QString)), this, SLOT(parseBookmarks()));
     init();
 }
 
-bookmarkPlugin::~bookmarkPlugin()
-{}
+bookmarkPlugin::~bookmarkPlugin() {}
 
 
 void bookmarkPlugin::init()
@@ -33,7 +32,7 @@ void bookmarkPlugin::init()
     const QString nfn(c2bSettingsP->fileName("cb2Bib/NetworkFile"));
     if (nfn == _bookmark_file)
         return;
-    if (QFileInfo(nfn).exists())
+    if (QFileInfo::exists(nfn))
     {
         if (!_bookmark_file.isEmpty())
             _fsw->removePath(_bookmark_file);
@@ -68,7 +67,7 @@ void bookmarkPlugin::parseBookmarks()
             }
             QAction* act = addAction(bm_parts.at(0), this, SLOT(openBookmark()));
             act->setData(bm_parts.at(1));
-            act->setStatusTip(QString("%1  [%2]").arg(bm_parts.at(0)).arg(bm_parts.at(1)));
+            act->setStatusTip(QString("%1  [%2]").arg(bm_parts.at(0), bm_parts.at(1)));
             act->setShortcut(bm_parts.at(2));
             act->setIcon(QIcon(iconProvider(bm_parts.at(1), bm_parts.at(3))));
         }
@@ -102,7 +101,7 @@ void bookmarkPlugin::openBookmark()
     if (act)
     {
         const QString fn(act->data().toString());
-        if (fn.endsWith(".bib"))  // Open BiBTeX files internally
+        if (fn.endsWith(".bib")) // Open BiBTeX files internally
             emit openFile(fn);
         else
             c2bUtils::openFile(fn, parentWidget());
