@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2b.h"
@@ -33,9 +33,10 @@ c2b::c2b(QWidget* main, QObject* parento) : QObject(parento)
 
         // Create cb2Bib network
         _c2b_network = new network(this);
-        connect(_c2b_network, SIGNAL(proxyAuthenticationRequired(const QNetworkProxy&, QAuthenticator*)),
-                this, SLOT(proxyAuthenticationRequired(const QNetworkProxy&, QAuthenticator*)));
-        connect(_c2b_network, SIGNAL(downloadProgress(qint64, qint64)), this, SLOT(updateDownloadProgress(qint64, qint64)));
+        connect(_c2b_network, SIGNAL(proxyAuthenticationRequired(QNetworkProxy,QAuthenticator*)), this,
+                SLOT(proxyAuthenticationRequired(QNetworkProxy,QAuthenticator*)));
+        connect(_c2b_network, SIGNAL(downloadProgress(qint64,qint64)), this,
+                SLOT(updateDownloadProgress(qint64,qint64)));
         _download_progress = new QProgressDialog(_c2b_main, dialog::flags);
         _download_progress->setWindowTitle("Downloading...");
         _download_progress->reset();
@@ -46,8 +47,7 @@ c2b::c2b(QWidget* main, QObject* parento) : QObject(parento)
 
         // Create cb2Bib metadata parser
         _c2b_metadataparser = new metadataParser(_c2b_bibparser, this);
-        connect(_c2b_metadataparser, SIGNAL(showMessage(const QString&, const QString&)),
-                this, SLOT(showMessage(const QString&, const QString&)));
+        connect(_c2b_metadataparser, SIGNAL(showMessage(QString,QString)), this, SLOT(showMessage(QString,QString)));
 
         // Create cb2Bib clipboard
         _c2b_clipboard = new c2bClipboard(this);
@@ -89,7 +89,7 @@ void c2b::configure(int index)
 
 void c2b::exitRequested()
 {
-    foreach(QWidget * w, QApplication::topLevelWidgets())
+    foreach (QWidget* w, QApplication::topLevelWidgets())
     {
         // So far only editors grant user exit cancellation
         // Avoid closing other visible widgets until exit is granted
@@ -98,7 +98,7 @@ void c2b::exitRequested()
                 w->close();
     }
     qApp->processEvents();
-    foreach(QWidget * widget, QApplication::topLevelWidgets())
+    foreach (QWidget* widget, QApplication::topLevelWidgets())
     {
         if (widget->isVisible())
             if (widget->inherits("c2bEditor"))
