@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  *
  *   Class implementation of the approximate search algorithm
@@ -13,21 +13,19 @@
 #include "triads.h"
 
 #if QT_VERSION >= 0x050400
-static const QRegularExpression::PatternOptions _qre_pattern_options(
-    QRegularExpression::DontCaptureOption |
-    QRegularExpression::UseUnicodePropertiesOption |
-    QRegularExpression::OptimizeOnFirstUsageOption);
+static const QRegularExpression::PatternOptions _qre_pattern_options(QRegularExpression::DontCaptureOption |
+        QRegularExpression::UseUnicodePropertiesOption |
+        QRegularExpression::OptimizeOnFirstUsageOption);
 #else
-static const QRegularExpression::PatternOptions _qre_pattern_options(
-    QRegularExpression::DontCaptureOption |
-    QRegularExpression::UseUnicodePropertiesOption);
+static const QRegularExpression::PatternOptions _qre_pattern_options(QRegularExpression::DontCaptureOption |
+        QRegularExpression::UseUnicodePropertiesOption);
 #endif
 
 
-approximatePattern::approximatePattern() : compositePattern()
-{}
+approximatePattern::approximatePattern() : compositePattern() {}
 
-approximatePattern::approximatePattern(const QString& pattern, const Qt::CaseSensitivity cs) : compositePattern(pattern, cs)
+approximatePattern::approximatePattern(const QString& pattern, const Qt::CaseSensitivity cs)
+    : compositePattern(pattern, cs)
 {
     setPattern(pattern, cs);
 }
@@ -77,11 +75,12 @@ void approximatePattern::setPattern(const QString& pattern, const Qt::CaseSensit
         ++pieces_per_block;
 
 #if C2B_DEBUG_APPROXIMATEPATTERN
-    qDebug() << _string_pieces << max_blocks << scan_factor << requested_blocks << pieces_per_block << _string_pieces.count() % blocks;
+    qDebug() << _string_pieces << max_blocks << scan_factor << requested_blocks << pieces_per_block
+             << _string_pieces.count() % blocks;
     for (int b = 0; b < blocks; ++b)
         for (int i = 0; i < pieces_per_block; ++i)
             if (b + (i * blocks) < _string_pieces.count())
-                qDebug() << "block#   " << b << "pick item " <<  b + (i * blocks) << _string_pieces.at(b + (i * blocks));
+                qDebug() << "block#   " << b << "pick item " << b + (i * blocks) << _string_pieces.at(b + (i * blocks));
 #endif
 
     _ranks.clear();
@@ -112,7 +111,8 @@ void approximatePattern::setPattern(const QString& pattern, const Qt::CaseSensit
         submatcher.append(sm);
         subpattern.append(sp);
         substring.append(ss);
-        _ranks.append(stretch_product * triads::textFrequency(ss)); // Rank according expectation (arXiv:0705.0751, Eq. 6)
+        // Rank according expectation (arXiv:0705.0751, Eq. 6)
+        _ranks.append(stretch_product * triads::textFrequency(ss));
         ++_subpattern_count;
     }
     set_sort_index();
@@ -251,11 +251,12 @@ QString approximatePattern::wordPattern(const QString& word, Qt::CaseSensitivity
     QStringList possible;
     possible.append(escape(ord.left(len - 2), cs));
     for (int i = 1; i < len - 2; ++i)
-        possible.append(QString("%1.{0,2}%2").arg(escape(ord.left(len - i - 3), cs)).arg(escape(ord.right(i), cs)));
+        possible.append(QString("%1.{0,2}%2").arg(escape(ord.left(len - i - 3), cs), escape(ord.right(i), cs)));
 #if C2B_DEBUG_APPROXIMATEPATTERN
-    qDebug() << "WordPattern: " << QString("(?:%1(?:%2)|%3)").arg(escape(word.at(0), cs)).arg(possible.join("|")).arg(escape(ord, cs));
+    qDebug() << "WordPattern: "
+             << QString("(?:%1(?:%2)|%3)").arg(escape(word.at(0), cs), possible.join("|"), escape(ord, cs));
 #endif
-    return QString("(?:%1(?:%2)|%3)").arg(escape(word.at(0), cs)).arg(possible.join("|")).arg(escape(ord, cs));
+    return QString("(?:%1(?:%2)|%3)").arg(escape(word.at(0), cs), possible.join("|"), escape(ord, cs));
 }
 
 int approximatePattern::wordCount(const QString& str)
@@ -269,7 +270,8 @@ int approximatePattern::stretch(int piece_i, int piece_j) const
     const int minStretch(3);
     const int maxStretch(20);
     if (_string_pieces.at(piece_j).length() > 4)
-        return qMax((maxStretch * (piece_j - piece_i)), minStretch * (_piece_starts.at(piece_j) - _piece_ends.at(piece_i)));
+        return qMax((maxStretch * (piece_j - piece_i)),
+                    minStretch * (_piece_starts.at(piece_j) - _piece_ends.at(piece_i)));
     else
         return minStretch * (_piece_starts.at(piece_j) - _piece_ends.at(piece_i)); // Estimated error ratio only
 }
