@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  *
  *   Class implementation of the approximate search algorithm
@@ -27,7 +27,7 @@ public:
 
     void setPattern(const QString& pattern, const Qt::CaseSensitivity cs = Qt::CaseSensitive);
 
-    inline bool matches(const QString& str) const
+    inline bool matches(const QString& str) const override
     {
         _matched_length = -1;
         if (str.length() == 0)
@@ -42,7 +42,7 @@ public:
         else
             return _regexp.match(str).hasMatch();
     }
-    inline int indexIn(const QString& str, const int from = 0) const
+    inline int indexIn(const QString& str, const int from = 0) const override
     {
         _matched_length = -1;
         if (str.length() == 0)
@@ -87,7 +87,6 @@ private:
     QStringList _suffixes;
     QVector<substringMatcher> _submatchers;
     mutable QRegularExpressionMatch _regexp_match;
-
 };
 
 #endif
