@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "authorString.h"
@@ -15,8 +15,7 @@
     in the 'Abcd, E., F. Ghij, ...' mixed order.
 
 */
-authorString::authorString() : _full_form(false)
-{}
+authorString::authorString() : _full_form(false) {}
 
 
 /** \page authorproc
@@ -80,11 +79,13 @@ QString authorString::toBibTeX(const QString& author, bool full_form)
     {
         if (is_first_reversed)
         {
-            if (_author_string.contains(QRegExp('^' + author::name + ",(?:\\s*-{0,1}\\b\\w\\b\\.){1,3},\\s*" + author::name)))
+            if (_author_string.contains(
+                    QRegExp('^' + author::name + ",(?:\\s*-{0,1}\\b\\w\\b\\.){1,3},\\s*" + author::name)))
             {
                 _author_string.replace(QRegExp("\\bJr.", Qt::CaseSensitive), "Jr");
                 _author_string.replace(".,", ".;");
-                separator = ';'; // Reversed, comma separated 'Abrahamsson, A.-L., Springett, J., Karlsson, L., Ottosson, T.'
+                separator =
+                    ';'; // Reversed, comma separated 'Abrahamsson, A.-L., Springett, J., Karlsson, L., Ottosson, T.'
                 is_string_reversed = true;
             }
             else if (_author_string.contains(QRegExp('^' + author::name + ',' + author::initials + ',')))
@@ -101,7 +102,7 @@ QString authorString::toBibTeX(const QString& author, bool full_form)
             separator = ',';
     }
     else if (has_semicolon)
-        separator = ';';  // Multiple Authors, separated by semicolon
+        separator = ';'; // Multiple Authors, separated by semicolon
     else
         separator = " and ";
     c2bUtils::debug(QObject::tr("Separator: |%1|").arg(separator));
@@ -116,7 +117,8 @@ QString authorString::toBibTeX(const QString& author, bool full_form)
     _author_string.replace(QRegExp(";\\s*"), ";");
     _author_string.replace(QRegExp(";+"), ";");
     c2bUtils::debug("4--|" + _author_string + '|');
-    const bool are_authors_in_uppercase(containUpperCaseLetter(_author_string) && !containLowerCaseLetter(_author_string));
+    const bool are_authors_in_uppercase(containUpperCaseLetter(_author_string) &&
+                                        !containLowerCaseLetter(_author_string));
     if (are_authors_in_uppercase)
         c2bUtils::debug("Input Authors in Uppercase");
     QStringList authors;
@@ -141,7 +143,7 @@ QString authorString::toBibTeX(const QString& author, bool full_form)
         QString author_i(authors.at(ai));
         c2bUtils::debug(author_i);
         author_i.replace(QRegExp("\\.{0,1}\\s{0,1}-"), "-"); // Abbreviated cases, eg M.-H. Something
-        author_i.replace(QRegExp("[^-'\\w,]"), " "); // Only these characters compose a name; keep commas
+        author_i.replace(QRegExp("[^-'\\w,]"), " ");         // Only these characters compose a name; keep commas
         author_i = c2bUtils::simplifyString(author_i);
 
         // Split author name
@@ -217,8 +219,8 @@ QString authorString::toBibTeX(const QString& author, bool full_form)
                     for (int l = 0; l < fore_length; ++l)
                         author_name += fore_name[l] + ". ";
                 }
-                else if (i == 1 && fore_name_parts.count() == 2 && fore_length > 1 && fore_length < 3 && !is_current_reversed &&
-                         !are_authors_in_uppercase && is_uppercase)
+                else if (i == 1 && fore_name_parts.count() == 2 && fore_length > 1 && fore_length < 3 &&
+                         !is_current_reversed && !are_authors_in_uppercase && is_uppercase)
                 {
                     // Cases 'Fore IJ Last': Process initials
                     for (int l = 0; l < fore_length; ++l)
@@ -272,8 +274,8 @@ QString authorString::processFirstMiddle(const QString& first_middle) const
             if (first_middle.length() - first_middle.indexOf('_') == 2)
                 proc_fm += '.';
         }
-        else
-            proc_fm = first_middle.left(1) + '.';
+        else if (first_middle.length() > 0)
+            proc_fm = first_middle.at(0) + '.';
     }
     return proc_fm;
 }
@@ -351,7 +353,7 @@ bool authorString::isReverseOrder(const QString& author)
     {
         const QString Last(rRevNISI.cap(1));
         const QString First(rRevNISI.cap(2));
-        c2bUtils::debug(QObject::tr("ISI:  |%1| |%2|").arg(Last).arg(First));
+        c2bUtils::debug(QObject::tr("ISI:  |%1| |%2|").arg(Last, First));
         if (containLowerCaseLetter(First))
             return false;
         if (!containLowerCaseLetter(Last))
@@ -364,9 +366,10 @@ bool authorString::isReverseOrder(const QString& author)
 bool authorString::containLowerCaseLetter(const QString& author)
 {
     QString author_line(author);
-    author_line.remove(QRegExp("\\band\\b")); // Remove possible 'and' separator
+    author_line.remove(QRegExp("\\band\\b"));                                 // Remove possible 'and' separator
     author_line.remove(QRegExp(author::prefixes + '_', Qt::CaseInsensitive)); // Remove possible prefixes
-    author_line.remove(QRegExp(author::double_initials + '_', Qt::CaseSensitive)); // Remove possible two-letter initials
+    author_line.remove(
+        QRegExp(author::double_initials + '_', Qt::CaseSensitive)); // Remove possible two-letter initials
     for (int i = 0; i < author_line.length(); i++)
     {
         if (author_line.at(i).isLetter())
@@ -547,8 +550,8 @@ void encoder::encode(const QString& raw)
 
     scapePattern("aL+[nN]{1,2}");
     scapePattern("a[nNw]&L+[nN]{1,2}"); // in Linear and / Sublinear Time
-    scapePattern(":L+[InN]{1,2}"); // ... Structure Classification: / A Survey
-    scapePattern("[nN]*&L[nN]L"); // Not an & for author
+    scapePattern(":L+[InN]{1,2}");      // ... Structure Classification: / A Survey
+    scapePattern("[nN]*&L[nN]L");       // Not an & for author
 }
 
 QString encoder::decoded(const int position, const int length) const
@@ -614,33 +617,51 @@ bool encoder::isAdparticle(const QString& w)
     const int ss(ws * int(sizeof(char)));
     if (ws == 2)
     {
-        if (memcmp("of", s, ss) == 0) return true;
-        if (memcmp("on", s, ss) == 0) return true;
-        if (memcmp("to", s, ss) == 0) return true;
-        if (memcmp("in", s, ss) == 0) return true;
-        if (memcmp("as", s, ss) == 0) return true;
-        if (memcmp("vs", s, ss) == 0) return true;
-        if (memcmp("at", s, ss) == 0) return true;
-        if (memcmp("is", s, ss) == 0) return true;
-        if (memcmp("an", s, ss) == 0) return true;
+        if (memcmp("of", s, ss) == 0)
+            return true;
+        if (memcmp("on", s, ss) == 0)
+            return true;
+        if (memcmp("to", s, ss) == 0)
+            return true;
+        if (memcmp("in", s, ss) == 0)
+            return true;
+        if (memcmp("as", s, ss) == 0)
+            return true;
+        if (memcmp("vs", s, ss) == 0)
+            return true;
+        if (memcmp("at", s, ss) == 0)
+            return true;
+        if (memcmp("is", s, ss) == 0)
+            return true;
+        if (memcmp("an", s, ss) == 0)
+            return true;
     }
     if (ws == 3)
     {
-        if (memcmp("for", s, ss) == 0) return true;
-        if (memcmp("but", s, ss) == 0) return true;
-        if (memcmp("are", s, ss) == 0) return true;
-        if (memcmp("its", s, ss) == 0) return true;
-        if (memcmp("the", s, ss) == 0) return true;
+        if (memcmp("for", s, ss) == 0)
+            return true;
+        if (memcmp("but", s, ss) == 0)
+            return true;
+        if (memcmp("are", s, ss) == 0)
+            return true;
+        if (memcmp("its", s, ss) == 0)
+            return true;
+        if (memcmp("the", s, ss) == 0)
+            return true;
     }
     if (ws == 4)
     {
-        if (memcmp("from", s, ss) == 0) return true;
-        if (memcmp("with", s, ss) == 0) return true;
-        if (memcmp("into", s, ss) == 0) return true;
+        if (memcmp("from", s, ss) == 0)
+            return true;
+        if (memcmp("with", s, ss) == 0)
+            return true;
+        if (memcmp("into", s, ss) == 0)
+            return true;
     }
     if (ws == 6)
     {
-        if (memcmp("within", s, ss) == 0) return true;
+        if (memcmp("within", s, ss) == 0)
+            return true;
     }
     return false;
 }
