@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef AUTHORSTRING_H
@@ -22,13 +22,15 @@ static const QString prefixes("(da|de|dal|del|der|di|do|du|dos|el|la|le|lo|van|v
 
 static const QString name("(?:\\w[-'\\w]{1,})");
 static const QString initials("(?:\\s*-{0,1}\\b\\w\\b\\.{0,1}){1,3}");
-static const QString reversed_romance_name("(?:\\w[-'\\w]{1,})\\s+(?:\\w[-'\\w]{1,}),\\s*(?:\\w[-'\\w]{1,}|" + initials + ')');
+static const QString reversed_romance_name("(?:\\w[-'\\w]{1,})\\s+(?:\\w[-'\\w]{1,}),\\s*(?:\\w[-'\\w]{1,}|" +
+        initials + ')');
 
 static const QRegExp reversed_name_rx('^' + name + ',');
 // Cases 'n1 n2, n3', 'n1 n2, n3 and n4 n5, n6', 'n1 n2, n3 and n4, n5 n6' are necessarily reverse order
-static const QRegExp reversed_romance_name_rx("^(?:" + reversed_romance_name + '|'
-        + reversed_romance_name + " and " + reversed_romance_name + '|'
-        + reversed_romance_name + " and (?:\\w[-'\\w]{1,}),\\s*(?:\\w[-'\\w]{1,}|\\w[-'\\w]{1,} \\w[-'\\w]{1,}|" + initials + "))$");
+static const QRegExp reversed_romance_name_rx(
+    "^(?:" + reversed_romance_name + '|' + reversed_romance_name + " and " + reversed_romance_name + '|' +
+    reversed_romance_name + " and (?:\\w[-'\\w]{1,}),\\s*(?:\\w[-'\\w]{1,}|\\w[-'\\w]{1,} \\w[-'\\w]{1,}|" + initials +
+    "))$");
 
 // simplifyString
 static const QRegExp simplify_string_rx1(QString("%1(?=\\w)").arg(QChar(8217)));
@@ -46,11 +48,12 @@ inline QString& simplifyString(QString& author, const bool full = false)
         author.replace(':', ' ');
     }
     author.replace(simplify_string_rx1, "\'"); // Normalize apostrophe
-    author.remove(simplify_string_rx2); // Remove spurious apostrophes
-    author.replace(simplify_string_rx3, "/"); // Break dates, addresses, etc, but remove from author's foot notes.
-    author.replace(simplify_string_rx4, ","); // Help no-separator designs, and also break zip codes.
+    author.remove(simplify_string_rx2);        // Remove spurious apostrophes
+    author.replace(simplify_string_rx3, "/");  // Break dates, addresses, etc, but remove from author's foot notes.
+    author.replace(simplify_string_rx4, ",");  // Help no-separator designs, and also break zip codes.
     author.replace(simplify_string_rx5, " ");
-    author.remove(simplify_string_rx6); // Better remove if no conflict. It will help to not confuse with chemical formula.
+    author.remove(
+        simplify_string_rx6); // Better remove if no conflict. It will help to not confuse with chemical formula.
     author.replace(simplify_string_rx7, " ");
     author = c2bUtils::simplifyString(author);
     return author;
@@ -115,7 +118,7 @@ struct encoder
             if (pos > -1)
             {
                 scape(pos, rx.matchedLength(), c);
-                pos  += rx.matchedLength();
+                pos += rx.matchedLength();
             }
         }
     }
@@ -164,7 +167,6 @@ private:
     QString _author_string;
     author::unifier as_unifier;
     bool _full_form;
-
 };
 
 #endif
