@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "bibExtractor.h"
@@ -26,8 +26,8 @@ bibExtractor::bibExtractor(QObject* parento) : QObject(parento), cout(*(new QTex
     init();
 }
 
-bibExtractor::bibExtractor(bibParser* bp, metadataParser* mp, networkQuery* nq, QObject* parento) :
-    QObject(parento), cout(*(new QTextStream(stdout))), _bpP(bp), _mpP(mp), _networkQP(nq)
+bibExtractor::bibExtractor(bibParser* bp, metadataParser* mp, networkQuery* nq, QObject* parento)
+    : QObject(parento), cout(*(new QTextStream(stdout))), _bpP(bp), _mpP(mp), _networkQP(nq)
 {
     _settingsP = settings::instance();
     Q_ASSERT_X(_bpP, "bibExtractor", "bibParser was not instantiated");
@@ -43,10 +43,10 @@ bibExtractor::~bibExtractor()
 
 void bibExtractor::init()
 {
-    connect(_networkQP, SIGNAL(queryEnded(bool, const QString&, const QString&)),
-            this, SLOT(queryEnded(bool, const QString&, const QString&)), Qt::QueuedConnection);
-    connect(_networkQP->networkPtr(), SIGNAL(proxyAuthenticationRequired(const QNetworkProxy&, QAuthenticator*)),
-            this, SLOT(proxyLogMessage()));
+    connect(_networkQP, SIGNAL(queryEnded(bool,QString,QString)), this, SLOT(queryEnded(bool,QString,QString)),
+            Qt::QueuedConnection);
+    connect(_networkQP->networkPtr(), SIGNAL(proxyAuthenticationRequired(QNetworkProxy,QAuthenticator*)), this,
+            SLOT(proxyLogMessage()));
     _event_loop = new QEventLoop(this);
 }
 
@@ -61,7 +61,7 @@ int bibExtractor::extract(const QStringList& input_fns, const QString& output_fn
     for (int i = 0; i < input_fns.count(); ++i)
     {
         const QString& input_fn = input_fns.at(i);
-        if (!QFileInfo(input_fn).exists())
+        if (!QFileInfo::exists(input_fn))
         {
             logMessage(tr("Error: File %1 does not exist.").arg(input_fn));
             continue;
@@ -82,8 +82,9 @@ int bibExtractor::extract(const QStringList& input_fns, const QString& output_fn
         if (_settingsP->value("cb2Bib/MovePdf").toBool() && !_document_fn.isEmpty() && isReliable())
         {
             const QString file(_bpP->documentFilename(_document_fn, output_fn));
-            const QString target_doc_fn(c2bUtils::documentAbsoluteName(_settingsP->value("cb2Bib/RelativePdfDirectory").toBool(),
-                                        output_fn, _settingsP->fileName("cb2Bib/PdfDirectory"), file));
+            const QString target_doc_fn(
+                c2bUtils::documentAbsoluteName(_settingsP->value("cb2Bib/RelativePdfDirectory").toBool(), output_fn,
+                                               _settingsP->fileName("cb2Bib/PdfDirectory"), file));
             const QString doc_dirname(QFileInfo(target_doc_fn).absolutePath());
             QDir doc_dir(doc_dirname);
             if (!doc_dir.exists())
