@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef BIBEXTRACTOR_H
@@ -33,7 +33,11 @@ public:
     bibExtractor(bibParser* bp, metadataParser* mp, networkQuery* nq, QObject* parento = 0);
     ~bibExtractor();
 
-    enum InputType {PlainText, Document};
+    enum InputType
+    {
+        PlainText,
+        Document
+    };
 
     int extract(const QString& text, QString* bibtex);
     int extract(const QStringList& input_fns, const QString& output_fn, const InputType& type);
@@ -61,7 +65,6 @@ private slots:
     void logMessage(const QString& ms) const;
     void proxyLogMessage() const;
     void queryEnded(bool succeeded, const QString& targetPDF, const QString& targetBib);
-
 };
 
 #endif
