@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "bibParser.h"
@@ -35,7 +35,7 @@ bibParser::bibParser(QObject* parento) : coreBibParser(parento)
 
     // Creating (external) reference preparser
     _preparserP = new bibPreparser(this);
-    connect(_preparserP, SIGNAL(statusMessage(const QString&)), this, SIGNAL(statusMessage(const QString&)));
+    connect(_preparserP, SIGNAL(statusMessage(QString)), this, SIGNAL(statusMessage(QString)));
 
     // Creating stream preprocess object
     _preprocessP = new preprocess(this);
@@ -63,7 +63,7 @@ QString bibParser::parse(const QString& field, const QString& value, const QStri
         document::normalize(v, document::Complete);
     v = removeTags(v);
     if (v.isEmpty())
-        return (v);
+        return v;
     c2bUtils::fullBibToC2b(v);
     if (field == "author")
     {
@@ -164,54 +164,60 @@ bibReference& bibParser::parse(bibReference& reference)
 
 QString bibParser::setJournalsToFull(const QString& text, const bool alternate)
 {
+    const bool ConvertReferenceToLaTeX(_settingsP->value("cb2Bib/ConvertReferenceToLaTeX").toBool());
     QString substituted_text(text);
-    QRegExp jnre("\\bjournal\\s*=\\s*[\\{\"](.*)[\\}\"]", Qt::CaseInsensitive);
-    jnre.setMinimal(true);
+    QRegExp jnre("\\bjournal\\s*=\\s*[\\{\"]", Qt::CaseInsensitive);
+    QString jn;
     int pos(0);
     uint nj(0);
     while (pos >= 0)
     {
         pos = jnre.indexIn(substituted_text, pos);
-        if (pos > -1)
+        if (pos > 0 && c2bUtils::inBraces(pos + jnre.matchedLength(), substituted_text, &jn))
         {
-            QString line(jnre.cap(0));
-            const QString jn(jnre.cap(1));
-            line.replace(jn, alternate ? alternateFullJournal(jn) : fullJournal(jn));
-            substituted_text.replace(pos, jnre.matchedLength(), line);
-            pos += line.length();
+            const int jnlength(jn.length());
+            c2bUtils::bibToC2b(jn);
+            jn = alternate ? alternateFullJournal(jn) : fullJournal(jn);
+            if (ConvertReferenceToLaTeX)
+                c2bUtils::c2bToBib(jn);
+            pos += jnre.matchedLength();
+            substituted_text.replace(pos, jnlength, jn);
             nj++;
         }
-        emit statusMessage(tr("Processed %1 journal names...").arg(nj));
-        QCoreApplication::processEvents();
+        else if (pos >= 0)
+            ++pos;
     }
     emit statusMessage(tr("Processed %1 journal names.").arg(nj));
-    return (substituted_text);
+    return substituted_text;
 }
 
 QString bibParser::setJournalsToAbbreviated(const QString& text, const bool alternate)
 {
+    const bool ConvertReferenceToLaTeX(_settingsP->value("cb2Bib/ConvertReferenceToLaTeX").toBool());
     QString substituted_text(text);
-    QRegExp jnre("\\bjournal\\s*=\\s*[\\{\"](.*)[\\}\"]", Qt::CaseInsensitive);
-    jnre.setMinimal(true);
+    QRegExp jnre("\\bjournal\\s*=\\s*[\\{\"]", Qt::CaseInsensitive);
+    QString jn;
     int pos(0);
     uint nj(0);
     while (pos >= 0)
     {
         pos = jnre.indexIn(substituted_text, pos);
-        if (pos > -1)
+        if (pos > 0 && c2bUtils::inBraces(pos + jnre.matchedLength(), substituted_text, &jn))
         {
-            QString line(jnre.cap(0));
-            const QString jn(jnre.cap(1));
-            line.replace(jn, alternate ? alternateAbbreviatedJournal(jn) : abbreviatedJournal(jn));
-            substituted_text.replace(pos, jnre.matchedLength(), line);
-            pos += line.length();
+            const int jnlength(jn.length());
+            c2bUtils::bibToC2b(jn);
+            jn = alternate ? alternateAbbreviatedJournal(jn) : abbreviatedJournal(jn);
+            if (ConvertReferenceToLaTeX)
+                c2bUtils::c2bToBib(jn);
+            pos += jnre.matchedLength();
+            substituted_text.replace(pos, jnlength, jn);
             nj++;
         }
-        emit statusMessage(tr("Processed %1 journal names...").arg(nj));
-        QCoreApplication::processEvents();
+        else if (pos >= 0)
+            ++pos;
     }
     emit statusMessage(tr("Processed %1 journal names.").arg(nj));
-    return (substituted_text);
+    return substituted_text;
 }
 
 QString bibParser::excerpt(const QString& text, const QStringList& hints) const
@@ -223,9 +229,12 @@ QString bibParser::excerpt(const QString& text, const QStringList& hints) const
     txt.replace(QRegExp("\\d"), " ");
     txt.replace(c2bUtils::nonLetter, " ");
     txt.replace(QRegExp("\\b\\w{1,2}\\b"), " ");
-    txt.replace(QRegExp("\\b(about|and|are|com|for|from|how|into|that|the|their|this|where|with|www)\\b", Qt::CaseInsensitive), " ");
+    txt.replace(
+        QRegExp("\\b(about|and|are|com|for|from|how|into|that|the|their|this|where|with|www)\\b", Qt::CaseInsensitive),
+        " ");
     txt.replace(QRegExp("\\b(january|february|march|april|may|june|july|august|september|october|november|december)\\b",
-                        Qt::CaseInsensitive), " ");
+                        Qt::CaseInsensitive),
+                " ");
     txt = hints.join(" ") + ' ' + txt;
     txt = c2bUtils::simplifyString(txt);
     const QStringList txtlist(txt.split(' ', QString::SkipEmptyParts));
@@ -458,8 +467,8 @@ void bibParser::parse(const QString& text, QString* out_text, QString* out_tagte
             if (tag == "AB")
                 _current_reference["abstract"] = parse("abstract", value);
             else if (tag == "FAU")
-                _current_reference["author"] = parse("addauthors", author::fromMedline(value),
-                                                     _current_reference.value("author"));
+                _current_reference["author"] =
+                    parse("addauthors", author::fromMedline(value), _current_reference.value("author"));
             else if (tag == "TA")
                 _current_reference["journal"] = parse("journal", value);
             else if (tag == "IP")
@@ -536,7 +545,8 @@ void bibParser::parse(const QString& text, QString* out_text, QString* out_tagte
             c2bUtils::debug(tr("Position: |%1|").arg(npos));
             if (efields != cfields)
             {
-                c2bUtils::warn(tr("RegExp |%1| is not valid. Mismatch between expected and actual captures").arg(ItemX));
+                c2bUtils::warn(
+                    tr("RegExp |%1| is not valid. Mismatch between expected and actual captures").arg(ItemX));
                 npos = -1;
             }
             nfilters++;
@@ -552,10 +562,12 @@ void bibParser::parse(const QString& text, QString* out_text, QString* out_tagte
                     {
                         if (listi == "author")
                             // Reminder: "addauthors" requires to init _current_reference["author"]
-                            _current_reference[listi] = parse("addauthors", rx.cap(ii), _current_reference.value(listi));
+                            _current_reference[listi] =
+                                parse("addauthors", rx.cap(ii), _current_reference.value(listi));
                         else if (listi == "editor")
                             // Reminder: "addeditors" requires to init _current_reference["editor"]
-                            _current_reference[listi] = parse("addeditors", rx.cap(ii), _current_reference.value(listi));
+                            _current_reference[listi] =
+                                parse("addeditors", rx.cap(ii), _current_reference.value(listi));
                         else if (listi == "title")
                             // Reminder: "addtitle" requires to init _current_reference["title"]
                             _current_reference[listi] = parse("addtitle", rx.cap(ii), _current_reference.value(listi));
@@ -582,8 +594,8 @@ void bibParser::parse(const QString& text, QString* out_text, QString* out_tagte
         const QString clean_text(removeTags(ottext));
         _heuristic_parserP->guessFields(clean_text, ottext);
         currentReferenceUpdated();
-        _auto_recognized_string = tr("Applied %1 filters: No automatic format detection. %2 fields guessed.")
-                                  .arg(nfilters).arg(fieldCount());
+        _auto_recognized_string =
+            tr("Applied %1 filters: No automatic format detection. %2 fields guessed.").arg(nfilters).arg(fieldCount());
     }
     else
         _auto_recognized_string = tr("Applied %1 filters: No automatic format detection.").arg(nfilters);
@@ -619,21 +631,21 @@ void bibParser::guessFields(const QString& text)
 QString bibParser::setTags(const QString& text) const
 {
     QString tagged_text(text.trimmed());
-    tagged_text.replace(QRegExp("\\r\\n"), "<found_new_line>");       // Windows new line
-    tagged_text.replace(QRegExp("\\n"), "<found_new_line>");          // Linux new line, LF
-    tagged_text.replace(QRegExp("\\r"), "<found_new_line>");          // OSX new line, CR
+    tagged_text.replace(QRegExp("\\r\\n"), "<found_new_line>"); // Windows new line
+    tagged_text.replace(QRegExp("\\n"), "<found_new_line>");    // Linux new line, LF
+    tagged_text.replace(QRegExp("\\r"), "<found_new_line>");    // OSX new line, CR
     QStringList spText(tagged_text.split("<found_new_line>"));
     int n(spText.count());
     tagged_text.clear();
     for (int i = 0; i < n - 1; i++)
         tagged_text += spText.at(i) + QString("<NewLine%1>").arg(i + 1);
-    tagged_text += spText[n-1];
+    tagged_text += spText[n - 1];
     spText = tagged_text.split(QRegExp("(\\s{10,}|\\t)"));
     n = spText.count();
     tagged_text.clear();
     for (int i = 0; i < n - 1; i++)
         tagged_text += spText.at(i) + QString("<Tab%1>").arg(i + 1);
-    tagged_text += spText[n-1];
+    tagged_text += spText[n - 1];
     tagged_text = c2bUtils::simplifyString(tagged_text);
     return tagged_text;
 }
