@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "bibSearcher.h"
@@ -97,7 +97,8 @@ bibSearcher::bibSearcher(bibParser* bp, QObject* parento) : QObject(parento), _b
     Top level driver for searching BibTeX files. Specialized constructor for
     searching repeated or similar references.
 */
-bibSearcher::bibSearcher(bibParser* bp, const QString& bib_dir, QObject* parento) : QObject(parento), _bpP(bp), _do_search_similar(true)
+bibSearcher::bibSearcher(bibParser* bp, const QString& bib_dir, QObject* parento)
+    : QObject(parento), _bpP(bp), _do_search_similar(true)
 {
     // Retrieve (any_author(approximate) AND any_title(approximate)) OR citeidName(exact)
     clear();
@@ -146,13 +147,12 @@ void bibSearcher::exec()
     for (int i = 0; i < _patterns.count(); ++i)
     {
         const searchPattern& pattern = _patterns.at(i);
-        _log_string += tr("% Pattern%1: %2%3\n").arg(i + 1).arg(and_or).arg(pattern.toString());
+        _log_string += tr("% Pattern%1: %2%3\n").arg(i + 1).arg(and_or, pattern.toString());
     }
 
     // Search In Files
-    const QStringList flist(_all_bibtex_files ?
-                            c2bUtils::filesInDir(_bibtex_dir, QStringList() << "*.bib") :
-                            c2bUtils::filesInDir(_bibtex_file, QStringList() << "*.bib"));
+    const QStringList flist(_all_bibtex_files ? c2bUtils::filesInDir(_bibtex_dir, QStringList() << "*.bib")
+                            : c2bUtils::filesInDir(_bibtex_file, QStringList() << "*.bib"));
     for (int i = 0; i < flist.count(); ++i)
     {
         search(flist.at(i));
@@ -165,8 +165,10 @@ void bibSearcher::exec()
     }
 
     // Search Done
-    _log_string += tr("% Scanned References: %1  BibTeX Files: %2  Linked Files: %3\n").
-                   arg(_reference_counter).arg(_bibtex_counter).arg(_document_counter);
+    _log_string += tr("% Scanned References: %1  BibTeX Files: %2  Linked Files: %3\n")
+                   .arg(_reference_counter)
+                   .arg(_bibtex_counter)
+                   .arg(_document_counter);
     if (_include_documents)
         _documents.unload();
     if (_hits_map.count() == 0)
@@ -234,7 +236,8 @@ void bibSearcher::search(const QString& bib_file)
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
     {
         _error_counter++;
-        _log_string += tr("% [cb2bib] Unable to open the file %1 for reading. Error: '%2'.\n").arg(bib_file).arg(file.errorString());
+        _log_string +=
+            tr("% [cb2bib] Unable to open the file %1 for reading. Error: '%2'.\n").arg(bib_file, file.errorString());
         return;
     }
     QTextStream stream(&file);
@@ -269,8 +272,9 @@ void bibSearcher::search(const QString& bib_file)
 
 void bibSearcher::searchReference(const QString& bib_file, const bibReference& ref)
 {
-    const bool include_document(_include_documents &&
-                                _documents.setCurrent(ref.value("file"), &_document_counter, &_log_string, &_error_counter));
+    const bool include_document(
+        _include_documents &&
+        _documents.setCurrent(ref.value("file"), &_document_counter, &_log_string, &_error_counter));
 
     // Initialize composite search
     bool hit(_boolean_and);
@@ -456,7 +460,7 @@ const QString bibSearcher::excerpts(const QString& contents) const
         }
         else
         {
-            exc += contents.mid(pos + length, i_pos.at(i + 1) - pos - length);
+            exc += contents.midRef(pos + length, i_pos.at(i + 1) - pos - length);
             item_begins = false;
         }
     }
