@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef CB2BIB_PARAMETERS_H
@@ -15,12 +15,11 @@ const int C2B_MESSAGE_TIME(6000);
 const QString C2B_APPLICATION("cb2Bib");
 const QString C2B_CITE_ID_PATTERN("<<author_first>><<year_abbreviated>><<ppages_first>>");
 const QString C2B_DOCUMENT_ID_PATTERN("<<citeid>>");
-const QString C2B_FIND_REPLACE_LIST(
-    "Corresponding Author Contact Information||ScienceDirect alt tag^e"
-    "E-mail The Corresponding Author||ScienceDirect alt tag^e"
-    "small pi, Greek|$\\pi$|ScienceDirect alt tag^e"
-    "{sect}||PNAS - Author String^e"
-    "{dagger}||PNAS - Author String");
+const QString C2B_FIND_REPLACE_LIST("Corresponding Author Contact Information||ScienceDirect alt tag^e"
+                                    "E-mail The Corresponding Author||ScienceDirect alt tag^e"
+                                    "small pi, Greek|$\\pi$|ScienceDirect alt tag^e"
+                                    "{sect}||PNAS - Author String^e"
+                                    "{dagger}||PNAS - Author String");
 const QString C2B_ICON_ABOUT_B_BACK("back_cb2bib_32.png");
 const QString C2B_ICON_ABOUT_B("cb2bib.png");
 const QString C2B_ICON_CONNECT_B("connect_established.png");
@@ -29,7 +28,7 @@ const QString C2B_ICON_DISCONNECT_B("connect_no.png");
 const QString C2B_ICON_VIEWBIB_B("viewbib.png");
 const QString C2B_ICON_VIEWC2B_B("viewcb.png");
 const QString C2B_ORGANIZATION("MOLspaces");
-const QString C2B_VERSION("1.9.9");
+const QString C2B_VERSION("2.0.0");
 
 // File Manager Client
 #if defined(Q_OS_WIN)
