@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef CB2BIB_UTILITIES_H
@@ -23,7 +23,14 @@
 namespace c2bUtils
 {
 
-enum AsciiConversion {Cleanup, Collation, FromBibTeX, KeepWords, Transliterate};
+enum AsciiConversion
+{
+    Cleanup,
+    Collation,
+    FromBibTeX,
+    KeepWords,
+    Transliterate
+};
 extern QString setCapitalization(const QString& str);
 extern QString toAscii(const QString& str, const AsciiConversion type);
 extern QString& bibToC2b(QString& str);
@@ -177,7 +184,8 @@ inline bool isUpperCaseString(const QString& str, const int pos0 = 0, int posn =
 /**
     Gives a document absolute, full path-name
 */
-inline QString documentAbsoluteName(const bool bibtexrelative, const QString& bibtexfn, const QString& docdir, const QString& docfn)
+inline QString documentAbsoluteName(const bool bibtexrelative, const QString& bibtexfn, const QString& docdir,
+                                    const QString& docfn)
 {
     QString name;
     if (bibtexrelative)
@@ -200,7 +208,8 @@ inline QString documentAbsoluteName(const bool bibtexrelative, const QString& bi
 /**
     Gives a document filename, as it will be written to BibTeX file tag
 */
-inline QString documentFilename(const bool bibtexrelative, const QString& bibtexfn, const QString& docdir, const QString& docfn)
+inline QString documentFilename(const bool bibtexrelative, const QString& bibtexfn, const QString& docdir,
+                                const QString& docfn)
 {
     QString name;
     if (bibtexrelative)
@@ -253,7 +262,7 @@ inline QString fileToString(const QString& fn, bool delete_on_close = false)
             f.remove();
         else
             f.close();
-        return (contents);
+        return contents;
     }
     else
         return QString();
@@ -357,7 +366,7 @@ inline QString fromQtXmlString(QString str)
     str.replace("%%gt;", ">");
     str.replace("%%lt;", "<");
     str.replace("%%quot;", "\"");
-    return (str);
+    return str;
 }
 
 inline QString toQtXmlString(QString str)
@@ -369,7 +378,7 @@ inline QString toQtXmlString(QString str)
     str.replace("&gt;", "%%gt;");
     str.replace("&lt;", "%%lt;");
     str.replace("&quot;", "%%quot;");
-    return (str);
+    return str;
 }
 
 inline void warn(const QString& ms)
