@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "collectionAnalyzer.h"
@@ -14,7 +14,8 @@
 #include <cmath>
 
 
-template <typename T> class lengthsorting
+template <typename T>
+class lengthsorting
 {
 public:
     explicit lengthsorting(const T& data) : _data(data) {}
@@ -27,6 +28,7 @@ public:
         else
             return ni < nj;
     }
+
 private:
     const T& _data;
 };
@@ -41,7 +43,8 @@ void double_sort(int start, int end, T1* v1, T2* v2)
 {
 top:
     int span = end - start;
-    if (span < 2) return;
+    if (span < 2)
+        return;
     --end;
     int low = start;
     int high = end - 1;
@@ -51,7 +54,8 @@ top:
         qSwap((*v1)[end], (*v1)[start]);
         qSwap((*v2)[end], (*v2)[start]);
     }
-    if (span == 2) return;
+    if (span == 2)
+        return;
     if ((*v1)[pivot] > (*v1)[start])
     {
         qSwap((*v1)[pivot], (*v1)[start]);
@@ -62,13 +66,16 @@ top:
         qSwap((*v1)[end], (*v1)[pivot]);
         qSwap((*v2)[end], (*v2)[pivot]);
     }
-    if (span == 3) return;
+    if (span == 3)
+        return;
     qSwap((*v1)[pivot], (*v1)[end]);
     qSwap((*v2)[pivot], (*v2)[end]);
     while (low < high)
     {
-        while (low < high && (*v1)[low] > (*v1)[end]) ++low;
-        while (high > low && (*v1)[end] > (*v1)[high]) --high;
+        while (low < high && (*v1)[low] > (*v1)[end])
+            ++low;
+        while (high > low && (*v1)[end] > (*v1)[high])
+            --high;
         if (low < high)
         {
             qSwap((*v1)[low], (*v1)[high]);
@@ -76,9 +83,11 @@ top:
             ++low;
             --high;
         }
-        else break;
+        else
+            break;
     }
-    if ((*v1)[low] > (*v1)[end]) ++low;
+    if ((*v1)[low] > (*v1)[end])
+        ++low;
     qSwap((*v1)[end], (*v1)[low]);
     qSwap((*v2)[end], (*v2)[low]);
     double_sort(start, low, v1, v2);
@@ -88,13 +97,8 @@ top:
 }
 
 
-
-collectionAnalyzer::collectionAnalyzer() :
-    _ndocuments(0),
-    _nsentences(0),
-    _nsimilar(0),
-    _settingsP(settings::instance())
-{}
+collectionAnalyzer::collectionAnalyzer()
+    : _ndocuments(0), _nsentences(0), _nsimilar(0), _settingsP(settings::instance()) {}
 
 
 void collectionAnalyzer::reload()
@@ -167,7 +171,7 @@ void collectionAnalyzer::setDocumentKeywords(const QString& documentfn)
     if (ndsentences == 0)
         return;
 
-    lengthsorting< QVarLengthArray<QString> > ls(_sentences);
+    lengthsorting<QVarLengthArray<QString>> ls(_sentences);
     qSort(dsentences.begin(), dsentences.end(), ls);
 
     for (int i = 0; i < ndsentences; ++i)
@@ -259,9 +263,9 @@ void collectionAnalyzer::skipSimilarDocument(const int i)
 {
     --_nsimilar;
     for (int j = i; j < _nsimilar; ++j)
-        _similarity[j] = _similarity[j+1];
+        _similarity[j] = _similarity[j + 1];
     for (int j = i; j < _nsimilar; ++j)
-        _similarity[j] = _similarity[j+1];
+        _similarity[j] = _similarity[j + 1];
 }
 
 void collectionAnalyzer::grepDocuments(const QString& documentfn, QVector<int>* dsentences) const
