@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "compositePattern.h"
@@ -9,7 +9,8 @@
 #include "cb2bib_utilities.h"
 
 
-template <typename T> class descending
+template <typename T>
+class descending
 {
 public:
     explicit descending(const T& data) : _data(data) {}
@@ -17,25 +18,21 @@ public:
     {
         return _data.at(i) > _data.at(j);
     }
+
 private:
     const T& _data;
 };
 
 
-compositePattern::compositePattern() :
-    _case_sensitivity(Qt::CaseSensitive),
-    _is_multipattern(false),
-    _subpattern_count(0),
-    _matched_length(-1)
-{}
+compositePattern::compositePattern()
+    : _case_sensitivity(Qt::CaseSensitive), _is_multipattern(false), _subpattern_count(0), _matched_length(-1) {}
 
-compositePattern::compositePattern(const QString& pattern, const Qt::CaseSensitivity cs) :
-    _string(pattern.simplified()),
-    _case_sensitivity(cs),
-    _is_multipattern(false),
-    _subpattern_count(0),
-    _matched_length(-1)
-{}
+compositePattern::compositePattern(const QString& pattern, const Qt::CaseSensitivity cs)
+    : _string(pattern.simplified()),
+      _case_sensitivity(cs),
+      _is_multipattern(false),
+      _subpattern_count(0),
+      _matched_length(-1) {}
 
 
 QString compositePattern::escape(const QString& str, const Qt::CaseSensitivity cs)
@@ -57,6 +54,6 @@ void compositePattern::set_sort_index()
     _index.resize(_subpattern_count);
     for (int i = 0; i < _subpattern_count; ++i)
         _index[i] = i;
-    descending< QList<double> > sort(_ranks);
+    descending<QList<double>> sort(_ranks);
     qSort(_index.begin(), _index.end(), sort);
 }
