@@ -1,15 +1,14 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "coreBibParser.h"
 
 
-coreBibParser::coreBibParser(QObject* parento) :
-    QObject(parento),
-    _close(QChar('}')), _comma(QChar(',')), _open(QChar('{')), _space(QChar(' '))
+coreBibParser::coreBibParser(QObject* parento)
+    : QObject(parento), _close(QChar('}')), _comma(QChar(',')), _open(QChar('{')), _space(QChar(' '))
 {
     _settingsP = settings::instance();
 
@@ -145,57 +144,56 @@ QString coreBibParser::adjacentNumbers(const QString& numbers) const
 
 void coreBibParser::setFields()
 {
-    _bibliographic_fields <<
-                          "title" <<
-                          "author" <<
-                          "journal" <<
-                          "booktitle" <<
-                          "series" <<
-                          "chapter" <<
-                          "pages" <<
-                          "volume" <<
-                          "number" <<
-                          "edition" <<
-                          "institution" <<
-                          "organization" <<
-                          "school" <<
-                          "address" <<
-                          "month" <<
-                          "year" <<
-                          "editor" <<
-                          "publisher" <<
-                          "abstract" <<
-                          "keywords" <<
-                          "isbn" <<
-                          "issn" <<
-                          "doi" <<
-                          "eprint" <<
-                          "file" <<
-                          "url" <<
-                          "note" <<
-                          "annote";
+    _bibliographic_fields << "title"
+                          << "author"
+                          << "journal"
+                          << "booktitle"
+                          << "series"
+                          << "chapter"
+                          << "pages"
+                          << "volume"
+                          << "number"
+                          << "edition"
+                          << "institution"
+                          << "organization"
+                          << "school"
+                          << "address"
+                          << "month"
+                          << "year"
+                          << "editor"
+                          << "publisher"
+                          << "abstract"
+                          << "keywords"
+                          << "isbn"
+                          << "issn"
+                          << "doi"
+                          << "eprint"
+                          << "file"
+                          << "url"
+                          << "note"
+                          << "annote";
     _sorted_bibliographic_fields = _bibliographic_fields;
     qSort(_sorted_bibliographic_fields);
 }
 
 void coreBibParser::setTypes()
 {
-    _bibliographic_types << "" <<
-                         "article" <<
-                         "book" <<
-                         "booklet" <<
-                         "conference" <<
-                         "inbook" <<
-                         "incollection" <<
-                         "inproceedings" <<
-                         "manual" <<
-                         "mastersthesis" <<
-                         "misc" <<
-                         "periodical" <<
-                         "phdthesis" <<
-                         "proceedings" <<
-                         "techreport" <<
-                         "unpublished";
+    _bibliographic_types << ""
+                         << "article"
+                         << "book"
+                         << "booklet"
+                         << "conference"
+                         << "inbook"
+                         << "incollection"
+                         << "inproceedings"
+                         << "manual"
+                         << "mastersthesis"
+                         << "misc"
+                         << "periodical"
+                         << "phdthesis"
+                         << "proceedings"
+                         << "techreport"
+                         << "unpublished";
 }
 
 void coreBibParser::setRegularExpressions()
