@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "crJson.h"
@@ -31,7 +31,8 @@ void crJson::readReference(const QString& json)
     QJsonDocument jdoc(QJsonDocument::fromJson(json.toUtf8(), &jerr));
     if (jdoc.isNull() || jdoc.isEmpty())
     {
-        _error_string = QObject::tr("Invalid data%1").arg(jerr.errorString().isEmpty() ? QString() : ": " + jerr.errorString());
+        _error_string =
+            QObject::tr("Invalid data%1").arg(jerr.errorString().isEmpty() ? QString() : ": " + jerr.errorString());
         return;
     }
     QJsonObject jobj(jdoc.object().value("message").toObject());
@@ -55,14 +56,16 @@ void crJson::readReference(const QString& json)
 
     if (!jobj.value("published-print").isUndefined())
     {
-        const QJsonValue jyear(jobj.value("published-print").toObject().value("date-parts").toArray().first().toArray().first());
+        const QJsonValue jyear(
+            jobj.value("published-print").toObject().value("date-parts").toArray().first().toArray().first());
         if (!jyear.isUndefined())
             _reference["year"] = QString::number(jyear.toDouble());
     }
     else if (!jobj.value("published-online").isUndefined())
     {
         // For articles no longer published in print
-        const QJsonValue jyear(jobj.value("published-online").toObject().value("date-parts").toArray().first().toArray().first());
+        const QJsonValue jyear(
+            jobj.value("published-online").toObject().value("date-parts").toArray().first().toArray().first());
         if (!jyear.isUndefined())
             _reference["year"] = QString::number(jyear.toDouble());
     }
@@ -212,7 +215,7 @@ QString crJson::_bibtex_title(const QStringList& titles, const QStringList& subt
         const int wt(_words(titles.first()));
         const int ws(_words(subtitles.first()));
         const int wu(_words(titles.first() + ' ' + subtitles.first()));
-        const int s(100 *(wt + ws - wu) / sqrt(double(wt * ws)));
+        const int s(100 * (wt + ws - wu) / sqrt(double(wt * ws)));
         if (s < 30)
             return titles.first() + ": " + subtitles.first();
     }
@@ -224,16 +227,20 @@ QString crJson::_bibtex_booktitle(const QStringList& titles)
     if (titles.count() == 0)
         return QString();
     if (titles.count() == 2)
-        return (!titles.at(1).contains(QRegExp("(advances|series|lecture notes|studies in|topics in)", Qt::CaseInsensitive))) ?
-               titles.at(1) : titles.at(0);
+        return (!titles.at(1).contains(
+                    QRegExp("(advances|series|lecture notes|studies in|topics in)", Qt::CaseInsensitive)))
+               ? titles.at(1)
+               : titles.at(0);
     return titles.first();
 }
 
 QString crJson::_bibtex_series(const QStringList& titles)
 {
     if (titles.count() == 2)
-        return (titles.at(1).contains(QRegExp("(advances|series|lecture notes|studies in|topics in)", Qt::CaseInsensitive))) ?
-               titles.at(1) : titles.at(0);
+        return (titles.at(1).contains(
+                    QRegExp("(advances|series|lecture notes|studies in|topics in)", Qt::CaseInsensitive)))
+               ? titles.at(1)
+               : titles.at(0);
     return QString();
 }
 
