@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "document.h"
@@ -55,7 +55,7 @@ QString document::toString()
     if (!converter.waitForStarted())
     {
         _error_string += QObject::tr("Converter '%1 %2' could not be started. Check file permissions and path\n")
-                         .arg(_converter_bin).arg(_converter_arg);
+                         .arg(_converter_bin, _converter_arg);
         return QString();
     }
     if (!converter.waitForFinished(_conversion_mode == Complete ? -1 : 150000))
@@ -68,8 +68,8 @@ QString document::toString()
     _log_string += '\n' + QString::fromUtf8(converter.readAllStandardError().trimmed());
     if (converter.exitStatus() != QProcess::NormalExit || doc.isEmpty())
     {
-        _error_string += QObject::tr("[%1 %2] Conversion failed for file %3\n")
-                         .arg(_converter_bin).arg(_converter_arg).arg(_document_fn);
+        _error_string +=
+            QObject::tr("[%1 %2] Conversion failed for file %3\n").arg(_converter_bin, _converter_arg, _document_fn);
         c2bUtils::warn(QObject::tr("Warning: Text conversion for file '%1' is empty").arg(_document_fn));
         return QString();
     }
@@ -185,16 +185,8 @@ QString& document::normalize(QString& doc, const Conversion mode)
             uc = 43;
         else if (uc == 1002 || uc == 1003)
             uc = 45;
-        else if (uc == 306 ||
-                 uc == 307 ||
-                 uc == 455 ||
-                 uc == 460 ||
-                 uc == 498 ||
-                 uc == 64256 ||
-                 uc == 64257 ||
-                 uc == 64258 ||
-                 uc == 64259 ||
-                 uc == 64260)
+        else if (uc == 306 || uc == 307 || uc == 455 || uc == 460 || uc == 498 || uc == 64256 || uc == 64257 ||
+                 uc == 64258 || uc == 64259 || uc == 64260)
             hligatures = true;
     }
 
@@ -217,10 +209,8 @@ QString& document::normalize(QString& doc, const Conversion mode)
                 const QChar r(*(c - 1));
                 const QChar s(*(c + 2));
                 if (r.isLetter())
-                    if ((r.isUpper() && s.isLetter()) ||
-                        s.category() == QChar::Punctuation_Dash ||
-                        s.category() == QChar::Punctuation_Other ||
-                        s.isSpace())
+                    if ((r.isUpper() && s.isLetter()) || s.category() == QChar::Punctuation_Dash ||
+                        s.category() == QChar::Punctuation_Other || s.isSpace())
                         *(c + 1) = unull;
             }
             ++c;
