@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef DOCUMENT_H
@@ -16,7 +16,11 @@ class document
 {
 
 public:
-    enum Conversion {FirstPage, Complete};
+    enum Conversion
+    {
+        FirstPage,
+        Complete
+    };
 
     document(const QString& fn, const Conversion mode);
     inline ~document() {}
@@ -45,7 +49,6 @@ private:
     QString _error_string;
     QString _log_string;
     void setConverter(const QString& bin, const QString& args);
-
 };
 
 #endif
