@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "documentCache.h"
@@ -14,12 +14,8 @@
 #include <QDataStream>
 
 
-documentCache::documentCache() :
-    _current(_cache),
-    _content_type(documentContents::Complete),
-    _cache_load_size(0),
-    _settingsP(settings::instance())
-{}
+documentCache::documentCache()
+    : _current(_cache), _content_type(documentContents::Complete), _cache_load_size(0), _settingsP(settings::instance()) {}
 
 documentCache::~documentCache()
 {
@@ -35,11 +31,11 @@ void documentCache::load(const QString& fn, const documentContents::Type type)
     unload();
     _load_filename = fn;
     const QString cache_dir(_settingsP->fileName("cb2Bib/CacheDirectory"));
-    if (QFileInfo(cache_dir).exists() && QFileInfo(cache_dir).isDir())
+    if (QFileInfo::exists(cache_dir) && QFileInfo(cache_dir).isDir())
         _cache_filename = QDir::cleanPath(cache_dir + '/' + QFileInfo(_load_filename).fileName() + ".c2b");
     else
         _cache_filename = _load_filename.trimmed() + ".c2b";
-    if (QFileInfo(_cache_filename).exists())
+    if (QFileInfo::exists(_cache_filename))
     {
         QFile file(_cache_filename);
         if (file.open(QIODevice::ReadOnly))
