@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef DOCUMENTCONTENTS_H
@@ -17,7 +17,11 @@ class documentContents
 {
 
 public:
-    enum Type {Simplified, Complete};
+    enum Type
+    {
+        Simplified,
+        Complete
+    };
 
     inline const QString& signature() const
     {
@@ -34,7 +38,8 @@ public:
         if (!_is_text_loaded)
         {
             if (_type == Simplified)
-                _text = c2bUtils::toAscii(c2bUtils::fromUtf8(c2bUtils::uncompress(_cache.value(_text_key))), c2bUtils::KeepWords);
+                _text = c2bUtils::toAscii(c2bUtils::fromUtf8(c2bUtils::uncompress(_cache.value(_text_key))),
+                                          c2bUtils::KeepWords);
             else
                 _text = c2bUtils::fromUtf8(c2bUtils::uncompress(_cache.value(_text_key)));
             _is_text_loaded = true;
@@ -44,7 +49,8 @@ public:
 
 
 private:
-    inline explicit documentContents(const QHash<QString, QByteArray>& cache) : _cache(cache) {}
+    inline explicit documentContents(const QHash<QString, QByteArray>& cache)
+        : _type(Complete), _cache(cache), _is_signature_loaded(false), _is_text_loaded(false) {}
     inline ~documentContents() {}
 
 
@@ -76,7 +82,6 @@ private:
     mutable bool _is_text_loaded;
 
     friend class documentCache;
-
 };
 
 #endif
