@@ -1,18 +1,14 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "documentParser.h"
 
-#include "QtDebug"
-documentParser::documentParser(const QString& text, const int maximum) :
-    _space(QChar(' ')),
-    _text(text),
-    _maximum_words(maximum),
-    _minimum_words(2),
-    _text_length(text.length())
+
+documentParser::documentParser(const QString& text, const int maximum)
+    : _space(QChar(' ')), _text(text), _maximum_words(maximum), _minimum_words(2), _text_length(text.length())
 {
     _current_nwords = 0;
     _current_ssentence_length = 0;
@@ -38,8 +34,7 @@ documentParser::documentParser(const QString& text, const int maximum) :
         _all_done = true;
 }
 
-documentParser::~documentParser()
-{}
+documentParser::~documentParser() {}
 
 
 bool documentParser::parses()
