@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "heuristicBibParser.h"
@@ -14,24 +14,24 @@
 #include <cmath>
 
 
-heuristicBibParser::heuristicBibParser(bibParser* bp) :
-    _bpP(bp),
-    _current_reference(bp->_current_reference),
-    _reliable_number(false),
-    _reliable_pages(false),
-    _reliable_volume(false),
-    _abstract("abstract"),
-    _addauthors("addauthors"),
-    _author("author"),
-    _isbn("isbn"),
-    _keywords("keywords"),
-    _number("number"),
-    _pages("pages"),
-    _title("title"),
-    _volume("volume"),
-    _year("year"),
-    _bibliographic_fields(bp->_bibliographic_fields),
-    _journal_db(*bp->_journal_dbP)
+heuristicBibParser::heuristicBibParser(bibParser* bp)
+    : _bpP(bp),
+      _current_reference(bp->_current_reference),
+      _reliable_number(false),
+      _reliable_pages(false),
+      _reliable_volume(false),
+      _abstract("abstract"),
+      _addauthors("addauthors"),
+      _author("author"),
+      _isbn("isbn"),
+      _keywords("keywords"),
+      _number("number"),
+      _pages("pages"),
+      _title("title"),
+      _volume("volume"),
+      _year("year"),
+      _bibliographic_fields(bp->_bibliographic_fields),
+      _journal_db(*bp->_journal_dbP)
 {
     _leading_non_letters = QRegExp("^[^<\\w]+");
     // Char 65533 appears many times in pdftotext outputs on windows (seems an encoding error, though)
@@ -44,15 +44,16 @@ heuristicBibParser::heuristicBibParser(bibParser* bp) :
     // Implementation of author field extraction
     // P. Constans. A Simple Extraction Procedure for Bibliographical Author Field.
     // arXiv:0902.0755, 2009.
-    _word_prefix_lexicon = c2bUtils::fileToString(":/txt/txt/word_prefix_lexicon.txt").split(c2bUtils::nonLetter,
-                           QString::SkipEmptyParts);
+    _word_prefix_lexicon =
+        c2bUtils::fileToString(":/txt/txt/word_prefix_lexicon.txt").split(c2bUtils::nonLetter, QString::SkipEmptyParts);
     for (int i = 0; i < _word_prefix_lexicon.count(); ++i)
     {
         _word_prefix_lexicon[i].replace('_', ' ');
         _word_prefix_lexicon[i].squeeze();
     }
     const QString author_lc_t("(?:n%1n|n%1%1n|%1n|%1nn|%1%1n|%1%1%1n|n%1nn|nn%1n|%1%1nn|%1n%1n|nn|nnn)");
-    const QString author_uc_t("(?:[nN]%1N|[nN]%1%1N|%1N|%1[nN]N|%1%1N|%1%1%1N|[nN]%1[nN]N|[nN]N%1N|%1%1[nN]N|%1[nN]%1N|[nN]N|[nN][nN]N)");
+    const QString author_uc_t(
+        "(?:[nN]%1N|[nN]%1%1N|%1N|%1[nN]N|%1%1N|%1%1%1N|[nN]%1[nN]N|[nN]N%1N|%1%1[nN]N|%1[nN]%1N|[nN]N|[nN][nN]N)");
     const QString author_initial("Ip{0,1}");
     const QString author_line("L%1(?:[,;&L]+%1)*(?=L)");
     const QString author_lc(author_line.arg(author_lc_t.arg(author_initial)));
@@ -61,10 +62,10 @@ heuristicBibParser::heuristicBibParser(bibParser* bp) :
 
     _author_sb = QRegExp(QString("L%1(?:[,;&]+L{0,2}%1)*[,;&L]*L").arg(author_lc_t.arg(author_initial)),
                          Qt::CaseInsensitive, QRegExp::RegExp);
-    _author_sb_lc = QRegExp(QString("L%1(?:[,;&L]+%1)*(?=L)").arg(author_lc_t.arg(author_initial)),
-                            Qt::CaseSensitive, QRegExp::RegExp);
-    _author_sb_uc = QRegExp(QString("L%1(?:[,;&L]+%1)*(?=L)").arg(author_uc_t.arg(author_initial)),
-                            Qt::CaseSensitive, QRegExp::RegExp);
+    _author_sb_lc = QRegExp(QString("L%1(?:[,;&L]+%1)*(?=L)").arg(author_lc_t.arg(author_initial)), Qt::CaseSensitive,
+                            QRegExp::RegExp);
+    _author_sb_uc = QRegExp(QString("L%1(?:[,;&L]+%1)*(?=L)").arg(author_uc_t.arg(author_initial)), Qt::CaseSensitive,
+                            QRegExp::RegExp);
     _author_sb.setMinimal(false);
     _author_sb_lc.setMinimal(false);
     _author_sb_uc.setMinimal(false);
@@ -72,22 +73,24 @@ heuristicBibParser::heuristicBibParser(bibParser* bp) :
     // If not, in cases as 'LnnL ... Lnn,nn,Lnn,&nnL' it will overextend addresses to include Lnn,nn,L.
     // This is not related to minimal/greedy.
     // Note also that Lnn,nn,L will not be taken, unless it is followed by another author line. This is a feature.
-    _author_b2_lc_rx = new QRegExp(QString("(%1)%2{0,7}(%1)").arg(author_lc).arg(author_address),
+    _author_b2_lc_rx =
+        new QRegExp(QString("(%1)%2{0,7}(%1)").arg(author_lc, author_address), Qt::CaseSensitive, QRegExp::RegExp);
+    _author_b2_uc_rx =
+        new QRegExp(QString("(%1)%2{0,7}(%1)").arg(author_uc, author_address), Qt::CaseSensitive, QRegExp::RegExp);
+    _author_b3_lc_rx = new QRegExp(QString("(%1)%2{0,7}(%1)%2{0,7}(%1)").arg(author_lc, author_address),
                                    Qt::CaseSensitive, QRegExp::RegExp);
-    _author_b2_uc_rx = new QRegExp(QString("(%1)%2{0,7}(%1)").arg(author_uc).arg(author_address),
+    _author_b3_uc_rx = new QRegExp(QString("(%1)%2{0,7}(%1)%2{0,7}(%1)").arg(author_uc, author_address),
                                    Qt::CaseSensitive, QRegExp::RegExp);
-    _author_b3_lc_rx = new QRegExp(QString("(%1)%2{0,7}(%1)%2{0,7}(%1)").arg(author_lc).arg(author_address),
+    _author_b4_lc_rx = new QRegExp(QString("(%1)%2{0,7}(%1)%2{0,7}(%1)%2{0,7}(%1)").arg(author_lc, author_address),
                                    Qt::CaseSensitive, QRegExp::RegExp);
-    _author_b3_uc_rx = new QRegExp(QString("(%1)%2{0,7}(%1)%2{0,7}(%1)").arg(author_uc).arg(author_address),
-                                   Qt::CaseSensitive, QRegExp::RegExp);
-    _author_b4_lc_rx = new QRegExp(QString("(%1)%2{0,7}(%1)%2{0,7}(%1)%2{0,7}(%1)").arg(author_lc).arg(author_address),
-                                   Qt::CaseSensitive, QRegExp::RegExp);
-    _author_b4_uc_rx = new QRegExp(QString("(%1)%2{0,7}(%1)%2{0,7}(%1)%2{0,7}(%1)").arg(author_uc).arg(author_address),
-                                   Qt::CaseSensitive, QRegExp::RegExp);
-    _author_b5_lc_rx = new QRegExp(QString("(%1)%2{0,7}(%1)%2{0,7}(%1)%2{0,7}(%1)%2{0,7}(%1)").arg(author_lc).arg(author_address),
-                                   Qt::CaseSensitive, QRegExp::RegExp);
-    _author_b5_uc_rx = new QRegExp(QString("(%1)%2{0,7}(%1)%2{0,7}(%1)%2{0,7}(%1)%2{0,7}(%1)").arg(author_uc).arg(author_address),
+    _author_b4_uc_rx = new QRegExp(QString("(%1)%2{0,7}(%1)%2{0,7}(%1)%2{0,7}(%1)").arg(author_uc, author_address),
                                    Qt::CaseSensitive, QRegExp::RegExp);
+    _author_b5_lc_rx =
+        new QRegExp(QString("(%1)%2{0,7}(%1)%2{0,7}(%1)%2{0,7}(%1)%2{0,7}(%1)").arg(author_lc, author_address),
+                    Qt::CaseSensitive, QRegExp::RegExp);
+    _author_b5_uc_rx =
+        new QRegExp(QString("(%1)%2{0,7}(%1)%2{0,7}(%1)%2{0,7}(%1)%2{0,7}(%1)").arg(author_uc, author_address),
+                    Qt::CaseSensitive, QRegExp::RegExp);
     _author_b2_lc_rx->setMinimal(true);
     _author_b2_uc_rx->setMinimal(true);
     _author_b3_lc_rx->setMinimal(true);
@@ -184,7 +187,8 @@ void heuristicBibParser::guessAbstract(const QString& text)
     if (text.contains("Abstract", Qt::CaseInsensitive))
     {
         const QString crl(QChar(169)); // Avoid abstract overextending to copyright line.
-        QRegExp rxH("(?:<NewLine\\d+>|<Tab\\d+>)\\s*Abstract[\\s\\.:]*<NewLine\\d+>(.+)(?:" + crl + "|<NewLine|$)", Qt::CaseInsensitive);
+        QRegExp rxH("(?:<NewLine\\d+>|<Tab\\d+>)\\s*Abstract[\\s\\.:]*<NewLine\\d+>(.+)(?:" + crl + "|<NewLine|$)",
+                    Qt::CaseInsensitive);
         rxH.setMinimal(true);
         int nH(rxH.indexIn(text));
         if (nH > -1)
@@ -194,7 +198,8 @@ void heuristicBibParser::guessAbstract(const QString& text)
                 _current_reference[_abstract] = _bpP->parse(_abstract, val);
                 return;
             }
-        rxH = QRegExp("(?:<NewLine\\d+>|<Tab\\d+>)\\s*Abstract[\\s\\.:]*<NewLine\\d+>(.+)(?:" + crl + "|<NewLine\\d+>\\s*<NewLine|$)",
+        rxH = QRegExp("(?:<NewLine\\d+>|<Tab\\d+>)\\s*Abstract[\\s\\.:]*<NewLine\\d+>(.+)(?:" + crl +
+                      "|<NewLine\\d+>\\s*<NewLine|$)",
                       Qt::CaseInsensitive);
         rxH.setMinimal(true);
         nH = rxH.indexIn(text);
@@ -214,7 +219,8 @@ void heuristicBibParser::guessAbstract(const QString& text)
                 _current_reference[_abstract] = _bpP->parse(_abstract, val);
                 return;
             }
-        rxH = QRegExp("(?:<NewLine\\d+>|<Tab\\d+>)\\s*Abstract\\b(.+)(?:" + crl + "|<NewLine\\d+>\\s*<NewLine|$)", Qt::CaseInsensitive);
+        rxH = QRegExp("(?:<NewLine\\d+>|<Tab\\d+>)\\s*Abstract\\b(.+)(?:" + crl + "|<NewLine\\d+>\\s*<NewLine|$)",
+                      Qt::CaseInsensitive);
         rxH.setMinimal(true);
         nH = rxH.indexIn(text);
         if (nH > -1)
@@ -226,7 +232,8 @@ void heuristicBibParser::guessAbstract(const QString& text)
     }
     if (text.contains("Summary", Qt::CaseInsensitive))
     {
-        QRegExp rxH("(?:<NewLine\\d+>|<Tab\\d+>)\\s*Summary[\\s\\.:]*<NewLine\\d+>(.+)(?:<NewLine|$)", Qt::CaseInsensitive);
+        QRegExp rxH("(?:<NewLine\\d+>|<Tab\\d+>)\\s*Summary[\\s\\.:]*<NewLine\\d+>(.+)(?:<NewLine|$)",
+                    Qt::CaseInsensitive);
         rxH.setMinimal(true);
         int nH(rxH.indexIn(text));
         if (nH > -1)
@@ -236,8 +243,9 @@ void heuristicBibParser::guessAbstract(const QString& text)
                 _current_reference[_abstract] = _bpP->parse(_abstract, val);
                 return;
             }
-        rxH = QRegExp("(?:<NewLine\\d+>|<Tab\\d+>)\\s*Summary[\\s\\.:]*<NewLine\\d+>(.+)(?:<NewLine\\d+>\\s*<NewLine|$)",
-                      Qt::CaseInsensitive);
+        rxH =
+            QRegExp("(?:<NewLine\\d+>|<Tab\\d+>)\\s*Summary[\\s\\.:]*<NewLine\\d+>(.+)(?:<NewLine\\d+>\\s*<NewLine|$)",
+                    Qt::CaseInsensitive);
         rxH.setMinimal(true);
         nH = rxH.indexIn(text);
         if (nH > -1)
@@ -256,7 +264,8 @@ void heuristicBibParser::guessAbstract(const QString& text)
                 _current_reference[_abstract] = _bpP->parse(_abstract, val);
                 return;
             }
-        rxH = QRegExp("(?:<NewLine\\d+>|<Tab\\d+>)\\s*Summary\\b(.+)(?:<NewLine\\d+>\\s*<NewLine|$)", Qt::CaseInsensitive);
+        rxH =
+            QRegExp("(?:<NewLine\\d+>|<Tab\\d+>)\\s*Summary\\b(.+)(?:<NewLine\\d+>\\s*<NewLine|$)", Qt::CaseInsensitive);
         rxH.setMinimal(true);
         nH = rxH.indexIn(text);
         if (nH > -1)
@@ -290,13 +299,15 @@ void heuristicBibParser::guessAuthor(const QString& tagged_text)
     simplified_text.replace(QRegExp("<Tab\\d+>"), " ");
 
     simplified_text.remove(QRegExp("author.{0,3}:{0,1}", Qt::CaseInsensitive));
-    simplified_text.replace(QRegExp("(\\w{4,10})[a-z]\\)", Qt::CaseSensitive), "\\1 "); // Remove superscript, e. g. LASTNAMEa
-    simplified_text.replace(QRegExp("([A-Z]{2,10})[a-z]\\b", Qt::CaseSensitive), "\\1 ");  // Remove superscript, e. g. LASTNAMEa)
+    simplified_text.replace(QRegExp("(\\w{4,10})[a-z]\\)", Qt::CaseSensitive),
+                            "\\1 "); // Remove superscript, e. g. LASTNAMEa
+    simplified_text.replace(QRegExp("([A-Z]{2,10})[a-z]\\b", Qt::CaseSensitive),
+                            "\\1 "); // Remove superscript, e. g. LASTNAMEa)
     simplified_text.replace(_hyphens, "-");
-    simplified_text.replace(QChar(183), ','); // Fancy author separator
+    simplified_text.replace(QChar(183), ',');               // Fancy author separator
     simplified_text.replace(' ' + QChar(198) + ' ', " , "); // Fancy author separator
-    simplified_text.replace(QChar(8226), ','); // Fancy author separator
-    simplified_text.replace(QChar(178), ' '); // Superscript dagger as sometimes translated by pdftotext
+    simplified_text.replace(QChar(8226), ',');              // Fancy author separator
+    simplified_text.replace(QChar(178), ' ');               // Superscript dagger as sometimes translated by pdftotext
     author::simplifyString(simplified_text);
 
     // Capitalize and encode
@@ -336,36 +347,36 @@ QString heuristicBibParser::guessAuthor_multi_block()
     QString author;
     if (_author_b5_uc_rx->indexIn(_aencoder.code) > -1)
         for (int i = 1; i < _author_b5_uc_rx->capturedTexts().count(); ++i)
-            author = _bpP->parse(_addauthors, _aencoder.decoded(_author_b5_uc_rx->pos(i), _author_b5_uc_rx->cap(i).length()),
-                                 author);
+            author = _bpP->parse(
+                         _addauthors, _aencoder.decoded(_author_b5_uc_rx->pos(i), _author_b5_uc_rx->cap(i).length()), author);
     else if (_author_b5_lc_rx->indexIn(_aencoder.code) > -1)
         for (int i = 1; i < _author_b5_lc_rx->capturedTexts().count(); ++i)
-            author = _bpP->parse(_addauthors, _aencoder.decoded(_author_b5_lc_rx->pos(i), _author_b5_lc_rx->cap(i).length()),
-                                 author);
+            author = _bpP->parse(
+                         _addauthors, _aencoder.decoded(_author_b5_lc_rx->pos(i), _author_b5_lc_rx->cap(i).length()), author);
     else if (_author_b4_uc_rx->indexIn(_aencoder.code) > -1)
         for (int i = 1; i < _author_b4_uc_rx->capturedTexts().count(); ++i)
-            author = _bpP->parse(_addauthors, _aencoder.decoded(_author_b4_uc_rx->pos(i), _author_b4_uc_rx->cap(i).length()),
-                                 author);
+            author = _bpP->parse(
+                         _addauthors, _aencoder.decoded(_author_b4_uc_rx->pos(i), _author_b4_uc_rx->cap(i).length()), author);
     else if (_author_b4_lc_rx->indexIn(_aencoder.code) > -1)
         for (int i = 1; i < _author_b4_lc_rx->capturedTexts().count(); ++i)
-            author = _bpP->parse(_addauthors, _aencoder.decoded(_author_b4_lc_rx->pos(i), _author_b4_lc_rx->cap(i).length()),
-                                 author);
+            author = _bpP->parse(
+                         _addauthors, _aencoder.decoded(_author_b4_lc_rx->pos(i), _author_b4_lc_rx->cap(i).length()), author);
     else if (_author_b3_uc_rx->indexIn(_aencoder.code) > -1)
         for (int i = 1; i < _author_b3_uc_rx->capturedTexts().count(); ++i)
-            author = _bpP->parse(_addauthors, _aencoder.decoded(_author_b3_uc_rx->pos(i), _author_b3_uc_rx->cap(i).length()),
-                                 author);
+            author = _bpP->parse(
+                         _addauthors, _aencoder.decoded(_author_b3_uc_rx->pos(i), _author_b3_uc_rx->cap(i).length()), author);
     else if (_author_b3_lc_rx->indexIn(_aencoder.code) > -1)
         for (int i = 1; i < _author_b3_lc_rx->capturedTexts().count(); ++i)
-            author = _bpP->parse(_addauthors, _aencoder.decoded(_author_b3_lc_rx->pos(i), _author_b3_lc_rx->cap(i).length()),
-                                 author);
+            author = _bpP->parse(
+                         _addauthors, _aencoder.decoded(_author_b3_lc_rx->pos(i), _author_b3_lc_rx->cap(i).length()), author);
     else if (_author_b2_uc_rx->indexIn(_aencoder.code) > -1)
         for (int i = 1; i < _author_b2_uc_rx->capturedTexts().count(); ++i)
-            author = _bpP->parse(_addauthors, _aencoder.decoded(_author_b2_uc_rx->pos(i), _author_b2_uc_rx->cap(i).length()),
-                                 author);
+            author = _bpP->parse(
+                         _addauthors, _aencoder.decoded(_author_b2_uc_rx->pos(i), _author_b2_uc_rx->cap(i).length()), author);
     else if (_author_b2_lc_rx->indexIn(_aencoder.code) > -1)
         for (int i = 1; i < _author_b2_lc_rx->capturedTexts().count(); ++i)
-            author = _bpP->parse(_addauthors, _aencoder.decoded(_author_b2_lc_rx->pos(i), _author_b2_lc_rx->cap(i).length()),
-                                 author);
+            author = _bpP->parse(
+                         _addauthors, _aencoder.decoded(_author_b2_lc_rx->pos(i), _author_b2_lc_rx->cap(i).length()), author);
     return author;
 }
 
@@ -384,7 +395,8 @@ int heuristicBibParser::authorCount(const QString& authors)
 */
 void heuristicBibParser::guessKeywords(const QString& text)
 {
-    QRegExp rxH("<(?:NewLine|Tab)\\d+>\\s*Key\\s{0,1}words and phrases[\\s\\.:]*<NewLine\\d+>(.+)(<NewLine|$)", Qt::CaseInsensitive);
+    QRegExp rxH("<(?:NewLine|Tab)\\d+>\\s*Key\\s{0,1}words and phrases[\\s\\.:]*<NewLine\\d+>(.+)(<NewLine|$)",
+                Qt::CaseInsensitive);
     rxH.setMinimal(true);
     int nH(rxH.indexIn(text));
     if (nH > -1)
@@ -402,7 +414,8 @@ void heuristicBibParser::guessKeywords(const QString& text)
         _current_reference[_keywords] = _bpP->parse(_keywords, val);
     }
 
-    rxH = QRegExp("<(?:NewLine|Tab)\\d+>\\s*Key\\s{0,1}words[\\s\\.:]*<NewLine\\d+>(.+)(<NewLine|$)", Qt::CaseInsensitive);
+    rxH =
+        QRegExp("<(?:NewLine|Tab)\\d+>\\s*Key\\s{0,1}words[\\s\\.:]*<NewLine\\d+>(.+)(<NewLine|$)", Qt::CaseInsensitive);
     rxH.setMinimal(true);
     nH = rxH.indexIn(text);
     if (nH > -1)
@@ -588,7 +601,7 @@ void heuristicBibParser::guessPages(const QString& text)
         {
             if (!rxH.cap(1).startsWith('0'))
             {
-                const QString pp(_bpP->parse(_pages, QString("%1 %2").arg(rxH.cap(1)).arg(rxH.cap(2))));
+                const QString pp(_bpP->parse(_pages, QString("%1 %2").arg(rxH.cap(1), rxH.cap(2))));
                 const QStringList flpp(pp.split(QRegExp("\\D"), QString::SkipEmptyParts));
                 if (flpp.count() != 2)
                     continue;
@@ -600,7 +613,7 @@ void heuristicBibParser::guessPages(const QString& text)
                     return;
                 }
             }
-            nH  += rxH.matchedLength();
+            nH += rxH.matchedLength();
         }
     }
 }
@@ -786,7 +799,8 @@ void heuristicBibParser::guessVolumePagesYear(const QString& text)
         return;
     }
     // J. Sci., 108 (15), 3206 (2004)
-    rxH = QRegExp("(\\d+)\\s*\\((" + _hyphen_nums + ")\\)\\s*[,:]\\s*(" + _hyphen_pages + ")[,\\s]*\\((19|20)(\\d\\d)\\)");
+    rxH =
+        QRegExp("(\\d+)\\s*\\((" + _hyphen_nums + ")\\)\\s*[,:]\\s*(" + _hyphen_pages + ")[,\\s]*\\((19|20)(\\d\\d)\\)");
     nH = rxH.indexIn(text);
     if (nH > -1)
     {
@@ -845,7 +859,8 @@ void heuristicBibParser::guessYearVolumePages(const QString& text)
         return;
     // J. Sci. 1995 January 25; 247(4):536-40.
     // J. Sci. 1995, 247(4):536-40.
-    QRegExp rxH(_current_reference.value(_year) + "[\\w ]{0,15}[,:; ]\\s*(\\d+)\\s*\\((" + _hyphen_nums + ")\\)\\s*[,:;]\\s*(" + _hyphen_pages + ')');
+    QRegExp rxH(_current_reference.value(_year) + "[\\w ]{0,15}[,:; ]\\s*(\\d+)\\s*\\((" + _hyphen_nums +
+                ")\\)\\s*[,:;]\\s*(" + _hyphen_pages + ')');
     int nH(rxH.indexIn(text));
     if (nH > -1)
     {
@@ -857,8 +872,8 @@ void heuristicBibParser::guessYearVolumePages(const QString& text)
         return;
     }
     // J. Sci. (1999), 86, 3, pp. 635-648
-    rxH = QRegExp("\\(" + _current_reference.value(_year) + "\\)" + "\\s*[,:;]\\s*(\\d+)\\s*[,:;]\\s*(" +
-                  _hyphen_nums + ")\\s*[,:;]\\s*(?:pp)?\\.?\\s*(" + _hyphen_pages + ')');
+    rxH = QRegExp("\\(" + _current_reference.value(_year) + "\\)" + "\\s*[,:;]\\s*(\\d+)\\s*[,:;]\\s*(" + _hyphen_nums +
+                  ")\\s*[,:;]\\s*(?:pp)?\\.?\\s*(" + _hyphen_pages + ')');
     nH = rxH.indexIn(text);
     if (nH > -1)
     {
@@ -874,7 +889,8 @@ void heuristicBibParser::guessYearVolumePages(const QString& text)
     // J. Sci. 1995 January 25; 247:536-40.
     // J. Sci. 2005, 103, 818
     // J. Sci. 2002;9:101–106.5.
-    rxH = QRegExp(_current_reference.value(_year) + "\\s*[\\w ]{0,15}[,:;]\\s*(\\d+)\\s*[,:;]\\s*(" + _hyphen_pages + ')');
+    rxH =
+        QRegExp(_current_reference.value(_year) + "\\s*[\\w ]{0,15}[,:;]\\s*(\\d+)\\s*[,:;]\\s*(" + _hyphen_pages + ')');
     nH = rxH.indexIn(text);
     if (nH > -1)
     {
