@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef HEURISTICBIBPARSER_H
@@ -96,12 +96,12 @@ private:
         for (int i = 0; i < _bibliographic_fields.count(); ++i)
         {
             if (!_current_reference.value(_bibliographic_fields.at(i)).isEmpty())
-                qDebug() << QString("    %1:  '%2'").arg(_bibliographic_fields.at(i))
+                qDebug() << QString("    %1:  '%2'")
+                         .arg(_bibliographic_fields.at(i))
                          .arg(_current_reference.value(_bibliographic_fields.at(i)));
         }
 #endif
     }
-
 };
 
 #endif
