@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "journalDB.h"
@@ -274,8 +274,8 @@ QString journalDB::retrieveAlternateFull(const QString& JQuery) const
         }
     if (journal_found == 1)
     {
-        if (journal_found_at + 2 < _nitems &&
-            JCode.at(journal_found_at + 1).isEmpty() && JCode.at(journal_found_at + 2).isEmpty())
+        if (journal_found_at + 2 < _nitems && JCode.at(journal_found_at + 1).isEmpty() &&
+            JCode.at(journal_found_at + 2).isEmpty())
             return JExtended.at(journal_found_at + 2);
         else if (journal_found_at + 1 < _nitems && JCode.at(journal_found_at + 1).isEmpty())
             return JExtended.at(journal_found_at + 1);
