@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "metadataParser.h"
@@ -151,12 +151,12 @@ const QString metadataParser::metadata(const QString& fn)
     {
         const QStringList& bibliographicFields(_cbpP->bibliographicFields());
         if (_ref.contains("type"))
-            data += QString("<%1>%2</%1>\n").arg("type").arg(_ref.value("type"));
+            data += QString("<type>%1</type>\n").arg(_ref.value("type"));
         for (int i = 0; i < bibliographicFields.count(); ++i)
         {
             const QString key(bibliographicFields.at(i));
             if (_ref.contains(key))
-                data += QString("<%1>%2</%1>\n").arg(key).arg(_ref.value(key));
+                data += QString("<%1>%2</%1>\n").arg(key, _ref.value(key));
         }
     }
     data = QString("[Bibliographic Metadata\n%1/Bibliographic Metadata]\n").arg(data);
@@ -431,7 +431,7 @@ void metadataParser::_fuzzyParser(const QString& data)
         c2bUtils::debug(tr("metadataParser: Error while parsing XML packets"));
 }
 
-bool metadataParser::insertMetadata(const bibReference& ref, const QString& fn, QString* error) const
+bool metadataParser::insertMetadata(const bibReference& ref, const QString& fn, QString* error)
 {
     if (error)
         error->clear();
@@ -441,8 +441,7 @@ bool metadataParser::insertMetadata(const bibReference& ref, const QString& fn,
         if (error)
             *error = tr("Metadata writer: ExifTool location has not been specified.");
         else
-            emit showMessage(tr("Warning - cb2Bib"),
-                             tr("Metadata writer: ExifTool location has not been specified."));
+            emit showMessage(tr("Warning - cb2Bib"), tr("Metadata writer: ExifTool location has not been specified."));
         return false;
     }
     if (ref.count() == 0)
@@ -451,8 +450,8 @@ bool metadataParser::insertMetadata(const bibReference& ref, const QString& fn,
     QString bibtags;
     QString key;
     QString value;
-    QString entry("<bibtex:%1>%2</bibtex:%1>\n");
-    bibtags += entry.arg("type").arg(ref.typeName);
+    const QString entry("<bibtex:%1>%2</bibtex:%1>\n");
+    bibtags += entry.arg("type", ref.typeName);
     const QStringList& bibliographicFields = _cbpP->bibliographicFields();
     for (int i = 0; i < bibliographicFields.count(); ++i)
     {
@@ -467,7 +466,7 @@ bool metadataParser::insertMetadata(const bibReference& ref, const QString& fn,
         c2bUtils::fullBibToC2b(value);
         if (key == "title" || key == "booktitle")
             c2bUtils::cleanTitle(value);
-        bibtags += entry.arg(key).arg(value);
+        bibtags += entry.arg(key, value);
     }
     QString bibtags_xmp(c2bUtils::fileToString(":/xml/xml/cb2bib.xmp"));
     bibtags_xmp.replace("GET_BIBTEX_TAGS", bibtags);
@@ -498,15 +497,18 @@ bool metadataParser::insertMetadata(const bibReference& ref, const QString& fn,
     if (!exiftool.waitForStarted())
     {
         if (error)
-            *error = tr("Metadata writer: '%1' could not be started. Check file permissions and path.").arg(exiftool_bin);
+            *error =
+                tr("Metadata writer: '%1' could not be started. Check file permissions and path.").arg(exiftool_bin);
         else
-            emit showMessage(tr("Warning - cb2Bib"),
-                             tr("Metadata writer: '%1' could not be started. Check file permissions and path.").arg(exiftool_bin));
+            emit showMessage(
+                tr("Warning - cb2Bib"),
+                tr("Metadata writer: '%1' could not be started. Check file permissions and path.").arg(exiftool_bin));
     }
     if (!exiftool.waitForFinished(90000))
         exiftool.kill();
     const QString exiftool_error(exiftool.readAllStandardError().trimmed());
-    const bool inserted(exiftool.error() == QProcess::UnknownError && exiftool.exitCode() == 0 && exiftool_error.isEmpty());
+    const bool inserted(exiftool.error() == QProcess::UnknownError && exiftool.exitCode() == 0 &&
+                        exiftool_error.isEmpty());
     if (!inserted && error)
         if (!exiftool_error.isEmpty())
             *error = exiftool_error;
