@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef METADATAPARSER_H
@@ -25,13 +25,13 @@ public:
     metadataParser(coreBibParser* cbp, QObject* parento = 0);
     inline ~metadataParser() {}
 
-    bool insertMetadata(const bibReference& ref, const QString& fn, QString* error = 0) const;
+    bool insertMetadata(const bibReference& ref, const QString& fn, QString* error = 0);
     bool metadata(const QString& fn, bibReference* ref);
     const QString metadata(const QString& fn);
 
 
 signals:
-    void showMessage(const QString& title, const QString& ms) const;
+    void showMessage(const QString& title, const QString& ms);
 
 
 private:
@@ -64,7 +64,6 @@ private:
         formatted += ", and " + alist.last();
         return formatted;
     }
-
 };
 
 #endif
