@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "monthDB.h"
@@ -9,12 +9,12 @@
 #include "settings.h"
 
 
-monthDB::monthDB() :
-    _day_rx(QRegExp("(\\d+)")),
-    _month_rx(QRegExp("([A-Za-z]+)")),
-    _month_abbreviated(QString("jan|feb|mar|apr|may|jun|jul|aug|sep|oct|nov|dec").split('|')),
-    _month_full(QString("January|February|March|April|May|June|July|August|September|October|November|December").split('|'))
-{}
+monthDB::monthDB()
+    : _day_rx(QRegExp("(\\d+)")),
+      _month_rx(QRegExp("([A-Za-z]+)")),
+      _month_abbreviated(QString("jan|feb|mar|apr|may|jun|jul|aug|sep|oct|nov|dec").split('|')),
+      _month_full(
+          QString("January|February|March|April|May|June|July|August|September|October|November|December").split('|')) {}
 
 
 QString monthDB::retrieve(const QString& month_query)
@@ -33,7 +33,7 @@ QString monthDB::retrieve(const QString& month_query)
     {
         // Do '1 April' -> '"1~" # apr'
         if (has_day)
-            return QString("\"%1~\" # %2").arg(_day_rx.cap(1)).arg(month_abbreviated);
+            return QString("\"%1~\" # %2").arg(_day_rx.cap(1), month_abbreviated);
         else
             return month_abbreviated;
     }
@@ -41,7 +41,7 @@ QString monthDB::retrieve(const QString& month_query)
     {
         // Capitalize
         if (has_day)
-            return QString("%1 %2").arg(_day_rx.cap(1)).arg(month_full);
+            return QString("%1 %2").arg(_day_rx.cap(1), month_full);
         else
             return month_full;
     }
@@ -52,8 +52,8 @@ QString monthDB::abbreviated(const QString& month) const
     for (int i = 0; i < 12; i++)
         if (QString::compare(month, _month_abbreviated.at(i), Qt::CaseInsensitive) == 0 ||
             QString::compare(month, _month_full.at(i), Qt::CaseInsensitive) == 0)
-            return(_month_abbreviated.at(i));
-    return(month);
+            return _month_abbreviated.at(i);
+    return month;
 }
 
 QString monthDB::full(const QString& month) const
@@ -61,6 +61,6 @@ QString monthDB::full(const QString& month) const
     for (int i = 0; i < 12; i++)
         if (QString::compare(month, _month_abbreviated.at(i), Qt::CaseInsensitive) == 0 ||
             QString::compare(month, _month_full.at(i), Qt::CaseInsensitive) == 0)
-            return(_month_full.at(i));
-    return(month);
+            return _month_full.at(i);
+    return month;
 }
