@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "network.h"
@@ -20,8 +20,8 @@ network::network(QObject* parento) : QObject(parento), _max_redirections(15)
 {
     _is_fetching = false;
     _fetcher = new QNetworkAccessManager(this);
-    connect(_fetcher, SIGNAL(proxyAuthenticationRequired(const QNetworkProxy&, QAuthenticator*)), this,
-            SIGNAL(proxyAuthenticationRequired(const QNetworkProxy&, QAuthenticator*)));
+    connect(_fetcher, SIGNAL(proxyAuthenticationRequired(QNetworkProxy,QAuthenticator*)), this,
+            SIGNAL(proxyAuthenticationRequired(QNetworkProxy,QAuthenticator*)));
     loadSettings();
     connect(settings::instance(), SIGNAL(newSettings()), this, SLOT(loadSettings()));
     // Set predefined cookies
@@ -37,8 +37,8 @@ network::network(QObject* parento) : QObject(parento), _max_redirections(15)
 
 *****************************************************************************/
 
-void network::getFile(const QString& source, const QString& destination, const Action action,
-                      QObject* receiver, const char* callback, const bool overwrite)
+void network::getFile(const QString& source, const QString& destination, const Action action, QObject* receiver,
+                      const char* callback, const bool overwrite)
 {
     if (_is_fetching)
     {
@@ -50,7 +50,7 @@ void network::getFile(const QString& source, const QString& destination, const A
     if (receiver)
         connect(this, SIGNAL(requestFinished(bool)), receiver, callback);
     if (overwrite)
-        if (QFileInfo(destination).exists())
+        if (QFileInfo::exists(destination))
             QFile::remove(destination);
     getFilePrivate(action);
 }
@@ -107,11 +107,11 @@ void network::getFilePrivate(const Action action)
 void network::headFilePrivate()
 {
     const QUrl u(_source_filename, QUrl::TolerantMode);
-    if (u.scheme() == "file" || QFileInfo(_source_filename).exists())
+    if (u.scheme() == "file" || QFileInfo::exists(_source_filename))
     {
         // Local File
         const QString fn(u.scheme() == "file" ? u.toLocalFile() : _source_filename);
-        const bool succeeded(QFileInfo(fn).exists());
+        const bool succeeded(QFileInfo::exists(fn));
         if (!succeeded)
             _request_error_string = tr("File does not exist.");
         _emit_request_finished(succeeded);
@@ -142,7 +142,7 @@ bool network::checkDestination()
 {
     // Checks whether or not writing to destination is safe
     // Returns false if file exists
-    if (QFileInfo(_destination_filename).exists())
+    if (QFileInfo::exists(_destination_filename))
     {
         _request_error_string = tr("Destination file '%1' already exists.").arg(_destination_filename);
         return false;
@@ -189,7 +189,7 @@ void network::_fetch_client(const Action action)
     Action act(action);
     // Only move local files
     QUrl u(_source_filename);
-    if (!(u.scheme() == "file" || QFileInfo(_source_filename).exists()))
+    if (!(u.scheme() == "file" || QFileInfo::exists(_source_filename)))
         if (action == Move)
             act = Copy; // Copy network files
 
@@ -208,7 +208,8 @@ void network::_fetch_client(const Action action)
     arglist.append(_source_filename);
     arglist.append(_destination_filename);
     _fetcher_client = new QProcess(this);
-    connect(_fetcher_client, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(_client_finished(int, QProcess::ExitStatus)));
+    connect(_fetcher_client, SIGNAL(finished(int,QProcess::ExitStatus)), this,
+            SLOT(_client_finished(int,QProcess::ExitStatus)));
     _fetcher_client->start(fmclient_bin, arglist);
     if (!_fetcher_client->waitForStarted())
     {
@@ -225,10 +226,11 @@ void network::_client_finished(int exitCode, QProcess::ExitStatus exitStatus)
         _request_error_string = tr("FM Client crashed.");
     else
     {
-        if (QFileInfo(_destination_filename).exists())
+        if (QFileInfo::exists(_destination_filename))
             succeeded = true;
         else
-            _request_error_string = tr("File '%1' has not been written. Exit code '%2'.").arg(_source_filename).arg(exitCode);
+            _request_error_string =
+                tr("File '%1' has not been written. Exit code '%2'.").arg(_source_filename).arg(exitCode);
     }
     delete _fetcher_client;
     _emit_request_finished(succeeded);
@@ -245,7 +247,11 @@ void network::_head(const QUrl& url)
 {
     QNetworkRequest request;
     request.setUrl(url);
-    request.setRawHeader("User-Agent", QString("cb2Bib/" + C2B_VERSION + " (https://www.molspaces.com/cb2bib/; mailto:cb2bib@molspaces.com; Bibliographic Browser Tool)").toLatin1());
+    request.setRawHeader(
+        "User-Agent",
+        QString("cb2Bib/" + C2B_VERSION +
+                " (https://www.molspaces.com/cb2bib/; mailto:cb2bib@molspaces.com; Bibliographic Browser Tool)")
+        .toLatin1());
     _current_reply = _fetcher->head(request);
     connect(_current_reply, SIGNAL(finished()), SLOT(_head_finished()));
 }
@@ -292,7 +298,7 @@ void network::_fetch_c2b(const Action action, const QNetworkAccessManager::Opera
         url_str = _source_filename;
 
     QUrl u(url_str, QUrl::TolerantMode);
-    if (u.scheme() == "file" || QFileInfo(_source_filename).exists())
+    if (u.scheme() == "file" || QFileInfo::exists(_source_filename))
     {
         // Local File
         QFile source(u.scheme() == "file" ? u.toLocalFile() : _source_filename);
@@ -317,13 +323,18 @@ void network::_fetch(const QUrl& url)
     _destination_file.setFileName(_destination_filename);
     if (!_destination_file.open(QIODevice::WriteOnly))
     {
-        _request_error_string = tr("File '%1' cannot be written. %2").arg(_destination_filename).arg(_destination_file.errorString());
+        _request_error_string =
+            tr("File '%1' cannot be written. %2").arg(_destination_filename, _destination_file.errorString());
         _emit_request_finished(false);
         return;
     }
     QNetworkRequest request;
     request.setUrl(url);
-    request.setRawHeader("User-Agent", QString("cb2Bib/" + C2B_VERSION + " (https://www.molspaces.com/cb2bib/; mailto:cb2bib@molspaces.com; Bibliographic Browser Tool)").toLatin1());
+    request.setRawHeader(
+        "User-Agent",
+        QString("cb2Bib/" + C2B_VERSION +
+                " (https://www.molspaces.com/cb2bib/; mailto:cb2bib@molspaces.com; Bibliographic Browser Tool)")
+        .toLatin1());
     if (_fetch_operation == QNetworkAccessManager::PostOperation)
     {
         request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
@@ -334,7 +345,7 @@ void network::_fetch(const QUrl& url)
     connect(_current_reply, SIGNAL(readyRead()), this, SLOT(_fetch_ready_read()));
     connect(_current_reply, SIGNAL(finished()), SLOT(_fetch_finished()));
     connect(_current_reply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(logError()));
-    connect(_current_reply, SIGNAL(downloadProgress(qint64, qint64)), this, SIGNAL(downloadProgress(qint64, qint64)));
+    connect(_current_reply, SIGNAL(downloadProgress(qint64,qint64)), this, SIGNAL(downloadProgress(qint64,qint64)));
 }
 
 void network::_fetch_finished()
