@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef NETWORK_H
@@ -28,10 +28,14 @@ public:
     explicit network(QObject* parento = 0);
     inline ~network() {}
 
-    enum Action {Copy, Move};
+    enum Action
+    {
+        Copy,
+        Move
+    };
 
-    void getFile(const QString& source, const QString& destination, const Action action = Copy,
-                 QObject* receiver = 0, const char* callback = 0, const bool overwrite = false);
+    void getFile(const QString& source, const QString& destination, const Action action = Copy, QObject* receiver = 0,
+                 const char* callback = 0, const bool overwrite = false);
     void headFile(const QString& source, QObject* receiver = 0, const char* callback = 0);
 
     inline const QString destinationFilename() const
@@ -93,7 +97,8 @@ private:
     int _redirection_count;
     void _emit_request_finished(bool succeeded);
     void _fetch(const QUrl& url);
-    void _fetch_c2b(const Action action, const QNetworkAccessManager::Operation operation = QNetworkAccessManager::GetOperation);
+    void _fetch_c2b(const Action action,
+                    const QNetworkAccessManager::Operation operation = QNetworkAccessManager::GetOperation);
     void _fetch_client(const Action action);
     void _head(const QUrl& url);
     void getFilePrivate(const Action action);
@@ -118,7 +123,6 @@ private slots:
     void _head_finished();
     void loadSettings();
     void logError();
-
 };
 
 #endif
