@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "networkQuery.h"
@@ -122,8 +122,8 @@ void networkQuery::submitQuery1()
         emit statusMessage(tr("Importing: %1.").arg(_targetQ));
     else
         emit statusMessage(tr("Query: %1.").arg(_targetQ));
-    _networkP->getFile(_targetQ, _networkquery_tmp_fn1, network::Copy,
-                       this, SLOT(submitQuery2(bool)), !_settingsP->value("cb2Bib/KeepTmpNQFiles").toBool());
+    _networkP->getFile(_targetQ, _networkquery_tmp_fn1, network::Copy, this, SLOT(submitQuery2(bool)),
+                       !_settingsP->value("cb2Bib/KeepTmpNQFiles").toBool());
 }
 
 void networkQuery::submitQuery2(bool succeeded)
@@ -232,8 +232,8 @@ void networkQuery::submitQuery3(bool succeeded)
         emit statusMessage(tr("Importing: %1.").arg(_targetBib));
     else
         emit statusMessage(tr("Retrieving: %1.").arg(_targetBib));
-    _networkP->getFile(_targetBib, _networkquery_tmp_fn2, network::Copy,
-                       this, SLOT(queryDone(bool)), !_settingsP->value("cb2Bib/KeepTmpNQFiles").toBool());
+    _networkP->getFile(_targetBib, _networkquery_tmp_fn2, network::Copy, this, SLOT(queryDone(bool)),
+                       !_settingsP->value("cb2Bib/KeepTmpNQFiles").toBool());
 }
 
 void networkQuery::queryDone(bool succeeded)
@@ -413,12 +413,14 @@ bool networkQuery::areQueryParametersValid()
             if (!_settingsP->value("networkQuery/isSupervised").toBool())
                 return false;
         }
-        else if (!(_action == "htm2txt_query" || _action == "htm2txt_referenceurl" ||
-                   _action == "merge_all_metadata" || _action == "merge_referenceurl_metadata"))
+        else if (!(_action == "htm2txt_query" || _action == "htm2txt_referenceurl" || _action == "merge_all_metadata" ||
+                   _action == "merge_referenceurl_metadata"))
             return false;
     }
-    const QString allParams(_targetQ + _captionQ + _referenceurl_prefix + _referenceurl_sufix + _pdfurl_prefix + _pdfurl_sufix);
-    return !(allParams.contains(QRegExp("(?:<<title>>|<<journal>>|<<pages>>|<<volume>>|<<doi>>|<<excerpt>>|<<eprint>>)")));
+    const QString allParams(_targetQ + _captionQ + _referenceurl_prefix + _referenceurl_sufix + _pdfurl_prefix +
+                            _pdfurl_sufix);
+    return !(
+               allParams.contains(QRegExp("(?:<<title>>|<<journal>>|<<pages>>|<<volume>>|<<doi>>|<<excerpt>>|<<eprint>>)")));
 }
 
 const QString networkQuery::encodeUrl(const QString& url) const
