@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "pubmedXml.h"
@@ -46,7 +46,7 @@ void pubmedXml::readReference()
         else if (name() == "ArticleId")
         {
             if (attributes().count() > 0)
-                if (attributes().first().value().toString() == "doi")
+                if (attributes().at(0).value().toString() == "doi")
                     readField("doi");
         }
 }
