@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "searchPattern.h"
@@ -24,17 +24,17 @@
 /**
     Top level driver for calling cb2Bib search types
 */
-searchPattern::searchPattern(const QString& pattern, const QString& patternType) :
-    _matcher(pattern.simplified(), typemap().value(patternType), Qt::CaseInsensitive)
+searchPattern::searchPattern(const QString& pattern, const QString& patternType)
+    : _matcher(pattern.simplified(), typemap().value(patternType), Qt::CaseInsensitive)
 {
     _modifier.NOT = false;
     _modifier.string = pattern.simplified();
     _rank = 0;
 }
 
-searchPattern::searchPattern(const bool NOT, const bool caseSensitive, const QString& patternType,
-                             const QString& scope, const QChar& yearScope, const QString& pattern) :
-    _matcher(pattern.simplified(), typemap().value(patternType), qtcase(caseSensitive))
+searchPattern::searchPattern(const bool NOT, const bool caseSensitive, const QString& patternType, const QString& scope,
+                             const QChar& yearScope, const QString& pattern)
+    : _matcher(pattern.simplified(), typemap().value(patternType), qtcase(caseSensitive))
 {
     _modifier.NOT = NOT;
     _modifier.string = pattern.simplified();
@@ -43,7 +43,7 @@ searchPattern::searchPattern(const bool NOT, const bool caseSensitive, const QSt
 
     if (_modifier.NOT)
         _formatted_string += "NOT.";
-    _formatted_string += QString(" [%1][%2|case=%3]").arg(_modifier.string).arg(patternType).arg(caseSensitive);
+    _formatted_string += QString(" [%1][%2|case=%3]").arg(_modifier.string, patternType).arg(caseSensitive);
     if (_modifier.scope == "year")
         _formatted_string += QString(" IN [%1(%2)]").arg(_modifier.scope).arg(_modifier.yearScope);
     else
@@ -93,7 +93,8 @@ const QMap<QString, searchPattern::Type> searchPattern::typemap()
 }
 
 
-searchPattern::matcher::matcher(const QString& pattern, const Type t, const Qt::CaseSensitivity cs) : type(t), length(-1)
+searchPattern::matcher::matcher(const QString& pattern, const Type t, const Qt::CaseSensitivity cs)
+    : type(t), length(-1)
 {
     switch (t)
     {
@@ -145,14 +146,12 @@ searchPattern::matcher::matcher(const QString& pattern, const Type t, const Qt::
     case RegularExpression:
     {
 #if QT_VERSION >= 0x050400
-        const QRegularExpression::PatternOptions po(
-            QRegularExpression::DontCaptureOption |
-            QRegularExpression::UseUnicodePropertiesOption |
-            QRegularExpression::OptimizeOnFirstUsageOption);
+        const QRegularExpression::PatternOptions po(QRegularExpression::DontCaptureOption |
+                QRegularExpression::UseUnicodePropertiesOption |
+                QRegularExpression::OptimizeOnFirstUsageOption);
 #else
-        const QRegularExpression::PatternOptions po(
-            QRegularExpression::DontCaptureOption |
-            QRegularExpression::UseUnicodePropertiesOption);
+        const QRegularExpression::PatternOptions po(QRegularExpression::DontCaptureOption |
+                QRegularExpression::UseUnicodePropertiesOption);
 #endif
         regexp.setPattern(pattern);
         regexp.setPatternOptions(cs == Qt::CaseSensitive ? po : po | QRegularExpression::CaseInsensitiveOption);
@@ -162,15 +161,12 @@ searchPattern::matcher::matcher(const QString& pattern, const Type t, const Qt::
     {
 #if QT_VERSION >= 0x050400
         const QRegularExpression::PatternOptions po(
-            QRegularExpression::InvertedGreedinessOption |
-            QRegularExpression::DontCaptureOption |
-            QRegularExpression::UseUnicodePropertiesOption |
-            QRegularExpression::OptimizeOnFirstUsageOption);
+            QRegularExpression::InvertedGreedinessOption | QRegularExpression::DontCaptureOption |
+            QRegularExpression::UseUnicodePropertiesOption | QRegularExpression::OptimizeOnFirstUsageOption);
 #else
-        const QRegularExpression::PatternOptions po(
-            QRegularExpression::InvertedGreedinessOption |
-            QRegularExpression::DontCaptureOption |
-            QRegularExpression::UseUnicodePropertiesOption);
+        const QRegularExpression::PatternOptions po(QRegularExpression::InvertedGreedinessOption |
+                QRegularExpression::DontCaptureOption |
+                QRegularExpression::UseUnicodePropertiesOption);
 #endif
         regexp.setPattern(_wildcard_escaped(pattern));
         regexp.setPatternOptions(cs == Qt::CaseSensitive ? po : po | QRegularExpression::CaseInsensitiveOption);
