@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef SEARCHPATTERN_H
@@ -21,18 +21,20 @@ class searchPattern
 
 public:
     searchPattern(const QString& pattern, const QString& patternType);
-    searchPattern(const bool NOT, const bool caseSensitive, const QString& patternType,
-                  const QString& scope, const QChar& yearScope, const QString& pattern);
+    searchPattern(const bool NOT, const bool caseSensitive, const QString& patternType, const QString& scope,
+                  const QChar& yearScope, const QString& pattern);
     inline ~searchPattern() {}
 
-    enum Type {ApproximateString = 1,
-               FixedStringAllWords = 2,
-               FixedStringAnyWord = 3,
-               FixedStringContext = 4,
-               FixedString = 5,
-               RegularExpression = 6,
-               Wildcard = 7
-              };
+    enum Type
+    {
+        ApproximateString = 1,
+        FixedStringAllWords = 2,
+        FixedStringAnyWord = 3,
+        FixedStringContext = 4,
+        FixedString = 5,
+        RegularExpression = 6,
+        Wildcard = 7
+    };
     static const QString type(const Type t);
     static const QStringList types();
 
@@ -72,7 +74,7 @@ public:
     {
         return _formatted_string;
     }
-    inline bool operator< (const searchPattern& p) const
+    inline bool operator<(const searchPattern& p) const
     {
         return (_rank < p._rank);
     }
@@ -104,10 +106,10 @@ private:
         {
             const int pl(ps.length()); // Always pl > 0
             const int cl(cs.length());
-            const ushort* ups = (const ushort*) ps.unicode();
+            const ushort* ups = (const ushort*)ps.unicode();
             const ushort* p = ups;
             const ushort* pn = ups + pl;
-            const ushort* ucs = (const ushort*) cs.unicode();
+            const ushort* ucs = (const ushort*)cs.unicode();
             const ushort* c = ucs - 1;
             const ushort* cn = ucs + cl;
             while (++c != cn)
@@ -116,7 +118,8 @@ private:
                         return true;
             return false;
         }
-        inline static bool _match(const QRegularExpression& submatcher, const QString& psignature, const documentContents& contents)
+        inline static bool _match(const QRegularExpression& submatcher, const QString& psignature,
+                                  const documentContents& contents)
         {
             // Skip signature check for patterns that do not define it
             if (psignature.length() == 0 || _match_signature(psignature, contents.signature()))
@@ -124,7 +127,8 @@ private:
             else
                 return false;
         }
-        template <typename T> inline static bool _match(const T& submatcher, const QString& psignature, const documentContents& contents)
+        template <typename T>
+        inline static bool _match(const T& submatcher, const QString& psignature, const documentContents& contents)
         {
             // Skip signature check for patterns that do not define it
             if (psignature.length() == 0 || _match_signature(psignature, contents.signature()))
@@ -132,14 +136,16 @@ private:
             else
                 return false;
         }
-        template <typename T> inline bool _match_all(const int n, const T& submatchers, const documentContents& contents) const
+        template <typename T>
+        inline bool _match_all(const int n, const T& submatchers, const documentContents& contents) const
         {
             for (int i = n - 1; i >= 0; --i)
                 if (!_match(submatchers.at(i), subsignatures.at(i), contents))
                     return false;
             return true;
         }
-        template <typename T> inline bool _match_any(const int n, const T& submatchers, const documentContents& contents) const
+        template <typename T>
+        inline bool _match_any(const int n, const T& submatchers, const documentContents& contents) const
         {
             for (int i = 0; i < n; ++i)
                 if (_match(submatchers.at(i), subsignatures.at(i), contents))
@@ -158,7 +164,6 @@ private:
     {
         return caseSensitive ? Qt::CaseSensitive : Qt::CaseInsensitive;
     }
-
 };
 
 #endif
