@@ -1,10 +1,11 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "settings.h"
+
 #include "cb2bib_utilities.h"
 
 #include <QCoreApplication>
@@ -42,8 +43,9 @@ void settings::init(bool command_line)
     if (command_line)
         readCommandLine();
     if (cl_user_configured)
-        _is_usb_configured_mode = QDir::toNativeSeparators(QDir::cleanPath(QSettings::fileName())) ==
-                                  QDir::toNativeSeparators(QDir::cleanPath(_c2bApp->applicationDirPath() + '/' + "cb2bib.conf"));
+        _is_usb_configured_mode =
+            QDir::toNativeSeparators(QDir::cleanPath(QSettings::fileName())) ==
+            QDir::toNativeSeparators(QDir::cleanPath(_c2bApp->applicationDirPath() + '/' + "cb2bib.conf"));
     else
         _is_usb_configured_mode = false;
     if (_is_usb_configured_mode)
@@ -129,7 +131,8 @@ void settings::setDefaults()
     else if (QDir(_c2bApp->applicationDirPath() + "/../Resources/data/").exists())
         C2B_DATA_DIR_MAC = QDir::cleanPath(_c2bApp->applicationDirPath() + "/../Resources/");
     defaults["c2bAnnote/AnnoteCssFile"] = QDir::cleanPath(C2B_DATA_DIR_MAC + "/data/tex2html.css");
-    defaults["c2bAnnote/MathJaxHeaderFile"] = QDir::cleanPath(C2B_DATA_DIR_MAC + "/data/tex2html_local_mathjax_header.html");
+    defaults["c2bAnnote/MathJaxHeaderFile"] =
+        QDir::cleanPath(C2B_DATA_DIR_MAC + "/data/tex2html_local_mathjax_header.html");
     defaults["c2bBibSearcher/Pdf2TextBin"] = QDir::cleanPath(C2B_BIBSEARCHER_PDF2TXT_BIN);
     defaults["c2bPdfImport/LastFile"] = QDir::cleanPath(C2B_DATA_DIR_MAC + "/testPDFImport/nomeaning1.pdf");
     defaults["c2bPdfImport/Pdf2TextBin"] = QDir::cleanPath(C2B_PDFIMPORT_PDF2TXT_BIN);
@@ -143,7 +146,8 @@ void settings::setDefaults()
     defaults["cb2Bib/RegularExpressionFile"] = QDir::cleanPath(C2B_DATA_DIR_MAC + "/data/regexps.txt");
 #else // Q_OS_UNIX
     defaults["c2bAnnote/AnnoteCssFile"] = QDir::cleanPath(C2B_DATA_DIR + dsep + "data/tex2html.css");
-    defaults["c2bAnnote/MathJaxHeaderFile"] = QDir::cleanPath(C2B_DATA_DIR + dsep + "data/tex2html_local_mathjax_header.html");
+    defaults["c2bAnnote/MathJaxHeaderFile"] =
+        QDir::cleanPath(C2B_DATA_DIR + dsep + "data/tex2html_local_mathjax_header.html");
     defaults["c2bBibSearcher/Pdf2TextBin"] = QDir::cleanPath(C2B_BIBSEARCHER_PDF2TXT_BIN);
     defaults["c2bPdfImport/LastFile"] = QDir::cleanPath(C2B_DATA_DIR + dsep + "testPDFImport/nomeaning1.pdf");
     defaults["c2bPdfImport/Pdf2TextBin"] = QDir::cleanPath(C2B_PDFIMPORT_PDF2TXT_BIN);
@@ -212,7 +216,7 @@ void settings::setDefaults()
 
 QString settings::applicationDataDir() const
 {
-    // Base application data dir containing ./data/ ./doc/ ./c2btools/
+// Base application data dir containing ./data/ ./doc/ ./c2btools/
 #if defined(Q_OS_WIN)
     const QString app_data_dir(_c2bApp->applicationDirPath());
 #elif defined(Q_OS_MACOS)
@@ -304,12 +308,8 @@ settings* settings::_c2b_global_settings = 0;
 bool settings::isConsoleMode(int& argc, char** argv)
 {
     for (int i = 0; i < argc; ++i)
-        if (
-            strcmp(argv[i], "--html-annote") == 0 ||
-            strcmp(argv[i], "--doc2bib") == 0 ||
-            strcmp(argv[i], "--txt2bib") == 0 ||
-            strcmp(argv[i], "--index") == 0 ||
-            strcmp(argv[i], "--test") == 0)
+        if (strcmp(argv[i], "--html-annote") == 0 || strcmp(argv[i], "--doc2bib") == 0 ||
+            strcmp(argv[i], "--txt2bib") == 0 || strcmp(argv[i], "--index") == 0 || strcmp(argv[i], "--test") == 0)
             return true;
     return false;
 }
@@ -432,7 +432,8 @@ void settings::readCommandLine()
         _is_loaded = false;
     if (cl_sloppy && !(cl_doc2bib || cl_txt2bib))
         _is_loaded = false;
-    if (cl_index && (cl_bibedit || cl_citer || cl_import || cl_html_annote || cl_view_annote || cl_doc2bib || cl_txt2bib))
+    if (cl_index &&
+        (cl_bibedit || cl_citer || cl_import || cl_html_annote || cl_view_annote || cl_doc2bib || cl_txt2bib))
         _is_loaded = false;
     if (!_is_loaded)
     {
@@ -575,7 +576,9 @@ void settings::printUsage()
     fprintf(stdout, "\n");
     fprintf(stdout, "       --bibedit [filename1.bib [filename2.bib ... ]]     Edit/browse BibTeX files\n");
     fprintf(stdout, "       --citer [filename1.bib [filename2.bib ... ]]       Start cb2Bib citer\n");
-    fprintf(stdout, "       --import tmp_reference_filename                    Import reference, usually from ad hoc websites\n");
+    fprintf(
+        stdout,
+        "       --import tmp_reference_filename                    Import reference, usually from ad hoc websites\n");
     fprintf(stdout, "\n");
     fprintf(stdout, "       --doc2bib fn1.doc [fn2.doc ... ] reference.bib     Extract reference from document file\n");
     fprintf(stdout, "       --txt2bib fn1.txt [fn2.txt ... ] reference.bib     Extract reference from text file\n");
@@ -588,29 +591,39 @@ void settings::printUsage()
     fprintf(stdout, "\n");
     fprintf(stdout, "Switches:\n");
     fprintf(stdout, "       --conf [filename.conf]                             Use configuration file\n");
-    fprintf(stdout, "       --sloppy                                           Accept guesses in automatic reference extraction\n");
+    fprintf(
+        stdout,
+        "       --sloppy                                           Accept guesses in automatic reference extraction\n");
     fprintf(stdout, "\n");
     fprintf(stdout, "Examples:\n");
     fprintf(stdout, "       cb2bib                                             Start cb2Bib extraction panel\n");
     fprintf(stdout, "       cb2bib --import tmp_reference_filename             Import reference\n");
     fprintf(stdout, "       cb2bib --bibedit filename.bib                      Edit BibTeX filename.bib\n");
     fprintf(stdout, "       cb2bib --conf                                      Start cb2Bib in USB mode\n");
-    fprintf(stdout, "       cb2bib --doc2bib *.pdf references.bib              Extract references from PDF title pages\n");
+    fprintf(stdout,
+            "       cb2bib --doc2bib *.pdf references.bib              Extract references from PDF title pages\n");
     fprintf(stdout, "\n");
     fprintf(stdout, "Notes:\n");
     fprintf(stdout, " -Use switch --conf to particularize specific settings for specific actions.\n");
-    fprintf(stdout, " -The file cb2bib.conf must be readable and writable. If it does not exist, cb2Bib will create one\n");
+    fprintf(stdout,
+            " -The file cb2bib.conf must be readable and writable. If it does not exist, cb2Bib will create one\n");
     fprintf(stdout, "  based on predefined defaults.\n");
-    fprintf(stdout, " -If starting cb2Bib from a removable media use, the command 'cb2bib --conf' without configuration\n");
-    fprintf(stdout, "  filename. Settings will be read from and written to /cb2bib/full/path/cb2bib.conf, being therefore\n");
+    fprintf(stdout,
+            " -If starting cb2Bib from a removable media use, the command 'cb2bib --conf' without configuration\n");
+    fprintf(stdout,
+            "  filename. Settings will be read from and written to /cb2bib/full/path/cb2bib.conf, being therefore\n");
     fprintf(stdout, "  independent of the mounting address that the host computer will provide.\n");
-    fprintf(stdout, " -To import references from a browser select when asked c2bimport, which expands to 'cb2bib --import %%f'.\n");
+    fprintf(
+        stdout,
+        " -To import references from a browser select when asked c2bimport, which expands to 'cb2bib --import %%f'.\n");
     fprintf(stdout, "  The browser will provide the temporary reference filename.\n");
-    fprintf(stdout, " -A number of factors influence the reliability of automatic extractions. Consider writing customized\n");
+    fprintf(stdout,
+            " -A number of factors influence the reliability of automatic extractions. Consider writing customized\n");
     fprintf(stdout, "  regular expressions and network queries, and use metadata when available.\n");
     fprintf(stdout, "\n");
     fprintf(stdout, "Important:\n");
-    fprintf(stdout, " -The commands --doc2bib and --txt2bib do not append the references to the references.bib. They create\n");
+    fprintf(stdout,
+            " -The commands --doc2bib and --txt2bib do not append the references to the references.bib. They create\n");
     fprintf(stdout, "  a new file, or silently overwrite it if already exists.\n");
     fprintf(stdout, "\n");
 }
