@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "substringMatcher.h"
@@ -10,11 +10,10 @@
 #include "triads.h"
 
 
-substringMatcher::substringMatcher() : _hook(-1), _substring_count(0), _matched_length(-1), _p0(0), _pn(0)
-{}
+substringMatcher::substringMatcher() : _hook(-1), _substring_count(0), _matched_length(-1), _p0(0), _pn(0) {}
 
-substringMatcher::substringMatcher(const QString& pattern, const Qt::CaseSensitivity cs) :
-    _hook(-1), _matched_length(-1), _p0(0), _pn(0)
+substringMatcher::substringMatcher(const QString& pattern, const Qt::CaseSensitivity cs)
+    : _hook(-1), _matched_length(-1), _p0(0), _pn(0)
 {
     QRegExp sep("\\.\\{(\\d+),(\\d+)\\}");
     QStringList substrings(pattern.split(sep, QString::SkipEmptyParts));
@@ -44,7 +43,7 @@ substringMatcher::substringMatcher(const QString& pattern, const Qt::CaseSensiti
         _stretches[i] = stretches.at(i - 1);
     _acc_lengths.fill(0, _substring_count);
     for (int i = 1; i < _substring_count; ++i)
-        _acc_lengths[i] = _acc_lengths[i-1] + _lengths.at(i - 1);
+        _acc_lengths[i] = _acc_lengths[i - 1] + _lengths.at(i - 1);
 
     int lf(10000);
     for (int i = 0; i < _substring_count; ++i)
