@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "texToHtml.h"
@@ -75,7 +75,8 @@ QString texToHtml::toHtml(const QString& tex)
     {
         if (!_tex_macros.isEmpty())
         {
-            QString t("\n\n<script type=\"text/x-mathjax-config\">\n  MathJax.Hub.Config({\n   TeX: {\n    Macros: {%1\n    }\n   }\n  });\n</script>\n");
+            QString t("\n\n<script type=\"text/x-mathjax-config\">\n  MathJax.Hub.Config({\n   TeX: {\n    Macros: "
+                      "{%1\n    }\n   }\n  });\n</script>\n");
             mathjax_head += t.arg(_tex_macros);
         }
         tex2html.replace("GET_MATHJAX_HEAD", mathjax_head);
@@ -168,7 +169,8 @@ void texToHtml::parseElement(const QString& p, const QString& e, const QString&
             parseTextParagraph("- " + items.at(i).simplified());
     }
     else if (e == "abstract")
-        _html += QString("\n<div id=\"abstract\" class=\"abstract\">\n%1\n</div><br /><hr />\n\n").arg(toHtmlString(v.trimmed(), false));
+        _html += QString("\n<div id=\"abstract\" class=\"abstract\">\n%1\n</div><br /><hr />\n\n")
+                 .arg(toHtmlString(v.trimmed(), false));
     else if (e == "verbatim")
         _html += QString("\n<pre>%1</pre>\n\n").arg(v);
     else if (e == "newcommand")
@@ -221,11 +223,9 @@ void texToHtml::extractMacro(const QString& v)
     definition.remove("\\ensuremath");
     definition.replace("\\", "\\\\");
     if (_macro_arguments_rx.indexIn(v) > -1)
-        _tex_macros += QString("\n     %1: ['%2',%3],")
-                       .arg(name).arg(definition).arg(_macro_arguments_rx.cap(1));
+        _tex_macros += QString("\n     %1: ['%2',%3],").arg(name, definition, _macro_arguments_rx.cap(1));
     else
-        _tex_macros += QString("\n     %1: '%2',")
-                       .arg(name).arg(definition);
+        _tex_macros += QString("\n     %1: '%2',").arg(name, definition);
 }
 
 void texToHtml::extractCites(const QString& p)
@@ -287,7 +287,8 @@ void texToHtml::retrieveReferences()
     bool done(false);
     for (int i = 0; i < flist.count(); ++i)
     {
-        if (done) return;
+        if (done)
+            return;
         const QString bib_contents(c2bUtils::fileToString(flist.at(i)));
         done = true;
         for (int j = 0; j < keys.count(); ++j)
