@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef TEXTOHTML_H
@@ -53,9 +53,9 @@ private:
     void citesToHtml(QString* html);
     void extractCites(const QString& p);
     void extractMacro(const QString& v);
-    void parseComment(const QString& p);
-    void parseElement(const QString& p, const QString& e, const QString& v);
-    void parseTextParagraph(const QString& p);
+    void parseComment(const QString& p) override;
+    void parseElement(const QString& p, const QString& e, const QString& v) override;
+    void parseTextParagraph(const QString& p) override;
     void referencesToHtml(QString* reference_list_html);
     void retrieveReferences();
 
@@ -87,7 +87,6 @@ private:
                 str.replace(_tex_macro_names_rx.at(i), "$\\1$");
         return str;
     }
-
 };
 
 #endif
