@@ -1,17 +1,16 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "wordMatcher.h"
 
-#include "triads.h"
 #include "cb2bib_utilities.h"
+#include "triads.h"
 
 
-wordMatcher::wordMatcher() : _stretch(0), _hook(-1), _substring_count(0), _matched_length(-1), _p0(0), _pn(0)
-{}
+wordMatcher::wordMatcher() : _stretch(0), _hook(-1), _substring_count(0), _matched_length(-1), _p0(0), _pn(0) {}
 
 wordMatcher::wordMatcher(const QString& pattern, const Qt::CaseSensitivity cs) : _p0(0), _pn(0)
 {
