@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "wordPattern.h"
@@ -10,11 +10,10 @@
 #include "triads.h"
 
 
-wordPattern::wordPattern() : compositePattern(), _type(AllWords)
-{}
+wordPattern::wordPattern() : compositePattern(), _type(AllWords) {}
 
-wordPattern::wordPattern(const QString& pattern, const Type type, const Qt::CaseSensitivity cs) :
-    compositePattern(pattern, cs), _type(type)
+wordPattern::wordPattern(const QString& pattern, const Type type, const Qt::CaseSensitivity cs)
+    : compositePattern(pattern, cs), _type(type)
 {
     setPattern(pattern, type, cs);
 }
