@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef WORDPATTERN_H
@@ -17,7 +17,11 @@ class wordPattern : public compositePattern
 {
 
 public:
-    enum Type {AllWords, AnyWord};
+    enum Type
+    {
+        AllWords,
+        AnyWord
+    };
 
     wordPattern();
     wordPattern(const QString& pattern, const Type type, const Qt::CaseSensitivity cs);
@@ -26,7 +30,7 @@ public:
 
     void setPattern(const QString& pattern, const Type type, const Qt::CaseSensitivity cs = Qt::CaseSensitive);
 
-    inline bool matches(const QString& str) const
+    inline bool matches(const QString& str) const override
     {
         _matched_length = -1;
         if (str.length() == 0)
@@ -46,7 +50,7 @@ public:
             return false;
         }
     }
-    inline int indexIn(const QString& str, const int from = 0) const
+    inline int indexIn(const QString& str, const int from = 0) const override
     {
         // Do not match. Get index for (w1|w2|...).
         _matched_length = -1;
@@ -75,7 +79,6 @@ public:
 private:
     QVector<QStringMatcher> _submatchers;
     Type _type;
-
 };
 
 #endif
