@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bAnnote.h"
@@ -69,12 +69,12 @@ c2bAnnote::c2bAnnote(QWidget* parentw) : QMainWindow(parentw)
     setCentralWidget(_view_port);
     QLabel* informationLabel = new QLabel(this);
     statusBar()->addWidget(informationLabel, 1);
-    connect(_view_port, SIGNAL(titleChanged(const QString&)), this, SLOT(setWindowTitle(const QString&)));
-    connect(_view_port, SIGNAL(statusMessage(const QString&)), this, SLOT(showMessage(const QString&)));
+    connect(_view_port, SIGNAL(windowTitleChanged(QString)), this, SLOT(setWindowTitle(QString)));
+    connect(_view_port, SIGNAL(statusMessage(QString)), this, SLOT(showMessage(QString)));
 
     // Creating cb2Bib global resources
     c2b* c2b_resources = new c2b(this, this);
-    connect(c2b_resources, SIGNAL(statusMessage(const QString&)), this, SLOT(showMessage(const QString&)));
+    connect(c2b_resources, SIGNAL(statusMessage(QString)), this, SLOT(showMessage(QString)));
 
     QAction* act = new QAction(QIcon(QString::fromUtf8(":/icons/icons/edit.png")), tr("Edit Note"), this);
     act->setShortcut(QKeySequence(Qt::Key_E));
@@ -98,7 +98,7 @@ c2bAnnote::c2bAnnote(QWidget* parentw) : QMainWindow(parentw)
 
     _t2h = new texToHtml;
     _fsw = new c2bFileSystemWatcher(this);
-    connect(_fsw, SIGNAL(fileChanged(const QString&)), this, SLOT(annote()));
+    connect(_fsw, SIGNAL(fileChanged(QString)), this, SLOT(annote()));
     disconnect(_view_port->viewReloadAction, 0, 0, 0);
     connect(_view_port->viewReloadAction, SIGNAL(triggered()), this, SLOT(update()));
 
@@ -120,15 +120,16 @@ bool c2bAnnote::show()
     const bool is_html = _annote_filename.endsWith(".html");
     if (is_html)
         _annote_filename.remove(QRegExp("\\.html$"));
-    if (!QFileInfo(_annote_filename).exists())
+    if (!QFileInfo::exists(_annote_filename))
     {
         QMessageBox::warning(this, tr("Warning - cb2Bib"),
-                             tr("Unable to open the file %1 for reading.\nError: '%2'.").
-                             arg(QDir::toNativeSeparators(_annote_filename)).arg("File does not exist"), QMessageBox::Ok);
+                             tr("Unable to open the file %1 for reading.\nError: '%2'.")
+                             .arg(QDir::toNativeSeparators(_annote_filename), "File does not exist"),
+                             QMessageBox::Ok);
         return false;
     }
     _html_filename = _annote_filename + ".html";
-    if (!is_html || !QFileInfo(_html_filename).exists())
+    if (!is_html || !QFileInfo::exists(_html_filename))
         _t2h->toHtml(c2bUtils::fileToString(_annote_filename), _html_filename);
     _view_port->setHomePage(_html_filename);
     _fsw->addPath(_annote_filename);
