@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bBibHighlighter.h"
@@ -26,8 +26,7 @@ c2bBibHighlighter::c2bBibHighlighter(QTextDocument* doc) : QSyntaxHighlighter(do
     rx3 = QRegExp("^%.+$");
 }
 
-c2bBibHighlighter::~c2bBibHighlighter()
-{}
+c2bBibHighlighter::~c2bBibHighlighter() {}
 
 
 void c2bBibHighlighter::highlightBlock(const QString& text)
@@ -42,7 +41,7 @@ void c2bBibHighlighter::highlightBlock(const QString& text)
         if (pos > -1)
         {
             setFormat(pos, rx0.matchedLength(), c->bib_delimiter_color);
-            pos  += rx0.matchedLength();
+            pos += rx0.matchedLength();
         }
     }
     pos = 0;
@@ -52,7 +51,7 @@ void c2bBibHighlighter::highlightBlock(const QString& text)
         if (pos > -1)
         {
             setFormat(pos, rx1.matchedLength(), c->bib_reference_type_color);
-            pos  += rx1.matchedLength();
+            pos += rx1.matchedLength();
         }
     }
     pos = 0;
@@ -62,7 +61,7 @@ void c2bBibHighlighter::highlightBlock(const QString& text)
         if (pos > -1)
         {
             setFormat(pos, rx2.matchedLength(), c->bib_reference_field_color);
-            pos  += rx2.matchedLength();
+            pos += rx2.matchedLength();
         }
     }
     pos = 0;
@@ -72,7 +71,7 @@ void c2bBibHighlighter::highlightBlock(const QString& text)
         if (pos > -1)
         {
             setFormat(pos, rx3.matchedLength(), c->comment_color);
-            pos  += rx3.matchedLength();
+            pos += rx3.matchedLength();
         }
     }
 }
