@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bBibParser.h"
@@ -31,24 +31,24 @@ c2bBibParser::c2bBibParser(QObject* parento) : bibParser(parento)
     else
     {
         QFile f(journal_f);
-        if (!f.open(QIODevice::ReadOnly | QIODevice::Text))      // jdbfile.exists wouldn't produce an errorString
+        if (!f.open(QIODevice::ReadOnly | QIODevice::Text)) // jdbfile.exists wouldn't produce an errorString
             QMessageBox::warning(_c2b_mainP, tr("Warning - cb2Bib"),
                                  tr("Unable to open the Journal Abbreviation file %1 for reading.\nError: '%2'.\n\n"
                                     "Note: Abbreviation files are specified through the cb2Bib Configure dialog.")
-                                 .arg(journal_f).arg(f.errorString()), QMessageBox::Ok);
+                                 .arg(journal_f, f.errorString()),
+                                 QMessageBox::Ok);
         else
             f.close();
     }
 
     // Set status messages
-    connect(this, SIGNAL(statusMessage(const QString&)), c2b::instance(), SIGNAL(statusMessage(const QString&)));
+    connect(this, SIGNAL(statusMessage(QString)), c2b::instance(), SIGNAL(statusMessage(QString)));
 
     // Set preparser log
-    connect(_preparserP, SIGNAL(preparserLogAvailable(const QString&)), this, SLOT(showLog(const QString&)));
+    connect(_preparserP, SIGNAL(preparserLogAvailable(QString)), this, SLOT(showLog(QString)));
 }
 
-c2bBibParser::~c2bBibParser()
-{}
+c2bBibParser::~c2bBibParser() {}
 
 
 void c2bBibParser::currentReferenceUpdated()
@@ -76,9 +76,9 @@ void c2bBibParser::clearCurrentReference()
     // Affects versions 4.6.x, expected to be fixed in 4.6.3
     for (int i = 0; i < _bibliographic_fields.count(); ++i)
         _field_editors[_bibliographic_fields.at(i)]->setText(QString());
-//        _field_editors[_bibliographic_fields.at(i)]->clear();
+    // _field_editors[_bibliographic_fields.at(i)]->clear();
     _field_editors["id"]->setText(QString());
-//    _field_editors["id"]->clear();
+    // _field_editors["id"]->clear();
     bibParser::clearCurrentReference();
     _current_reference.typeName = "article";
     _type_editor->setCurrentIndex(1);
@@ -159,10 +159,10 @@ void c2bBibParser::setWidgetMapping()
     {
         const QString& name = _bibliographic_fields.at(i);
         connect(_field_editors.value(name), SIGNAL(returnPressed()), this, SLOT(setField()));
-        connect(_field_editors.value(name), SIGNAL(textChanged(const QString&)), this, SLOT(referenceEdited(const QString&)));
+        connect(_field_editors.value(name), SIGNAL(textChanged(QString)), this, SLOT(referenceEdited(QString)));
     }
-    connect(_field_editors.value("id"), SIGNAL(textChanged(const QString&)), this, SLOT(referenceEdited(const QString&)));
-    connect(_type_editor, SIGNAL(editTextChanged(const QString&)), this, SLOT(referenceEdited(const QString&)));
+    connect(_field_editors.value("id"), SIGNAL(textChanged(QString)), this, SLOT(referenceEdited(QString)));
+    connect(_type_editor, SIGNAL(editTextChanged(QString)), this, SLOT(referenceEdited(QString)));
 }
 
 void c2bBibParser::showLog(const QString& log)
@@ -179,7 +179,8 @@ void c2bBibParser::checkRegExpFile(const QString& fn)
     {
         QMessageBox::information(_c2b_mainP, tr("Information - cb2Bib"),
                                  tr("No RegExp filename has been specified.\n\n"
-                                    "Note: RegExp files are specified through the cb2Bib Configure dialog."), QMessageBox::Ok);
+                                    "Note: RegExp files are specified through the cb2Bib Configure dialog."),
+                                 QMessageBox::Ok);
         return;
     }
     QFile f(fn);
@@ -188,7 +189,9 @@ void c2bBibParser::checkRegExpFile(const QString& fn)
                              tr("Unable to open the RegExp file %1 for reading.\nError: '%2'.\n\n"
                                 "Note: RegExp files are specified through the cb2Bib Configure dialog. "
                                 "After manual matching, patterns can be edited and stored in a "
-                                "RegExp file for future autodetection.").arg(fn).arg(f.errorString()), QMessageBox::Ok);
+                                "RegExp file for future autodetection.")
+                             .arg(fn, f.errorString()),
+                             QMessageBox::Ok);
     else
         f.close();
 }
