@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bBibPreparserLog.h"
@@ -28,8 +28,7 @@ c2bBibPreparserLog::c2bBibPreparserLog(QWidget* parentw) : QDialog(parentw)
     connect(this, SIGNAL(finished(int)), this, SLOT(close()));
 }
 
-c2bBibPreparserLog::~c2bBibPreparserLog()
-{}
+c2bBibPreparserLog::~c2bBibPreparserLog() {}
 
 
 void c2bBibPreparserLog::append(const QString& ms)
