@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BCITER_H
@@ -122,21 +122,36 @@
 namespace c2bCiter
 {
 
-enum Format {AJYT, IT, JYA, T, YAJT, R, K};
-enum Filter {None, Document, Keyword, Pattern, Related, Selected};
+enum Format
+{
+    AJYT,
+    IT,
+    JYA,
+    T,
+    YAJT,
+    R,
+    K
+};
+enum Filter
+{
+    None,
+    Document,
+    Keyword,
+    Pattern,
+    Related,
+    Selected
+};
 
 struct State
 {
     inline State() : format(AJYT), filter(None), viewer_index(0) {}
-    inline State(const Format fo, const Filter fi, const int vi, const QString fs) :
-        format(fo),
-        filter(fi),
-        viewer_index(vi),
-        filter_string(fs) {}
+    inline State(const Format fo, const Filter fi, const int vi, const QString fs)
+        : format(fo), filter(fi), viewer_index(vi), filter_string(fs) {}
 
     inline bool operator==(const State& s) const
     {
-        return format == s.format && filter == s.filter && viewer_index == s.viewer_index && filter_string == s.filter_string;
+        return format == s.format && filter == s.filter && viewer_index == s.viewer_index &&
+               filter_string == s.filter_string;
     }
 
     Format format;
