@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bCiterExcerptView.h"
@@ -27,7 +27,8 @@ c2bCiterExcerptView::c2bCiterExcerptView(const QString& html, QWidget* parentw)
     resize(settings->value("c2bCiterExcerptView/size", QSize(500, 500)).toSize());
     move(settings->value("c2bCiterExcerptView/position", pos()).toPoint());
 
-    _browserP->setFont(QFont(QFont().family(), settings->value("c2bCiterExcerptView/BrowserFontPointSize", QFont().pointSize()).toInt()));
+    _browserP->setFont(QFont(QFont().family(),
+                             settings->value("c2bCiterExcerptView/BrowserFontPointSize", QFont().pointSize()).toInt()));
     QString css(c2bUtils::fileToString(settings->fileName("cb2Bib/BrowserCssFile")));
     if (css.isEmpty())
         css = c2bUtils::fileToString(":/htm/htm/references.css");
