@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BCITERHISTORY_H
@@ -21,10 +21,11 @@ public:
     inline ~c2bCiterHistory() {}
 
     void clear();
-    void saveCurrentState(const c2bCiter::Format format, const c2bCiter::Filter filter, const int iindex, const int vindex, const QString fstring);
+    void saveCurrentState(const c2bCiter::Format format, const c2bCiter::Filter filter, const int iindex,
+                          const int vindex, const QString fstring);
 
-    inline void saveCurrentState(const c2bCiter::Format format, const c2bCiter::Filter filter, const int iindex, const QModelIndex* const index,
-                                 const QString fstring)
+    inline void saveCurrentState(const c2bCiter::Format format, const c2bCiter::Filter filter, const int iindex,
+                                 const QModelIndex* const index, const QString fstring)
     {
         if (index)
             saveCurrentState(format, filter, iindex, index->row(), fstring);
@@ -103,7 +104,6 @@ private:
 
     QVarLengthArray<c2bCiter::State> _states;
     QVarLengthArray<int> _index;
-
 };
 
 #endif
