@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bCiterModel.h"
@@ -14,7 +14,8 @@
 #include <QIcon>
 
 
-template <typename T> class ascending
+template <typename T>
+class ascending
 {
 public:
     explicit ascending(const T& data) : _data(data) {}
@@ -22,6 +23,7 @@ public:
     {
         return _data.at(i) < _data.at(j);
     }
+
 private:
     const T& _data;
 };
@@ -179,7 +181,8 @@ void c2bCiterModel::setSelectedFilter(QModelIndex* current_index)
     emit layoutChanged();
 }
 
-void c2bCiterModel::setRelatedFilter(const QString& documentfn, QModelIndex* current_index, const c2bCiter::Format format)
+void c2bCiterModel::setRelatedFilter(const QString& documentfn, QModelIndex* current_index,
+                                     const c2bCiter::Format format)
 {
     _analyzer.setSimilarDocuments(documentfn);
     if (_analyzer.similarCount() == 0)
@@ -364,7 +367,8 @@ void c2bCiterModel::clearCurrentFilter(QModelIndex* current_index)
 c2bCiter::State c2bCiterModel::currentState(const QModelIndex& current_index) const
 {
     const int current_item(_current_item(current_index));
-    c2bCiter::State s(_format == c2bCiter::R ? _history.lastCitationFormat() : _format, _filter, current_index.row(), _fstring);
+    c2bCiter::State s(_format == c2bCiter::R ? _history.lastCitationFormat() : _format, _filter, current_index.row(),
+                      _fstring);
     if (current_item > -1)
         s.index_data = (_format == c2bCiter::K) ? _analyzer.sentence(current_item) : _search_string.at(current_item);
     return s;
@@ -385,7 +389,8 @@ void c2bCiterModel::restoreState(const c2bCiter::State& s, QModelIndex* current_
         emit layoutChanged();
         break;
     case c2bCiter::Document:
-        if (_file.contains(s.filter_string)) emit statusLabel(tr("Keywords from '%1'").arg(_title.at(_file.value(s.filter_string))));
+        if (_file.contains(s.filter_string))
+            emit statusLabel(tr("Keywords from '%1'").arg(_title.at(_file.value(s.filter_string))));
         setDocumentFilter(s.filter_string, 0);
         break;
     case c2bCiter::Keyword:
@@ -708,12 +713,13 @@ void c2bCiterModel::_set_sort_indices()
     for (int i = 0; i < _author_count; ++i)
     {
         const int j(_map_author.at(i));
-        _search_string[i] = c2bUtils::toAscii(_author.at(i) + sp + _journal.at(j) + sp + _year.at(j) + sp + _title.at(j), c2bUtils::Collation);
+        _search_string[i] = c2bUtils::toAscii(
+                                _author.at(i) + sp + _journal.at(j) + sp + _year.at(j) + sp + _title.at(j), c2bUtils::Collation);
     }
     _map_ajyt.resize(_author_count);
     for (int i = 0; i < _author_count; ++i)
         _map_ajyt[i] = i;
-    ascending< QVector<QString> > ajyt(_search_string);
+    ascending<QVector<QString>> ajyt(_search_string);
     qSort(_map_ajyt.begin(), _map_ajyt.end(), ajyt);
 
     // IT
@@ -722,20 +728,22 @@ void c2bCiterModel::_set_sort_indices()
     const QString dtt("%1");
     const QChar padding('0');
     for (int i = 0; i < _citation_count; ++i)
-        _search_string[i] = c2bUtils::toAscii(dtt.arg(current_dtt - _included_date.at(i), 10, 10, padding) + sp + _title.at(i), c2bUtils::Collation);
+        _search_string[i] = c2bUtils::toAscii(
+                                dtt.arg(current_dtt - _included_date.at(i), 10, 10, padding) + sp + _title.at(i), c2bUtils::Collation);
     _map_it.resize(_citation_count);
     for (int i = 0; i < _citation_count; ++i)
         _map_it[i] = i;
-    ascending< QVector<QString> > it(_search_string);
+    ascending<QVector<QString>> it(_search_string);
     qSort(_map_it.begin(), _map_it.end(), it);
 
     // JYA
     for (int i = 0; i < _citation_count; ++i)
-        _search_string[i] = c2bUtils::toAscii(_journal.at(i) + sp + _year.at(i) + sp + _author_string.at(i), c2bUtils::Collation);
+        _search_string[i] =
+            c2bUtils::toAscii(_journal.at(i) + sp + _year.at(i) + sp + _author_string.at(i), c2bUtils::Collation);
     _map_jya.resize(_citation_count);
     for (int i = 0; i < _citation_count; ++i)
         _map_jya[i] = i;
-    ascending< QVector<QString> > jya(_search_string);
+    ascending<QVector<QString>> jya(_search_string);
     qSort(_map_jya.begin(), _map_jya.end(), jya);
 
     // T
@@ -744,16 +752,17 @@ void c2bCiterModel::_set_sort_indices()
     _map_t.resize(_citation_count);
     for (int i = 0; i < _citation_count; ++i)
         _map_t[i] = i;
-    ascending< QVector<QString> > t(_search_string);
+    ascending<QVector<QString>> t(_search_string);
     qSort(_map_t.begin(), _map_t.end(), t);
 
     // YAJT
     for (int i = 0; i < _citation_count; ++i)
-        _search_string[i] = c2bUtils::toAscii(_year.at(i) + sp + _author_string.at(i) + sp + _journal.at(i) + sp + _title.at(i), c2bUtils::Collation);
+        _search_string[i] = c2bUtils::toAscii(
+                                _year.at(i) + sp + _author_string.at(i) + sp + _journal.at(i) + sp + _title.at(i), c2bUtils::Collation);
     _map_yajt.resize(_citation_count);
     for (int i = 0; i < _citation_count; ++i)
         _map_yajt[i] = i;
-    ascending< QVector<QString> > yajt(_search_string);
+    ascending<QVector<QString>> yajt(_search_string);
     qSort(_map_yajt.begin(), _map_yajt.end(), yajt);
     // Keep _search_string for filtering
 }
@@ -841,9 +850,9 @@ QString c2bCiterModel::_display_it(const int row, const int column) const
     switch (column)
     {
     case 0:
-        return _included_date.at(_offset(row)) > 0 ?
-               QDateTime::fromTime_t(_included_date.at(_offset(row))).date().toString(Qt::ISODate) :
-               QString();
+        return _included_date.at(_offset(row)) > 0
+               ? QDateTime::fromTime_t(_included_date.at(_offset(row))).date().toString(Qt::ISODate)
+               : QString();
     case 1:
         return _title.at(_offset(row));
     default:
