@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BCITERMODEL_H
@@ -44,7 +44,8 @@ public:
     void setGlossaryView(QModelIndex* current_index);
     void setKeywordFilter(const QString& keyword, QModelIndex* current_index);
     void setPatternFilter(const QString& pattern, QModelIndex* current_index, const c2bCiter::Format format);
-    void setRelatedFilter(const QString& documentfn, QModelIndex* current_index, const c2bCiter::Format format = c2bCiter::R);
+    void setRelatedFilter(const QString& documentfn, QModelIndex* current_index,
+                          const c2bCiter::Format format = c2bCiter::R);
     void setSelectedFilter(QModelIndex* current_index);
     void updateFormat(const c2bCiter::Format format, QModelIndex* current_index);
 
@@ -225,7 +226,6 @@ private:
     int _keyword_count;
     int _related_count;
     int _row_count;
-
 };
 
 #endif
