@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bCiterView.h"
@@ -44,7 +44,7 @@ void c2bCiterView::reloadModel(QAbstractItemModel* citations, const QStringList&
     {
         _citationsP = static_cast<c2bCiterModel*>(citations);
         QTableView::setModel(_citationsP);
-        connect(_citationsP, SIGNAL(patternFilterChanged(const QString&)), this, SLOT(updatePatternFilter(const QString&)));
+        connect(_citationsP, SIGNAL(patternFilterChanged(QString)), this, SLOT(updatePatternFilter(QString)));
     }
     QModelIndex i(currentIndex());
     _citationsP->reloadCitations(bibtex_files, s, &i);
@@ -164,8 +164,8 @@ void c2bCiterView::toggleKeywordView()
 void c2bCiterView::toggleGlossaryView()
 {
     QModelIndex i(currentIndex());
-    if (_citationsP->currentFormat() == c2bCiter::K
-        && (_citationsP->currentFilter() == c2bCiter::None || _citationsP->currentFilter() == c2bCiter::Pattern))
+    if (_citationsP->currentFormat() == c2bCiter::K &&
+        (_citationsP->currentFilter() == c2bCiter::None || _citationsP->currentFilter() == c2bCiter::Pattern))
         _citationsP->restoreLastNonKeywordState(&i);
     else
         _citationsP->setGlossaryView(&i);
@@ -237,7 +237,7 @@ void c2bCiterView::updateViewport()
     if (required_w > vp_w)
     {
         int available_w(vp_w - w.at(0));
-        int div[] = {0, 0, 0, 0};
+        int div[] = { 0, 0, 0, 0 };
         while (available_w > 0)
             for (int i = 1; i < nc; ++i)
                 if (div[i] < w.at(i))
@@ -249,7 +249,7 @@ void c2bCiterView::updateViewport()
             w[i] = div[i];
     }
     else
-        w[nc-1] += vp_w - required_w;
+        w[nc - 1] += vp_w - required_w;
     for (int i = 0; i < nc; ++i)
         setColumnWidth(i, w.at(i));
 }
@@ -293,7 +293,7 @@ void c2bCiterView::keyPressEvent(QKeyEvent* qevent)
     }
     switch (qevent->key())
     {
-        // Formats
+    // Formats
     case Qt::Key_A:
         updateFormat(c2bCiter::AJYT);
         qevent->accept();
@@ -315,7 +315,7 @@ void c2bCiterView::keyPressEvent(QKeyEvent* qevent)
         qevent->accept();
         return;
 
-        // Filters
+    // Filters
     case Qt::Key_Delete:
         _citationsP->clearSelection();
         qevent->accept();
@@ -346,13 +346,13 @@ void c2bCiterView::keyPressEvent(QKeyEvent* qevent)
         qevent->accept();
         return;
 
-        // Actions
+    // Actions
     case Qt::Key_Left:
-        emit showPreviousState();
+        showPreviousState();
         qevent->accept();
         return;
     case Qt::Key_Right:
-        emit showNextState();
+        showNextState();
         qevent->accept();
         return;
     case Qt::Key_C:
@@ -384,7 +384,7 @@ void c2bCiterView::keyPressEvent(QKeyEvent* qevent)
         qevent->accept();
         return;
 
-        // Navigation
+    // Navigation
     case Qt::Key_Tab:
     {
         QKeyEvent ke(QEvent::KeyPress, Qt::Key_Down, Qt::NoModifier);
@@ -441,5 +441,4 @@ void c2bCiterView::resizeEvent(QResizeEvent* qevent)
     QTableView::resizeEvent(qevent);
 }
 
-void c2bCiterView::keyboardSearch(const QString& /* search */)
-{}
+void c2bCiterView::keyboardSearch(const QString& /* search */) {}
