@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bCiterWidget.h"
@@ -36,18 +36,19 @@ c2bCiterWidget::c2bCiterWidget(QWidget* parentw) : QWidget(parentw)
     _clipboard_connected = true;
     _citations = new c2bCiterModel(this);
 
-    connect(_citations, SIGNAL(statusLabel(const QString&)), this, SLOT(showLabel(const QString&)));
-    connect(_citations, SIGNAL(statusMessage(const QString&)), this, SLOT(showMessage(const QString&)));
-    connect(c2b::clipboard(), SIGNAL(cbDataChanged(const QString&)), this, SLOT(filterDataChanged(const QString&)));
-    connect(ui.citationsView, SIGNAL(activated(const QModelIndex&)), _citations, SLOT(selectCitation(const QModelIndex&)));
+    connect(_citations, SIGNAL(statusLabel(QString)), this, SLOT(showLabel(QString)));
+    connect(_citations, SIGNAL(statusMessage(QString)), this, SLOT(showMessage(QString)));
+    connect(c2b::clipboard(), SIGNAL(cbDataChanged(QString)), this, SLOT(filterDataChanged(QString)));
+    connect(ui.citationsView, SIGNAL(activated(QModelIndex)), _citations, SLOT(selectCitation(QModelIndex)));
     connect(ui.citationsView, SIGNAL(citeReferences()), this, SLOT(citeReferences()));
     connect(ui.citationsView, SIGNAL(editReference()), this, SLOT(editReference()));
     connect(ui.citationsView, SIGNAL(hideCiter()), this, SLOT(hide()));
     connect(ui.citationsView, SIGNAL(openAnnote()), this, SIGNAL(openAnnote()));
     connect(ui.citationsView, SIGNAL(openFile()), this, SLOT(openFile()));
     connect(ui.citationsView, SIGNAL(openUrl()), this, SLOT(openUrl()));
-    connect(ui.citationsView, SIGNAL(patternFilterChanged(const bool, const QString&)), this, SLOT(updatePatternFilter(const bool, const QString&)));
-    connect(ui.citationsView, SIGNAL(statusMessage(const QString&)), this, SLOT(showMessage(const QString&)));
+    connect(ui.citationsView, SIGNAL(patternFilterChanged(bool,QString)), this,
+            SLOT(updatePatternFilter(bool,QString)));
+    connect(ui.citationsView, SIGNAL(statusMessage(QString)), this, SLOT(showMessage(QString)));
 }
 
 c2bCiterWidget::~c2bCiterWidget()
@@ -65,7 +66,8 @@ void c2bCiterWidget::load()
 {
     _bibtex_files.clear();
     if (_settingsP->cl_citer_filenames.count() == 0)
-        _bibtex_files = c2bUtils::filesInDir(QFileInfo(_settingsP->fileName("cb2Bib/BibTeXFile")).absolutePath(), QStringList() << "*.bib");
+        _bibtex_files = c2bUtils::filesInDir(QFileInfo(_settingsP->fileName("cb2Bib/BibTeXFile")).absolutePath(),
+                                             QStringList() << "*.bib");
     else
         for (int i = 0; i < _settingsP->cl_citer_filenames.count(); ++i)
             _bibtex_files += c2bUtils::filesInDir(_settingsP->cl_citer_filenames.at(i), QStringList() << "*.bib");
@@ -85,7 +87,8 @@ void c2bCiterWidget::reload(const c2bCiter::State& state)
     QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
     updatePatternFilter(false, QString());
     if (_bibtex_files.count() == 1)
-        setWindowTitle(tr("%1 - cb2Bib").arg(QDir::toNativeSeparators(QFileInfo(_bibtex_files.at(0)).absoluteFilePath())));
+        setWindowTitle(
+            tr("%1 - cb2Bib").arg(QDir::toNativeSeparators(QFileInfo(_bibtex_files.at(0)).absoluteFilePath())));
     else if (_bibtex_files.count() > 1)
         setWindowTitle(tr("%1 - cb2Bib").arg(QDir::toNativeSeparators(QFileInfo(_bibtex_files.at(0)).absolutePath())));
     else
@@ -114,17 +117,17 @@ void c2bCiterWidget::show()
 void c2bCiterWidget::setTrayIcon()
 {
     _tray_icon = new QSystemTrayIcon(this);
-    _tray_icon->setIcon(QIcon(":/icons/icons/cb2bib.png"));
+    _tray_icon->setIcon(QIcon(":/icons/icons/cb2bib.ico"));
     _tray_icon->setToolTip("c2bBib Citer");
     QMenu* tray_icon_menu = new QMenu(this);
-    foreach(QAction * a, actions())
+    foreach (QAction* a, actions())
     {
         tray_icon_menu->addAction(a);
     }
     _tray_icon->setContextMenu(tray_icon_menu);
     _tray_icon->show();
-    connect(_tray_icon, SIGNAL(activated(QSystemTrayIcon::ActivationReason)),
-            this, SLOT(trayIconActivated(QSystemTrayIcon::ActivationReason)));
+    connect(_tray_icon, SIGNAL(activated(QSystemTrayIcon::ActivationReason)), this,
+            SLOT(trayIconActivated(QSystemTrayIcon::ActivationReason)));
 }
 
 void c2bCiterWidget::trayIconActivated(QSystemTrayIcon::ActivationReason r)
@@ -224,7 +227,8 @@ void c2bCiterWidget::openFiles()
     QString dir;
     if (_bibtex_files.count() > 0)
         dir = _bibtex_files.at(0);
-    const QStringList fns(c2bFileDialog::getOpenFilenames(this, "Select BibTeX filenames", dir, "BibTeX (*.bib);;All (*)"));
+    const QStringList fns(
+        c2bFileDialog::getOpenFilenames(this, "Select BibTeX filenames", dir, "BibTeX (*.bib);;All (*)"));
     if (fns.count() > 0)
     {
         _bibtex_files = fns;
@@ -234,7 +238,8 @@ void c2bCiterWidget::openFiles()
 
 void c2bCiterWidget::doSearchInFiles()
 {
-    const QString fn(_citations->isKeywordView() ? QString() :  _citations->dataBibTeXFile(ui.citationsView->currentIndex()));
+    const QString fn(_citations->isKeywordView() ? QString()
+                     : _citations->dataBibTeXFile(ui.citationsView->currentIndex()));
     if (fn.isEmpty())
         showMessage(tr("No active reference."));
     else
