@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bClipEdit.h"
@@ -37,8 +37,7 @@ c2bClipEdit::c2bClipEdit(const Mode mode, QWidget* parentw) : QPlainTextEdit(par
     }
 }
 
-c2bClipEdit::~c2bClipEdit()
-{}
+c2bClipEdit::~c2bClipEdit() {}
 
 
 void c2bClipEdit::setText(const QString& text, const QString& tagged_text)
