@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BCLIPEDIT_H
@@ -19,7 +19,11 @@ class c2bClipEdit : public QPlainTextEdit
     Q_OBJECT
 
 public:
-    enum Mode {Editor, Browser};
+    enum Mode
+    {
+        Editor,
+        Browser
+    };
 
     c2bClipEdit(const Mode mode, QWidget* parentw = 0);
     ~c2bClipEdit();
@@ -50,7 +54,6 @@ private:
     QString _text;
     bool _has_selecting_ended;
     bool _is_tagged_view;
-
 };
 
 #endif
