@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bCollectionIndex.h"
@@ -38,7 +38,8 @@ void c2bCollectionIndex::index()
     ui.buttonBox->button(QDialogButtonBox::Close)->setEnabled(false);
     _indexerP = new QProcess(this);
     _indexerP->setProcessChannelMode(QProcess::MergedChannels);
-    connect(_indexerP, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(indexingEnded(int, QProcess::ExitStatus)));
+    connect(_indexerP, SIGNAL(finished(int,QProcess::ExitStatus)), this,
+            SLOT(indexingEnded(int,QProcess::ExitStatus)));
     connect(_indexerP, SIGNAL(readyReadStandardOutput()), this, SLOT(addToLog()));
     const QStringList flags(QStringList() << "--index" << c2bSettingsP->confCommandFlags());
     _indexerP->start(QCoreApplication::applicationFilePath(), flags);
