@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bColors.h"
@@ -24,8 +24,7 @@ c2bColors::c2bColors()
     colorList.insert("cb2Bib unrelevant text", &cb2bib_unrelevant_color);
 }
 
-c2bColors::~c2bColors()
-{}
+c2bColors::~c2bColors() {}
 
 
 void c2bColors::updateColor(const QColor& color, const QString& colorName)
@@ -61,6 +60,7 @@ void c2bColors::loadColors(c2bSettings* settings)
     cb2bib_tag_color = settings->value("c2bColors/cb2bib_tag_color", "#5AF7F4").value<QColor>();
     cb2bib_unrelevant_color = settings->value("c2bColors/cb2bib_unrelevant_color", "#868374").value<QColor>();
     comment_color = settings->value("c2bColors/comment_color", "#A5A5A5").value<QColor>();
-    netqinf_command_content_color = settings->value("c2bColors/netqinf_command_content_color", "#FFFFFF").value<QColor>();
+    netqinf_command_content_color =
+        settings->value("c2bColors/netqinf_command_content_color", "#FFFFFF").value<QColor>();
     netqinf_command_key_color = settings->value("c2bColors/netqinf_command_key_color", "#D5A805").value<QColor>();
 }
