@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bComboBox.h"
@@ -12,11 +12,9 @@
 #include <QMenu>
 
 
-c2bComboBox::c2bComboBox(QWidget* parentw) : QComboBox(parentw)
-{}
+c2bComboBox::c2bComboBox(QWidget* parentw) : QComboBox(parentw) {}
 
-c2bComboBox::~c2bComboBox()
-{}
+c2bComboBox::~c2bComboBox() {}
 
 
 void c2bComboBox::contextMenuEvent(QContextMenuEvent* e)
