@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bConfigureFR.h"
@@ -20,8 +20,7 @@ c2bConfigureFR::c2bConfigureFR(QTreeWidgetItem* item, QWidget* parentw) : QDialo
     ui.lineEditFind->setFocus();
 }
 
-c2bConfigureFR::~c2bConfigureFR()
-{}
+c2bConfigureFR::~c2bConfigureFR() {}
 
 
 void c2bConfigureFR::reject()
