@@ -1,14 +1,14 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bConsole.h"
 
+#include "c2bNetworkQuery.h"
 #include "c2bSettings.h"
 #include "c2bTests.h"
-#include "c2bNetworkQuery.h"
 
 #include <bibExtractor.h>
 #include <bibParser.h>
@@ -20,11 +20,9 @@
 #include <QTimer>
 
 
-c2bConsole::c2bConsole(QObject* parento) : QObject(parento)
-{}
+c2bConsole::c2bConsole(QObject* parento) : QObject(parento) {}
 
-c2bConsole::~c2bConsole()
-{}
+c2bConsole::~c2bConsole() {}
 
 
 void c2bConsole::load()
@@ -51,7 +49,7 @@ void c2bConsole::_process()
 
 int c2bConsole::cl_html_annote()
 {
-    if (QFileInfo(c2bSettingsP->cl_annote_filename).exists())
+    if (QFileInfo::exists(c2bSettingsP->cl_annote_filename))
     {
         const QString tex(c2bUtils::fileToString(c2bSettingsP->cl_annote_filename));
         const QString htmlf(c2bSettingsP->cl_annote_filename + ".html");
@@ -72,7 +70,8 @@ int c2bConsole::cl_doc2bib()
     metadataParser mp(&bp);
     c2bNetworkQuery nq(&bp); // needs c2bUtils::fromHtmlString
     bibExtractor be(&bp, &mp, &nq);
-    const int c(be.extract(c2bSettingsP->cl_extract_input_filenames, c2bSettingsP->cl_extract_output_filename, bibExtractor::Document));
+    const int c(be.extract(c2bSettingsP->cl_extract_input_filenames, c2bSettingsP->cl_extract_output_filename,
+                           bibExtractor::Document));
     return c;
 }
 
@@ -82,7 +81,8 @@ int c2bConsole::cl_txt2bib()
     metadataParser mp(&bp);
     c2bNetworkQuery nq(&bp);
     bibExtractor be(&bp, &mp, &nq);
-    const int c(be.extract(c2bSettingsP->cl_extract_input_filenames, c2bSettingsP->cl_extract_output_filename, bibExtractor::PlainText));
+    const int c(be.extract(c2bSettingsP->cl_extract_input_filenames, c2bSettingsP->cl_extract_output_filename,
+                           bibExtractor::PlainText));
     return c;
 }
 
