@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  *
  *   The LyX pipe procedure in citeToLyXPipe has been adapted from Tellico
@@ -28,12 +28,12 @@ c2bCoreCiter::c2bCoreCiter(QWidget* parentw) : QObject(parentw)
 {
     _parentWP = parentw;
     _settingsP = settings::instance();
-    _settingsP->setDefaultValue("c2bCoreCiter/LyXPipe", QDir::cleanPath(QDir::homePath() + QDir::separator() + ".lyx/lyxpipe.in"));
+    _settingsP->setDefaultValue("c2bCoreCiter/LyXPipe",
+                                QDir::cleanPath(QDir::homePath() + QDir::separator() + ".lyx/lyxpipe.in"));
     _lyxpipe = _settingsP->value("c2bCoreCiter/LyXPipe").toString();
 }
 
-c2bCoreCiter::~c2bCoreCiter()
-{}
+c2bCoreCiter::~c2bCoreCiter() {}
 
 
 void c2bCoreCiter::cite(const QStringList& keys) const
