@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bEditor.h"
@@ -35,7 +35,6 @@
 #include <QTextStream>
 
 
-
 /** \page bibeditor Embedded File Editor
 
 <p>GET_TABLE_OF_CONTENTS</p>
@@ -170,7 +169,8 @@ summary="Summary table of Additional Functionality">
 <tr> <td valign="top">Ctrl+V</td> <td valign="top">Pastes the clipboard text into text edit</td></tr>
 <tr> <td valign="top">Shift+Insert</td> <td valign="top">Pastes the clipboard text into text edit</td></tr>
 <tr> <td valign="top">Ctrl+X</td> <td valign="top">Deletes the selected text and copies it to the clipboard</td></tr>
-<tr> <td valign="top">Shift+Delete</td> <td valign="top">Deletes the selected text and copies it to the clipboard</td></tr>
+<tr> <td valign="top">Shift+Delete</td> <td valign="top">Deletes the selected text and copies it to the
+clipboard</td></tr>
 <tr> <td valign="top">Ctrl+Z</td> <td valign="top">Undoes the last operation</td></tr>
 <tr> <td valign="top">Ctrl+Y</td> <td valign="top">Redoes the last operation</td></tr>
 <tr> <td valign="top">LeftArrow</td> <td valign="top">Moves the cursor one character to the left</td></tr>
@@ -238,7 +238,7 @@ void c2bEditor::initEditor()
     _stackedWidgetP->addWidget(_editorP);
     _textFinderP = new findDialog(this);
     _lineLabelP = new QLabel();
-    _lineLabelP->setText(tr(" Line: 1 Col: 1 "));
+    _lineLabelP->setText(tr(" Line: 1  Col: 1 "));
     _lineLabelP->setAlignment(Qt::AlignVCenter | Qt::AlignRight);
     _lineLabelP->setFrameStyle(QFrame::NoFrame);
     _lineLabelP->setLineWidth(1);
@@ -283,15 +283,16 @@ void c2bEditor::initEditor()
     // Bookmarks
     bookmarkPlugin* bookmarks = new bookmarkPlugin(this);
     menuBar()->insertMenu(ui.menuSettings->menuAction(), bookmarks);
-    connect(bookmarks, SIGNAL(openFile(const QString&)), this, SIGNAL(openFile(const QString&)));
+    connect(bookmarks, SIGNAL(openFile(QString)), this, SIGNAL(openFile(QString)));
     connect(bookmarks, SIGNAL(editBookmarks()), this, SIGNAL(openBookmarks()));
 
     load();
     setEditorMode();
     importActions();
-    QApplication::processEvents(); // Qt 4.7.0 emits contentsChange with position inconsistently defined, make sure it is not captured
-    connect(_editorP->document(), SIGNAL(contentsChange(int, int, int)), this, SLOT(isModified(int, int, int)));
-    connect(c2b::instance(), SIGNAL(statusMessage(const QString&)), this, SLOT(showMessage(const QString&)));
+    QApplication::processEvents(); // Qt 4.7.0 emits contentsChange with position inconsistently defined, make sure it
+    // is not captured
+    connect(_editorP->document(), SIGNAL(contentsChange(int,int,int)), this, SLOT(isModified(int,int,int)));
+    connect(c2b::instance(), SIGNAL(statusMessage(QString)), this, SLOT(showMessage(QString)));
 }
 
 void c2bEditor::setEditorMode()
@@ -342,11 +343,12 @@ void c2bEditor::setEditorMode()
         _editorP->setBibTeXActions();
         connect(_editorP->pasteCurrentBibTeXAction, SIGNAL(triggered()), this, SLOT(pasteCurrentBibTeX()));
         connect(_editorP->journalsToAbbreviatedAction, SIGNAL(triggered()), this, SLOT(journalsToAbbreviated()));
-        connect(_editorP->journalsToAlternateAbbreviatedAction, SIGNAL(triggered()), this, SLOT(journalsToAlternateAbbreviated()));
+        connect(_editorP->journalsToAlternateAbbreviatedAction, SIGNAL(triggered()), this,
+                SLOT(journalsToAlternateAbbreviated()));
         connect(_editorP->journalsToFullAction, SIGNAL(triggered()), this, SLOT(journalsToFull()));
         connect(_editorP->journalsToAlternateFullAction, SIGNAL(triggered()), this, SLOT(journalsToAlternateFull()));
         connect(_editorP->updateMetadataAction, SIGNAL(triggered()), this, SLOT(updateMetadata()));
-        connect(_c2b_mainP, SIGNAL(addedBibToFile(const QString&)), this, SLOT(reload(const QString&)));
+        connect(_c2b_mainP, SIGNAL(addedBibToFile(QString)), this, SLOT(reload(QString)));
         ui.fileExecAction->setText(tr("Save and Postprocess"));
         ui.fileExecAction->setStatusTip(tr("Save and postprocess"));
         _settingsP->setKeysequence("Shortcuts/Editor/", ui.fileExecAction);
@@ -354,7 +356,8 @@ void c2bEditor::setEditorMode()
 
         // Browser
         _browserP = new c2bTextBrowser(this);
-        _browserP->setFont(QFont(QFont().family(), _settingsP->value("c2bEditor/BrowserFontPointSize", QFont().pointSize()).toInt()));
+        _browserP->setFont(
+            QFont(QFont().family(), _settingsP->value("c2bEditor/BrowserFontPointSize", QFont().pointSize()).toInt()));
         _stackedWidgetP->addWidget(_browserP);
         ui.viewEditorModeAction->setVisible(true);
         _settingsP->setKeysequence("Shortcuts/Editor/", ui.viewEditorModeAction);
@@ -369,7 +372,7 @@ void c2bEditor::setEditorMode()
         if (_searcherP)
         {
             edit_mode = (_searcherP->hitsCount() == 0 && _searcherP->errorsCount() > 0);
-            connect(_referencesP, SIGNAL(openFile(const QString&)), this, SIGNAL(openFile(const QString&)));
+            connect(_referencesP, SIGNAL(openFile(QString)), this, SIGNAL(openFile(QString)));
         }
         if (!_edit_reference_at_position.isEmpty())
         {
@@ -440,10 +443,9 @@ bool c2bEditor::closeEditor()
     // here ui.fileSaveAction->isEnabled().
     if (_is_modified_by_user)
     {
-        const int button(QMessageBox::information(this, tr("Information - cb2Bib"),
-                         tr("The document has been modified.\nDo you want to save the changes?"),
-                         QMessageBox::Save | QMessageBox::Discard | QMessageBox::Cancel,
-                         QMessageBox::Save));
+        const int button(QMessageBox::information(
+                             this, tr("Information - cb2Bib"), tr("The document has been modified.\nDo you want to save the changes?"),
+                             QMessageBox::Save | QMessageBox::Discard | QMessageBox::Cancel, QMessageBox::Save));
         if (button == QMessageBox::Save)
         {
             if (!fileSave())
@@ -472,7 +474,8 @@ void c2bEditor::fileOpen()
 {
     if (_editor_mode == BibTeX)
     {
-        const QString filename(c2bFileDialog::getOpenFilename(this, "Select a BibTeX filename", _editor_fn, "BibTeX (*.bib)"));
+        const QString filename(
+            c2bFileDialog::getOpenFilename(this, "Select a BibTeX filename", _editor_fn, "BibTeX (*.bib)"));
         if (!filename.isEmpty())
             emit openFile(filename);
     }
@@ -485,10 +488,10 @@ bool c2bEditor::fileSave()
     QFile file(_editor_fn);
     if (!file.open(QIODevice::WriteOnly | QIODevice::Text))
     {
-        QMessageBox::warning(this, tr("Warning - cb2Bib"),
-                             tr("Unable to open the file %1 for writing.\nError: '%2'.").
-                             arg(_editor_fn).arg(file.errorString()),
-                             QMessageBox::Ok);
+        QMessageBox::warning(
+            this, tr("Warning - cb2Bib"),
+            tr("Unable to open the file %1 for writing.\nError: '%2'.").arg(_editor_fn, file.errorString()),
+            QMessageBox::Ok);
         return false;
     }
     QTextStream stream(&file);
@@ -538,17 +541,19 @@ void c2bEditor::load()
 {
     bool modified_flag(false);
     QFileInfo fi(_editor_fn);
-    if (_editor_fn.isEmpty() || fi.isDir())  // Set an appropriate working name
+    if (_editor_fn.isEmpty() || fi.isDir()) // Set an appropriate working name
     {
         QStringList unamedList;
-        foreach(QWidget * widget, QApplication::topLevelWidgets())
+        foreach (QWidget* widget, QApplication::topLevelWidgets())
         {
             if (widget->inherits("c2bEditor"))
                 unamedList.append(widget->objectName());
         }
         int i(1);
-        while (unamedList.indexOf(QRegExp(QString(".*unnamed_%1.bib").arg(i))) > -1) ++i;
-        _editor_fn = QDir::toNativeSeparators(QDir::cleanPath(_editor_fn + QDir::separator() + QString("unnamed_%1.bib").arg(i)));
+        while (unamedList.indexOf(QRegExp(QString(".*unnamed_%1.bib").arg(i))) > -1)
+            ++i;
+        _editor_fn =
+            QDir::toNativeSeparators(QDir::cleanPath(_editor_fn + QDir::separator() + QString("unnamed_%1.bib").arg(i)));
         if (_searcherP)
         {
             _editorP->setPlainText(_searcherP->logString() + _searcherP->hitsString());
@@ -566,10 +571,10 @@ void c2bEditor::load()
         QFile file(_editor_fn);
         if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
         {
-            QMessageBox::warning(_c2b_mainP,
-                                 tr("Warning - cb2Bib"), tr("Unable to open the file %1 for reading.\nError: '%2'.").
-                                 arg(_editor_fn).arg(file.errorString()),
-                                 QMessageBox::Ok);
+            QMessageBox::warning(
+                _c2b_mainP, tr("Warning - cb2Bib"),
+                tr("Unable to open the file %1 for reading.\nError: '%2'.").arg(_editor_fn, file.errorString()),
+                QMessageBox::Ok);
         }
         else
         {
@@ -701,7 +706,7 @@ void c2bEditor::helpEditor()
 void c2bEditor::helpCb2Bib()
 {
     const QString umanual(QDir::cleanPath(_settingsP->applicationDataDir() + "/doc/cb2bib_user_manual.pdf"));
-    if (QFileInfo(umanual).exists())
+    if (QFileInfo::exists(umanual))
         c2bUtils::displayHelp(umanual);
     else
         c2bUtils::displayHelp("https://www.molspaces.com/cb2bib/doc/contents/");
@@ -729,6 +734,8 @@ void c2bEditor::setViewMode(bool edit_mode)
         acts = _editorP->actions();
         for (int i = 0; i < acts.count(); ++i)
             acts.at(i)->setVisible(true);
+        _overwriteLabelP->setVisible(true);
+        _lineLabelP->setVisible(true);
         _stackedWidgetP->setCurrentWidget(_editorP);
     }
     else
@@ -743,6 +750,8 @@ void c2bEditor::setViewMode(bool edit_mode)
             acts.at(i)->setVisible(true);
         ui.viewZoomInAction->setVisible(true);
         ui.viewZoomOutAction->setVisible(true);
+        _overwriteLabelP->setVisible(false);
+        _lineLabelP->setVisible(false);
         _stackedWidgetP->setCurrentWidget(_browserP);
     }
 }
@@ -754,17 +763,9 @@ void c2bEditor::showMessage(const QString& ms)
 
 void c2bEditor::cursorPositionChanged()
 {
-    int lineNumber(0);
-    QTextBlock current = _editorP->textCursor().block();
-    QTextBlock b;
-    for (b = _editorP->document()->begin(); b.isValid(); b = b.next())
-    {
-        ++lineNumber;
-        if (b == current)
-            break;
-    }
-    int linePosition(_editorP->textCursor().position() - current.position() + 1);
-    _lineLabelP->setText(tr(" Line: %1 Col: %2 ").arg(lineNumber).arg(linePosition));
+    int ln, lp;
+    _editorP->cursorPosition(&ln, &lp);
+    _lineLabelP->setText(tr(" Line: %1  Col: %2 ").arg(ln).arg(lp));
 }
 
 void c2bEditor::overwriteModeChanged()
