@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BEDITOR_H
@@ -32,7 +32,14 @@ class c2bEditor : public QMainWindow
     Q_OBJECT
 
 public:
-    enum Mode {Annote, BibTeX, JAbbrev, NetQInfo, RegExp};
+    enum Mode
+    {
+        Annote,
+        BibTeX,
+        JAbbrev,
+        NetQInfo,
+        RegExp
+    };
 
     c2bEditor(const QString& file, const Mode mode, QWidget* main, QWidget* parentw = 0);
     c2bEditor(const QString& file, bibSearcher* searcher, QWidget* main, QWidget* parentw = 0);
@@ -109,11 +116,10 @@ private:
     void initEditor();
     void setEditorMode();
 
-    QMenu* createPopupMenu()  // to avoid default context menu
+    QMenu* createPopupMenu() // to avoid default context menu
     {
         return 0;
     }
-
 };
 
 #endif
