@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bExport.h"
@@ -11,11 +11,9 @@
 #include <cb2bib_parameters.h>
 
 
-c2bExport::c2bExport(QObject* parento) : QObject(parento)
-{}
+c2bExport::c2bExport(QObject* parento) : QObject(parento) {}
 
-c2bExport::~c2bExport()
-{}
+c2bExport::~c2bExport() {}
 
 
 void c2bExport::exportEntries(const export_data& ed)
@@ -39,21 +37,22 @@ void c2bExport::exportEntries(const export_data& ed)
             continue;
         if (ed.copy_documents)
         {
-            QString sfn(ref.value("file"));
+            const QString sfn(ref.value("file"));
             if (!sfn.isEmpty())
             {
-                QString dfn(c2bUtils::documentAbsoluteName(ed.relative_dir, ed.export_fn, ed.documents_dir, sfn));
+                const QString dfn(c2bUtils::documentAbsoluteName(ed.relative_dir, ed.export_fn, ed.documents_dir, sfn));
                 QFile source(sfn);
                 if (!source.copy(dfn))
-                    export_log += tr("% Unable to copy file %1 to %2. %3.\n").arg(sfn).arg(dfn).arg(source.errorString());
-                if (QFileInfo(dfn).exists())
+                    export_log += tr("% Unable to copy file %1 to %2. %3.\n").arg(sfn, dfn, source.errorString());
+                if (QFileInfo::exists(dfn))
                 {
                     const int pos(filere.indexIn(ref.rawReference, 0));
                     if (pos > -1)
                     {
                         QString line(filere.cap(0));
-                        QString file(filere.cap(1));
-                        line.replace(file, c2bUtils::documentFilename(ed.relative_dir, ed.export_fn, ed.documents_dir, sfn));
+                        const QString file(filere.cap(1));
+                        line.replace(file,
+                                     c2bUtils::documentFilename(ed.relative_dir, ed.export_fn, ed.documents_dir, sfn));
                         ref.rawReference.replace(pos, filere.matchedLength(), line);
                     }
                 }
