@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bFileDialog.h"
@@ -17,22 +17,13 @@ c2bFileDialog::c2bFileDialog(QWidget* parentw, const QString& caption, const QSt
     : QFileDialog(parentw, caption, fpath, ffilter)
 {
     setWindowFlags(windowFlags() & ~Qt::WindowContextHelpButtonHint);
+    setWindowFlags(windowFlags() | Qt::WindowMinMaxButtonsHint);
     setOptions(QFileDialog::DontUseNativeDialog);
     setModal(true);
     settings = c2bSettingsP;
-#ifdef Q_OS_UNIX
-    // Distinguish executable files
-    fip = new fileIconProvider();
-    setIconProvider(fip);
-#endif
 }
 
-c2bFileDialog::~c2bFileDialog()
-{
-#ifdef Q_OS_UNIX
-    delete fip;
-#endif
-}
+c2bFileDialog::~c2bFileDialog() {}
 
 
 QString c2bFileDialog::getFilename(QWidget* parentw, const QString& caption, const QString& path, const QString& filter)
@@ -47,7 +38,8 @@ QString c2bFileDialog::getFilename(QWidget* parentw, const QString& caption, con
     return fn;
 }
 
-QString c2bFileDialog::getOpenFilename(QWidget* parentw, const QString& caption, const QString& path, const QString& filter)
+QString c2bFileDialog::getOpenFilename(QWidget* parentw, const QString& caption, const QString& path,
+                                       const QString& filter)
 {
     c2bFileDialog* dlg = new c2bFileDialog(parentw, _caption(tr("Select a filename"), caption), _path(path), filter);
     dlg->setFileMode(ExistingFile);
@@ -57,7 +49,8 @@ QString c2bFileDialog::getOpenFilename(QWidget* parentw, const QString& caption,
     return fn;
 }
 
-QStringList c2bFileDialog::getOpenFilenames(QWidget* parentw, const QString& caption, const QString& path, const QString& filter)
+QStringList c2bFileDialog::getOpenFilenames(QWidget* parentw, const QString& caption, const QString& path,
+        const QString& filter)
 {
     c2bFileDialog* dlg = new c2bFileDialog(parentw, _caption(tr("Select filenames"), caption), _path(path), filter);
     dlg->setFileMode(ExistingFiles);
@@ -70,7 +63,8 @@ QStringList c2bFileDialog::getOpenFilenames(QWidget* parentw, const QString& cap
     return fns;
 }
 
-QString c2bFileDialog::getSaveFilename(QWidget* parentw, const QString& caption, const QString& path, const QString& filter)
+QString c2bFileDialog::getSaveFilename(QWidget* parentw, const QString& caption, const QString& path,
+                                       const QString& filter)
 {
     c2bFileDialog* dlg = new c2bFileDialog(parentw, _caption(tr("Save As"), caption), _path(path), filter);
     dlg->setFileMode(AnyFile);
@@ -90,7 +84,8 @@ QString c2bFileDialog::getExistingDirectory(QWidget* parentw, const QString& cap
     return fn;
 }
 
-QString c2bFileDialog::getSystemFilename(QWidget* parentw, const QString& caption, const QString& path, const QString& filter)
+QString c2bFileDialog::getSystemFilename(QWidget* parentw, const QString& caption, const QString& path,
+        const QString& filter)
 {
     c2bFileDialog* dlg = new c2bFileDialog(parentw, _caption(tr("Select a filename"), caption), _path(path), filter);
     dlg->setFileMode(AnyFile);
@@ -220,25 +215,3 @@ QString c2bFileDialog::_dirpath(const QString& path)
     else
         return QFileInfo(path + '/').absolutePath();
 }
-
-
-/***************************************************************************
- Class fileIconProvider
- ***************************************************************************/
-
-fileIconProvider::fileIconProvider() : QFileIconProvider()
-{
-    _exec_icon = QIcon(":/icons/icons/application-x-executable.png");
-}
-
-fileIconProvider::~fileIconProvider()
-{}
-
-
-QIcon fileIconProvider::icon(const QFileInfo& info) const
-{
-    if (info.isExecutable() && !info.isDir())
-        return _exec_icon;
-    else
-        return QFileIconProvider::icon(info);
-}
