@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bFileSystemWatcher.h"
@@ -14,7 +14,7 @@
 */
 c2bFileSystemWatcher::c2bFileSystemWatcher(QObject* parento) : QObject(parento)
 {
-    connect(&_filewatcher, SIGNAL(fileChanged(const QString&)), this, SLOT(waitForSaved(const QString&)));
+    connect(&_filewatcher, SIGNAL(fileChanged(QString)), this, SLOT(waitForSaved(QString)));
 }
 
 void c2bFileSystemWatcher::waitForSaved(const QString& path)
