@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bHighlighter.h"
@@ -43,8 +43,7 @@ c2bHighlighter::c2bHighlighter(QTextDocument* doc) : QSyntaxHighlighter(doc)
     rx_metadata_ends = QRegExp("/(Bibliographic|Raw) Metadata\\]");
 }
 
-c2bHighlighter::~c2bHighlighter()
-{}
+c2bHighlighter::~c2bHighlighter() {}
 
 
 void c2bHighlighter::highlightBlock(const QString& text)
@@ -59,7 +58,7 @@ void c2bHighlighter::highlightBlock(const QString& text)
         if (pos > -1)
         {
             setFormat(pos, rx0.matchedLength(), c->cb2bib_digit_color);
-            pos  += rx0.matchedLength();
+            pos += rx0.matchedLength();
         }
     }
     pos = 0;
@@ -69,7 +68,7 @@ void c2bHighlighter::highlightBlock(const QString& text)
         if (pos > -1)
         {
             setFormat(pos, rx1.matchedLength(), c->cb2bib_unrelevant_color);
-            pos  += rx1.matchedLength();
+            pos += rx1.matchedLength();
         }
     }
     pos = 0;
@@ -79,7 +78,7 @@ void c2bHighlighter::highlightBlock(const QString& text)
         if (pos > -1)
         {
             setFormat(pos, rx2.matchedLength(), c->cb2bib_unrelevant_color);
-            pos  += rx2.matchedLength();
+            pos += rx2.matchedLength();
         }
     }
     pos = 0;
@@ -89,7 +88,7 @@ void c2bHighlighter::highlightBlock(const QString& text)
         if (pos > -1)
         {
             setFormat(pos, rx3.matchedLength(), c->cb2bib_relevant_color);
-            pos  += rx3.matchedLength();
+            pos += rx3.matchedLength();
         }
     }
     pos = 0;
@@ -99,7 +98,7 @@ void c2bHighlighter::highlightBlock(const QString& text)
         if (pos > -1)
         {
             setFormat(pos, rx4.matchedLength(), c->cb2bib_highly_relevant_color);
-            pos  += rx4.matchedLength();
+            pos += rx4.matchedLength();
         }
     }
     pos = 0;
@@ -109,7 +108,7 @@ void c2bHighlighter::highlightBlock(const QString& text)
         if (pos > -1)
         {
             setFormat(pos, rx5.matchedLength(), c->cb2bib_tag_color);
-            pos  += rx5.matchedLength();
+            pos += rx5.matchedLength();
         }
     }
     pos = 0;
@@ -119,7 +118,7 @@ void c2bHighlighter::highlightBlock(const QString& text)
         if (pos > -1)
         {
             setFormat(pos, rx6.matchedLength(), c->cb2bib_unrelevant_color);
-            pos  += rx6.matchedLength();
+            pos += rx6.matchedLength();
         }
     }
 
