@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  *
  *   Improvements and modifications:
@@ -91,8 +91,7 @@ c2bIdLineEdit::c2bIdLineEdit(QWidget* parentw) : c2bLineEdit(parentw)
     a_citeid->setVisible(false);
 }
 
-c2bIdLineEdit::~c2bIdLineEdit()
-{}
+c2bIdLineEdit::~c2bIdLineEdit() {}
 
 
 void c2bIdLineEdit::setDocumentIDEdit()
