@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bLineEdit.h"
@@ -11,11 +11,9 @@
 #include <QMenu>
 
 
-c2bLineEdit::c2bLineEdit(QWidget* parentw) : QLineEdit(parentw)
-{}
+c2bLineEdit::c2bLineEdit(QWidget* parentw) : QLineEdit(parentw) {}
 
-c2bLineEdit::~c2bLineEdit()
-{}
+c2bLineEdit::~c2bLineEdit() {}
 
 
 void c2bLineEdit::contextMenuEvent(QContextMenuEvent* e)
