@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bNetworkQuery.h"
@@ -11,14 +11,11 @@
 #include <QMessageBox>
 
 
-c2bNetworkQuery::c2bNetworkQuery(bibParser* bp, QObject* parento) : networkQuery(bp, parento)
-{}
+c2bNetworkQuery::c2bNetworkQuery(bibParser* bp, QObject* parento) : networkQuery(bp, parento) {}
 
-c2bNetworkQuery::c2bNetworkQuery(bibParser* bp, network* net, QObject* parento) : networkQuery(bp, net, parento)
-{}
+c2bNetworkQuery::c2bNetworkQuery(bibParser* bp, network* net, QObject* parento) : networkQuery(bp, net, parento) {}
 
-c2bNetworkQuery::~c2bNetworkQuery()
-{}
+c2bNetworkQuery::~c2bNetworkQuery() {}
 
 
 bool c2bNetworkQuery::checkQueryFile(const QString& fn) const
@@ -37,7 +34,7 @@ bool c2bNetworkQuery::checkQueryFile(const QString& fn) const
         QMessageBox::warning(c2b::mainWidget(), tr("Warning - cb2Bib"),
                              tr("Unable to open the Network Query file %1 for reading.\nError: '%2'.\n\n"
                                 "Note: Network Query files are specified through the cb2Bib Configure dialog.")
-                             .arg(fn).arg(file.errorString()),
+                             .arg(fn, file.errorString()),
                              QMessageBox::Ok);
         return false;
     }
