@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BNETWORKQUERY_H
@@ -24,16 +24,15 @@ public:
 
 
 protected:
-    bool checkQueryFile(const QString& fn) const;
-    inline QString fromHtmlString(const QString& str, const bool addMetadata = false) const
+    bool checkQueryFile(const QString& fn) const override;
+    inline QString fromHtmlString(const QString& str, const bool addMetadata = false) const override
     {
         return c2bUtils::fromHtmlString(str, addMetadata);
     }
-    bool openFile(const QString& fn) const
+    bool openFile(const QString& fn) const override
     {
         return c2bUtils::openFile(fn);
     }
-
 };
 
 #endif
