@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bNetworkQueryInfo.h"
@@ -22,12 +22,11 @@ c2bNetworkQueryInfo::c2bNetworkQueryInfo(QObject* parento) : QObject(parento)
     _bpP = c2b::instance()->bibParser();
     connect(c2bSettingsP, SIGNAL(newSettings()), this, SLOT(loadSettings()));
     _fsw = new c2bFileSystemWatcher(this);
-    connect(_fsw, SIGNAL(fileChanged(const QString&)), this, SLOT(parseBookmarks()));
+    connect(_fsw, SIGNAL(fileChanged(QString)), this, SLOT(parseBookmarks()));
     loadSettings();
 }
 
-c2bNetworkQueryInfo::~c2bNetworkQueryInfo()
-{}
+c2bNetworkQueryInfo::~c2bNetworkQueryInfo() {}
 
 
 void c2bNetworkQueryInfo::loadSettings()
@@ -35,7 +34,7 @@ void c2bNetworkQueryInfo::loadSettings()
     const QString nfn(c2bSettingsP->fileName("cb2Bib/NetworkFile"));
     if (nfn == NetworkFile)
         return;
-    if (QFileInfo(nfn).exists())
+    if (QFileInfo::exists(nfn))
     {
         if (!NetworkFile.isEmpty())
             _fsw->removePath(NetworkFile);
@@ -82,7 +81,7 @@ void c2bNetworkQueryInfo::parseBookmarks()
             {
                 QAction* act = new QAction(bm_parts.at(0), this);
                 act->setData(bm_parts.at(1));
-                act->setStatusTip(QString("%1  [%2]").arg(bm_parts.at(0)).arg(bm_parts.at(1)));
+                act->setStatusTip(QString("%1  [%2]").arg(bm_parts.at(0), bm_parts.at(1)));
                 connect(act, SIGNAL(triggered()), this, SLOT(openBookmark()));
                 BookmarkActionList.append(act);
             }
