@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bPdfImport.h"
@@ -271,11 +271,11 @@ c2bPdfImport::c2bPdfImport(QWidget* parentw) : QDialog(parentw)
     connect(buttonSelectFiles, SIGNAL(clicked()), this, SLOT(selectFiles()));
     connect(buttonProcess, SIGNAL(clicked()), this, SLOT(processOneFile()));
     connect(ui.DoAll, SIGNAL(toggled(bool)), this, SIGNAL(setClipboardDisabled(bool)));
-    connect(c2b::instance(), SIGNAL(statusMessage(const QString&)), this, SLOT(showMessage(const QString&)));
+    connect(c2b::instance(), SIGNAL(statusMessage(QString)), this, SLOT(showMessage(QString)));
 
-    ui.Log->appendPlainText(tr("PDF to Text converter: %1\nArguments: %2\n").
-                            arg(settings->fileName("c2bPdfImport/Pdf2TextBin")).
-                            arg(settings->value("c2bPdfImport/Pdf2TextArg").toString()));
+    ui.Log->appendPlainText(
+        tr("PDF to Text converter: %1\nArguments: %2\n")
+        .arg(settings->fileName("c2bPdfImport/Pdf2TextBin"), settings->value("c2bPdfImport/Pdf2TextArg").toString()));
     showMessage(tr("See cb2Bib install directory for demo c2bPdfImport files."));
 }
 
@@ -382,8 +382,8 @@ void c2bPdfImport::referenceExtacted(bool status)
 
 void c2bPdfImport::dropEvent(QDropEvent* qevent)
 {
-    QList<QUrl> fns(qevent->mimeData()->urls());
-    for (int i = 0; i < fns.count(); i++)
+    const QList<QUrl> fns(qevent->mimeData()->urls());
+    for (int i = 0; i < fns.count(); ++i)
     {
         QString scheme(fns.at(i).scheme());
         QString fn;
@@ -391,7 +391,7 @@ void c2bPdfImport::dropEvent(QDropEvent* qevent)
             fn = fns.at(i).toLocalFile();
         if (!fn.isEmpty())
         {
-            QListWidgetItem* item = new QListWidgetItem(fn, ui.PDFlist);
+            QListWidgetItem* item(new QListWidgetItem(fn, ui.PDFlist));
             if (ui.PDFlist->currentItem() == 0)
                 ui.PDFlist->setCurrentItem(item);
         }
@@ -422,19 +422,17 @@ bool c2bPdfImport::event(QEvent* qevent)
 
 void c2bPdfImport::selectFiles()
 {
-    QStringList fns(c2bFileDialog::getOpenFilenames(this, QString(),
-                    settings->fileName("c2bPdfImport/LastFile"),
-                    tr("Portable Document Format (*.pdf);;All (*)")));
+    const QStringList fns(c2bFileDialog::getOpenFilenames(this, QString(), settings->fileName("c2bPdfImport/LastFile"),
+                          tr("Portable Document Format (*.pdf);;All (*)")));
     if (fns.isEmpty())
         return;
     settings->setFilename("c2bPdfImport/LastFile", fns.last());
-    QStringList::Iterator it = fns.begin();
-    while (it != fns.end())
+
+    for (QStringList::const_iterator i = fns.constBegin(); i != fns.constEnd(); ++i)
     {
-        QListWidgetItem* item = new QListWidgetItem(*it, ui.PDFlist);
+        QListWidgetItem* item(new QListWidgetItem(*i, ui.PDFlist));
         if (ui.PDFlist->currentItem() == 0)
             ui.PDFlist->setCurrentItem(item);
-        ++it;
     }
     buttonProcess->setEnabled(true);
     buttonProcess->setFocus();
