@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bRLWebSearchSettings.h"
@@ -25,8 +25,7 @@ c2bRLWebSearchSettings::c2bRLWebSearchSettings(QWidget* parentw) : QDialog(paren
     ui.addQuotes->setChecked(settings->value("c2bReferenceList/SearchEngineAddQuotes").toBool());
 }
 
-c2bRLWebSearchSettings::~c2bRLWebSearchSettings()
-{}
+c2bRLWebSearchSettings::~c2bRLWebSearchSettings() {}
 
 
 void c2bRLWebSearchSettings::accept()
