@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bReferenceList.h"
@@ -28,7 +28,7 @@ class TreeWidgetItem : public QTreeWidgetItem
     // Reimplement sorting
 public:
     explicit TreeWidgetItem(const QStringList& strings) : QTreeWidgetItem(strings) {}
-    bool operator< (const QTreeWidgetItem& other) const
+    bool operator<(const QTreeWidgetItem& other) const
     {
         const int sortCol(treeWidget()->sortColumn());
         const QString str(c2bUtils::toAscii(text(sortCol), c2bUtils::Collation));
@@ -132,7 +132,7 @@ c2bReferenceList::c2bReferenceList(c2bTextEdit* ed, c2bTextBrowser* br, QWidget*
     refreshListAction->setStatusTip(tr("Refresh list and browser"));
     connect(refreshListAction, SIGNAL(triggered()), this, SLOT(refreshList()));
     ui.listView->addAction(refreshListAction);
-    connect(ui.listView, SIGNAL(itemActivated(QTreeWidgetItem*, int)), this, SLOT(goToReference(QTreeWidgetItem*)));
+    connect(ui.listView, SIGNAL(itemActivated(QTreeWidgetItem*,int)), this, SLOT(goToReference(QTreeWidgetItem*)));
 
     // Actions dependent on selection and availability
     itemSelectionChanged();
@@ -172,12 +172,11 @@ c2bReferenceList::c2bReferenceList(c2bTextEdit* ed, c2bTextBrowser* br, QWidget*
         _browserP->addAction(al.at(i));
     _browserP->setContextMenuPolicy(Qt::ActionsContextMenu);
 
-    connect(_browserP, SIGNAL(anchorClicked(const QUrl&)), this, SLOT(openLink(const QUrl&)));
-    connect(_browserP, SIGNAL(highlighted(const QString&)), parentw->parent(), SLOT(showMessage(const QString&)));
+    connect(_browserP, SIGNAL(anchorClicked(QUrl)), this, SLOT(openLink(QUrl)));
+    connect(_browserP, SIGNAL(highlighted(QString)), parentw->parent(), SLOT(showMessage(QString)));
 }
 
-c2bReferenceList::~c2bReferenceList()
-{}
+c2bReferenceList::~c2bReferenceList() {}
 
 
 void c2bReferenceList::loadList(const QString& txt, bibSearcher* searcher)
@@ -291,7 +290,8 @@ void c2bReferenceList::loadList(const QString& txt, bibSearcher* searcher)
         bib_item_html.replace("GET_REFERENCE_VOLUME", volume);
         bib_item_html.replace("GET_REFERENCE_YEAR", year);
         if (searcher)
-            bib_item_html.replace("GET_REFERENCE_ABSTRACT", searcher->highlight(abstract) + searcher->hitValue(ref.rawReference));
+            bib_item_html.replace("GET_REFERENCE_ABSTRACT",
+                                  searcher->highlight(abstract) + searcher->hitValue(ref.rawReference));
         else
             bib_item_html.replace("GET_REFERENCE_ABSTRACT", c2bUtils::toHtmlString(abstract));
         references += bib_item_html;
@@ -614,13 +614,14 @@ void c2bReferenceList::setupFilterBar()
         const QString& t = types.at(i);
         QAction* act = filterMode->addAction(t);
         act->setCheckable(true);
-        if (_filter_mode == t) act->setChecked(true);
+        if (_filter_mode == t)
+            act->setChecked(true);
     }
     QMenu* filterModeM = new QMenu(this);
     filterModeM->addActions(filterMode->actions());
     ui.filterB->setMenu(filterModeM);
     connect(filterMode, SIGNAL(triggered(QAction*)), this, SLOT(setFilterMode(QAction*)));
-    connect(ui.comboFilter, SIGNAL(editTextChanged(const QString&)), this, SLOT(blockFilterSignals()));
+    connect(ui.comboFilter, SIGNAL(editTextChanged(QString)), this, SLOT(blockFilterSignals()));
 }
 
 void c2bReferenceList::setFilterMode(QAction* mode)
