@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bSaveREHighlighter.h"
@@ -20,8 +20,7 @@ c2bSaveREHighlighter::c2bSaveREHighlighter(QRegExp& rx, QTextDocument* doc) : QS
     connect(settings, SIGNAL(newSettings()), this, SLOT(rehighlight()));
 }
 
-c2bSaveREHighlighter::~c2bSaveREHighlighter()
-{}
+c2bSaveREHighlighter::~c2bSaveREHighlighter() {}
 
 
 void c2bSaveREHighlighter::highlightBlock(const QString& text)
