@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bSearchInFiles.h"
@@ -45,12 +45,11 @@ c2bSearchInFiles::c2bSearchInFiles(const QString& file, QWidget* parentw) : QDia
     connect(ui.allBibFiles, SIGNAL(clicked()), this, SLOT(setBibTeXFile()));
     connect(ui.buttonBox, SIGNAL(helpRequested()), this, SLOT(help()));
     connect(ui.pattern, SIGNAL(patternAvailable(bool)), this, SLOT(updateForm()));
-    connect(ui.patternList, SIGNAL(itemActivated(QTreeWidgetItem*, int)), this, SLOT(on_editPatternB_clicked()));
-    connect(ui.patternList, SIGNAL(itemClicked(QTreeWidgetItem*, int)), this, SLOT(updateForm()));
+    connect(ui.patternList, SIGNAL(itemActivated(QTreeWidgetItem*,int)), this, SLOT(on_editPatternB_clicked()));
+    connect(ui.patternList, SIGNAL(itemClicked(QTreeWidgetItem*,int)), this, SLOT(updateForm()));
 }
 
-c2bSearchInFiles::~c2bSearchInFiles()
-{}
+c2bSearchInFiles::~c2bSearchInFiles() {}
 
 
 void c2bSearchInFiles::updateForm()
@@ -58,7 +57,8 @@ void c2bSearchInFiles::updateForm()
     ui.addPatternB->setEnabled(ui.pattern->isAvailable());
     ui.Boolean->setEnabled((ui.patternList->topLevelItemCount() > 1) ||
                            (ui.pattern->isAvailable() && ui.patternList->topLevelItemCount() > 0));
-    _searchB->setEnabled(!_bibtex_dir.isEmpty() && (ui.pattern->isAvailable() || ui.patternList->topLevelItemCount() > 0));
+    _searchB->setEnabled(!_bibtex_dir.isEmpty() &&
+                         (ui.pattern->isAvailable() || ui.patternList->topLevelItemCount() > 0));
     if (ui.patternList->currentItem())
     {
         ui.deletePatternB->setEnabled(true);
@@ -97,8 +97,8 @@ void c2bSearchInFiles::on_editPatternB_clicked()
     ui_editor.setupUi(&editor);
     QTreeWidgetItem* item = ui.patternList->currentItem();
     ui_editor.pattern->setPattern(item);
-    connect(ui_editor.pattern, SIGNAL(patternAvailable(bool)),
-            ui_editor.buttonBox->button(QDialogButtonBox::Ok), SLOT(setEnabled(bool)));
+    connect(ui_editor.pattern, SIGNAL(patternAvailable(bool)), ui_editor.buttonBox->button(QDialogButtonBox::Ok),
+            SLOT(setEnabled(bool)));
     if (editor.exec() == QDialog::Accepted)
     {
         const QStringList pattern(ui_editor.pattern->patterns());
@@ -147,7 +147,9 @@ void c2bSearchInFiles::searchB_clicked()
     {
         if (searcher.hitsCount() > 0)
             search_status = tr("Found %1 hits from %2 references (%3s)")
-                            .arg(searcher.hitsCount()).arg(searcher.referencesCount()).arg(t.elapsed() / 1000.0);
+                            .arg(searcher.hitsCount())
+                            .arg(searcher.referencesCount())
+                            .arg(t.elapsed() / 1000.0);
         else
             ui.searchLog->setText(_search_log);
         QApplication::processEvents();
