@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bSearchInFilesPattern.h"
@@ -26,8 +26,8 @@ c2bSearchInFilesPattern::c2bSearchInFilesPattern(QWidget* parentw) : QWidget(par
     ui.inputPattern->setFocus();
 
     connect(ui.clearB, SIGNAL(clicked()), this, SLOT(patternChanged()));
-    connect(ui.inputPattern, SIGNAL(textEdited(const QString&)), this, SLOT(patternChanged()));
-    connect(ui.patternScope, SIGNAL(currentIndexChanged(const QString&)), this, SLOT(showYearScope(const QString&)));
+    connect(ui.inputPattern, SIGNAL(textEdited(QString)), this, SLOT(patternChanged()));
+    connect(ui.patternScope, SIGNAL(currentIndexChanged(QString)), this, SLOT(showYearScope(QString)));
 }
 
 c2bSearchInFilesPattern::~c2bSearchInFilesPattern()
