@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bSettings.h"
@@ -19,11 +19,9 @@
     Global settings for cb2Bib
 */
 c2bSettings::c2bSettings(const QString& organization, const QString& application, QObject* parento)
-    : settings(organization, application, parento), _progress_bar(0)
-{}
+    : settings(organization, application, parento), _progress_bar(0) {}
 
-c2bSettings::c2bSettings(const QString& fn, QObject* parento) : settings(fn, parento), _progress_bar(0)
-{}
+c2bSettings::c2bSettings(const QString& fn, QObject* parento) : settings(fn, parento), _progress_bar(0) {}
 
 c2bSettings::~c2bSettings()
 {
@@ -154,7 +152,7 @@ void c2bSettings::setKeysequences(const QHash<QString, QKeySequence>& keysequenc
 
     // Set keysequences to created objects
     const QString sctag("Shortcuts/");
-    foreach(QWidget * w, QApplication::topLevelWidgets())
+    foreach (QWidget* w, QApplication::topLevelWidgets())
     {
         const QList<QAction*> alist(w->findChildren<QAction*>());
         for (int i = 0; i < alist.count(); ++i)
@@ -173,7 +171,7 @@ void c2bSettings::setKeysequences(const QHash<QString, QKeySequence>& keysequenc
     }
 }
 
-void  c2bSettings::setKeysequence(const QString& path, QAction* action)
+void c2bSettings::setKeysequence(const QString& path, QAction* action)
 {
     if (!action)
         return;
@@ -187,7 +185,7 @@ void  c2bSettings::setKeysequence(const QString& path, QAction* action)
         c2bUtils::warn(tr("Action '%1' is not registered in default keysequence list").arg(fullname));
 }
 
-void  c2bSettings::setKeysequence(const QString& fullname, QShortcut* shortcut)
+void c2bSettings::setKeysequence(const QString& fullname, QShortcut* shortcut)
 {
     if (!shortcut)
         return;
@@ -239,8 +237,10 @@ void c2bSettings::processReferenceFile()
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
     {
         cl_cb2bib_import_mode = true;
-        QMessageBox::warning(0, tr("Warning - cb2Bib"), tr("Unable to open the reference file %1 for reading.\nError: '%2'.").
-                             arg(cl_import_filename).arg(file.errorString()), QMessageBox::Ok);
+        QMessageBox::warning(0, tr("Warning - cb2Bib"),
+                             tr("Unable to open the reference file %1 for reading.\nError: '%2'.")
+                             .arg(cl_import_filename, file.errorString()),
+                             QMessageBox::Ok);
         QTimer::singleShot(500, qApp, SLOT(quit()));
     }
     else
@@ -252,7 +252,6 @@ void c2bSettings::processReferenceFile()
                 _progress_bar = new QProgressBar;
             _progress_bar->setRange(0, 100);
             _progress_bar->setWindowTitle(QObject::tr("Importing..."));
-            _progress_bar->setWindowIcon(QIcon(QString::fromUtf8(":/icons/icons/cb2bib.png")));
             _progress_bar->show();
             _progress_bar->setValue(50);
         }
