@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BSETTINGS_H
@@ -68,14 +68,13 @@ private:
     void processReferenceFile();
     void setDefaults();
 #ifdef Q_OS_WIN
-    QString decodeFilename(const QString& fn) const;
+    QString decodeFilename(const QString& fn) const override;
 #endif
 
 
 private slots:
     void guiExits();
     void processReferenceFileEvent();
-
 };
 
 #define c2bSettingsP (static_cast<c2bSettings*>(settings::instance()))
