@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bShortcutPushButton.h"
@@ -32,19 +32,10 @@ void c2bShortcutPushButton::keyPressEvent(QKeyEvent* qevent)
     const int k(qevent->key());
     // This function is based on GPL configdialog.cpp
     // Copyright (C) 2003-2007 by Pascal Brachet, http://www.xm1math.net/texmaker/
-    if ((qevent->modifiers() != 0 &&
-         k != Qt::Key_Enter &&
-         k != Qt::Key_Alt &&
-         k != Qt::Key_Shift &&
-         k != Qt::Key_Control &&
-         k != Qt::Key_AltGr &&
-         k != Qt::Key_Meta &&
-         k != 0 &&
-         k != Qt::Key_Super_L &&
-         k != Qt::Key_Super_R)
-        ||
-        (k >= Qt::Key_F1 &&
-         k <= Qt::Key_F35))
+    if ((qevent->modifiers() != 0 && k != Qt::Key_Enter && k != Qt::Key_Alt && k != Qt::Key_Shift &&
+         k != Qt::Key_Control && k != Qt::Key_AltGr && k != Qt::Key_Meta && k != 0 && k != Qt::Key_Super_L &&
+         k != Qt::Key_Super_R) ||
+        (k >= Qt::Key_F1 && k <= Qt::Key_F35))
     {
         _set_keysequence(QKeySequence(qevent->modifiers() | k));
         return;
