@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #define C2B_CHECK_CAPITALIZATION 0
@@ -21,7 +21,7 @@
 #include <QTextStream>
 
 
-c2bTests::c2bTests() : cout(*(new QTextStream(stdout)))
+c2bTests::c2bTests() : cout(*(new QTextStream(stdout))), _failed_test_count(0), _test_count(0)
 {
     cout.setCodec("UTF-8");
 
@@ -192,7 +192,8 @@ void c2bTests::heuristic_author()
             const QString guess(bp.currentReference().value("author"));
             const bool passed(guess == author);
             ++_test_count;
-            if (!passed) ++_failed_test_count;
+            if (!passed)
+                ++_failed_test_count;
             cout << QString("[%1]\t'%2'\n").arg(boolToStr(passed)).arg(author);
             if (!passed)
                 cout << QString("\t'%1'\n").arg(guess);
@@ -212,7 +213,8 @@ void c2bTests::heuristic_author()
         if (dc.length() != 2)
             continue;
         if (dc.at(0).isLetter() && dc.at(1).isLetter())
-            cout << '[' << c << ']' << " u: " << u << " decompose: " << decomposition(c) << " category: " << c.category() << endl;
+            cout << '[' << c << ']' << " u: " << u << " decompose: " << decomposition(c)
+                 << " category: " << c.category() << endl;
     }
     return;
 #endif
@@ -244,9 +246,9 @@ void c2bTests::heuristic_author()
     }
     QList<QChar> cl = charfreq.keys();
     for (int i = 0; i < cl.count(); ++i)
-        cout << '[' << cl.at(i) << ']' << " u: " << cl.at(i).unicode() << " letter: " << cl.at(i).isLetter() <<
-             " decompose: " << decomposition(cl.at(i)) << " category: " << cl.at(i).category() <<
-             " f: " << charfreq.value(cl.at(i)) << endl;
+        cout << '[' << cl.at(i) << ']' << " u: " << cl.at(i).unicode() << " letter: " << cl.at(i).isLetter()
+             << " decompose: " << decomposition(cl.at(i)) << " category: " << cl.at(i).category()
+             << " f: " << charfreq.value(cl.at(i)) << endl;
     cout << "\nTotal characters: " << char_count << endl;
     return;
 #endif
@@ -262,7 +264,7 @@ void c2bTests::heuristic_author()
                                .split(QRegExp("[\\n\\r]"), QString::SkipEmptyParts));
     QHash<QString, QString> doc_cache;
     const QString doc_cache_fn(_bibliographic_dir + "/c2b_test.cache");
-    if (QFileInfo(doc_cache_fn).exists())
+    if (QFileInfo::exists(doc_cache_fn))
     {
         cout << "Reading from cache" << endl;
         QFile file(doc_cache_fn);
@@ -331,25 +333,27 @@ void c2bTests::heuristic_author()
                 QString guess_ascii(c2bUtils::toAscii(guess, c2bUtils::Cleanup));
                 passed = guess_ascii == author_ascii;
                 if (passed)
-                    cout << QString("[%1*] '%2'\n").arg(boolToStr(passed)).arg(author);
+                    cout << QString("[%1*] '%2'\n").arg(boolToStr(passed), author);
                 else
-                    cout << QString("[%1]  '%2'\n").arg(boolToStr(passed)).arg(author);
+                    cout << QString("[%1]  '%2'\n").arg(boolToStr(passed), author);
                 if (!passed)
                 {
                     qDebug() << author;
                     qDebug() << guess;
                     qDebug() << reference.value("file");
                     qDebug() << "DOCUMENT: \n" << doc << endl << endl;
-//                    for (int i = 0; i < doc.count(); ++i)
-//                        cout << '[' << doc.at(i) << ']' << " u: " << doc.at(i).unicode() << " letter: " <<
-//                             doc.at(i).isLetter() << endl;
+                    //                    for (int i = 0; i < doc.count(); ++i)
+                    //                        cout << '[' << doc.at(i) << ']' << " u: " << doc.at(i).unicode() << "
+                    //                        letter: " <<
+                    //                             doc.at(i).isLetter() << endl;
                 }
                 cout << QString("          '%1'\n").arg(guess);
             }
             else
-                cout << QString("[%1]  '%2'\n").arg(boolToStr(passed)).arg(author);
+                cout << QString("[%1]  '%2'\n").arg(boolToStr(passed), author);
             ++n_pdf;
-            if (!passed) ++n_failed_pdf;
+            if (!passed)
+                ++n_failed_pdf;
         }
     }
     cout << "PDF Tests: " << n_pdf << endl;
@@ -368,6 +372,7 @@ void c2bTests::check_abbreviations_txt()
     cout << endl;
 
     const QString dbfile(settings::instance()->fileName("cb2Bib/JournalFile"));
+    cout << dbfile << endl;
     journalDB jdb(dbfile);
 
     QStringList abbr1, abbr2, full1, full2, code;
@@ -445,72 +450,92 @@ void c2bTests::check_abbreviations_txt()
     cout << endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieve(code.at(i)) != abbr1.at(i))
-            cout << "failed code to abbr1   " << code.at(i) << " | " << abbr1.at(i) << " | " << jdb.retrieve(code.at(i)) << endl;
+            cout << "failed code to abbr1   " << code.at(i) << " | " << abbr1.at(i) << " | " << jdb.retrieve(code.at(i))
+                 << endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieveAlternate(code.at(i)) != abbr2.at(i))
-            cout << "failed code to abbr2   " << code.at(i) << " | " << abbr2.at(i) << " | " << jdb.retrieveAlternate(code.at(i)) << endl;
+            cout << "failed code to abbr2   " << code.at(i) << " | " << abbr2.at(i) << " | "
+                 << jdb.retrieveAlternate(code.at(i)) << endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieveFull(code.at(i)) != full1.at(i))
-            cout << "failed code to full1   " << code.at(i) << " | " << full1.at(i) << " | " << jdb.retrieveFull(code.at(i)) << endl;
+            cout << "failed code to full1   " << code.at(i) << " | " << full1.at(i) << " | "
+                 << jdb.retrieveFull(code.at(i)) << endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieveAlternateFull(code.at(i)) != full2.at(i))
-            cout << "failed code to full2   " << code.at(i) << " | " << full2.at(i) << " | " << jdb.retrieveAlternateFull(code.at(i)) << endl;
+            cout << "failed code to full2   " << code.at(i) << " | " << full2.at(i) << " | "
+                 << jdb.retrieveAlternateFull(code.at(i)) << endl;
 
     cout << endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieve(abbr1.at(i)) != abbr1.at(i))
-            cout << "failed abbr1 to abbr1  " << abbr1.at(i) << " | " << abbr1.at(i) << " | " << jdb.retrieve(abbr1.at(i)) << endl;
+            cout << "failed abbr1 to abbr1  " << abbr1.at(i) << " | " << abbr1.at(i) << " | "
+                 << jdb.retrieve(abbr1.at(i)) << endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieveAlternate(abbr1.at(i)) != abbr2.at(i))
-            cout << "failed abbr1 to abbr2  " << abbr1.at(i) << " | " << abbr2.at(i) << " | " << jdb.retrieveAlternate(abbr1.at(i)) << endl;
+            cout << "failed abbr1 to abbr2  " << abbr1.at(i) << " | " << abbr2.at(i) << " | "
+                 << jdb.retrieveAlternate(abbr1.at(i)) << endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieveFull(abbr1.at(i)) != full1.at(i))
-            cout << "failed abbr1 to full1  " << abbr1.at(i) << " | " << full1.at(i) << " | " << jdb.retrieveFull(abbr1.at(i)) << endl;
+            cout << "failed abbr1 to full1  " << abbr1.at(i) << " | " << full1.at(i) << " | "
+                 << jdb.retrieveFull(abbr1.at(i)) << endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieveAlternateFull(abbr1.at(i)) != full2.at(i))
-            cout << "failed abbr1 to full2  " << abbr1.at(i) << " | " << full2.at(i) << " | " << jdb.retrieveAlternateFull(abbr1.at(i)) << endl;
+            cout << "failed abbr1 to full2  " << abbr1.at(i) << " | " << full2.at(i) << " | "
+                 << jdb.retrieveAlternateFull(abbr1.at(i)) << endl;
 
     cout << endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieve(abbr2.at(i)) != abbr1.at(i))
-            cout << "failed abbr2 to abbr1  " << abbr2.at(i) << " | " << abbr1.at(i) << " | " << jdb.retrieve(abbr2.at(i)) << endl;
+            cout << "failed abbr2 to abbr1  " << abbr2.at(i) << " | " << abbr1.at(i) << " | "
+                 << jdb.retrieve(abbr2.at(i)) << endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieveAlternate(abbr2.at(i)) != abbr2.at(i))
-            cout << "failed abbr2 to abbr2  " << abbr2.at(i) << " | " << abbr2.at(i) << " | " << jdb.retrieveAlternate(abbr2.at(i)) << endl;
+            cout << "failed abbr2 to abbr2  " << abbr2.at(i) << " | " << abbr2.at(i) << " | "
+                 << jdb.retrieveAlternate(abbr2.at(i)) << endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieveFull(abbr2.at(i)) != full1.at(i))
-            cout << "failed abbr2 to full1  " << abbr2.at(i) << " | " << full1.at(i) << " | " << jdb.retrieveFull(abbr2.at(i)) << endl;
+            cout << "failed abbr2 to full1  " << abbr2.at(i) << " | " << full1.at(i) << " | "
+                 << jdb.retrieveFull(abbr2.at(i)) << endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieveAlternateFull(abbr2.at(i)) != full2.at(i))
-            cout << "failed abbr2 to full2  " << abbr2.at(i) << " | " << full2.at(i) << " | " << jdb.retrieveAlternateFull(abbr2.at(i)) << endl;
+            cout << "failed abbr2 to full2  " << abbr2.at(i) << " | " << full2.at(i) << " | "
+                 << jdb.retrieveAlternateFull(abbr2.at(i)) << endl;
 
     cout << endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieve(full1.at(i)) != abbr1.at(i))
-            cout << "failed full1 to abbr1  " << full1.at(i) << " | " << abbr1.at(i) << " | " << jdb.retrieve(full1.at(i)) << endl;
+            cout << "failed full1 to abbr1  " << full1.at(i) << " | " << abbr1.at(i) << " | "
+                 << jdb.retrieve(full1.at(i)) << endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieveAlternate(full1.at(i)) != abbr2.at(i))
-            cout << "failed full1 to abbr2  " << full1.at(i) << " | " << abbr2.at(i) << " | " << jdb.retrieveAlternate(full1.at(i)) << endl;
+            cout << "failed full1 to abbr2  " << full1.at(i) << " | " << abbr2.at(i) << " | "
+                 << jdb.retrieveAlternate(full1.at(i)) << endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieveFull(full1.at(i)) != full1.at(i))
-            cout << "failed full1 to full1  " << full1.at(i) << " | " << full1.at(i) << " | " << jdb.retrieveFull(full1.at(i)) << endl;
+            cout << "failed full1 to full1  " << full1.at(i) << " | " << full1.at(i) << " | "
+                 << jdb.retrieveFull(full1.at(i)) << endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieveAlternateFull(full1.at(i)) != full2.at(i))
-            cout << "failed full1 to full2  " << full1.at(i) << " | " << full2.at(i) << " | " << jdb.retrieveAlternateFull(full1.at(i)) << endl;
+            cout << "failed full1 to full2  " << full1.at(i) << " | " << full2.at(i) << " | "
+                 << jdb.retrieveAlternateFull(full1.at(i)) << endl;
 
     cout << endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieve(full2.at(i)) != abbr1.at(i))
-            cout << "failed full2 to abbr1  " << full2.at(i) << " | " << abbr1.at(i) << " | " << jdb.retrieve(full2.at(i)) << endl;
+            cout << "failed full2 to abbr1  " << full2.at(i) << " | " << abbr1.at(i) << " | "
+                 << jdb.retrieve(full2.at(i)) << endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieveAlternate(full2.at(i)) != abbr2.at(i))
-            cout << "failed full2 to abbr2  " << full2.at(i) << " | " << abbr2.at(i) << " | " << jdb.retrieveAlternate(full2.at(i)) << endl;
+            cout << "failed full2 to abbr2  " << full2.at(i) << " | " << abbr2.at(i) << " | "
+                 << jdb.retrieveAlternate(full2.at(i)) << endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieveFull(full2.at(i)) != full1.at(i))
-            cout << "failed full2 to full1  " << full2.at(i) << " | " << full1.at(i) << " | " << jdb.retrieveFull(full2.at(i)) << endl;
+            cout << "failed full2 to full1  " << full2.at(i) << " | " << full1.at(i) << " | "
+                 << jdb.retrieveFull(full2.at(i)) << endl;
     for (int i = 0; i < njournals; ++i)
         if (jdb.retrieveAlternateFull(full2.at(i)) != full2.at(i))
-            cout << "failed full2 to full2  " << full2.at(i) << " | " << full2.at(i) << " | " << jdb.retrieveAlternateFull(full2.at(i)) << endl;
+            cout << "failed full2 to full2  " << full2.at(i) << " | " << full2.at(i) << " | "
+                 << jdb.retrieveAlternateFull(full2.at(i)) << endl;
 #endif
 }
 
@@ -600,7 +625,8 @@ void c2bTests::heuristic_journal()
             else
                 cout << QString("[%1]  '%2'\n").arg(boolToStr(passed)).arg(fjournal);
             ++n_pdf;
-            if (!passed) ++n_failed_pdf;
+            if (!passed)
+                ++n_failed_pdf;
         }
     }
     cout << "PDF Tests: " << n_pdf << endl;
@@ -610,7 +636,8 @@ void c2bTests::heuristic_journal()
     _failed_test_count += n_failed_pdf;
 
     qSort(doclengths);
-    cout << "doclengths min max median: " << doclengths.first() << ' ' << doclengths.last() << ' ' << doclengths.at(doclengths.count() / 2) << endl;
+    cout << "doclengths min max median: " << doclengths.first() << ' ' << doclengths.last() << ' '
+         << doclengths.at(doclengths.count() / 2) << endl;
 #endif
 }
 
@@ -649,8 +676,8 @@ void c2bTests::author_parser()
     input = "Aaaaaaa, BB";
     check_test(author == bp.parse("author", input), input, author);
     author = "J. R. Aaaaaaa";
-//    input = "Aaaaaaa, JR"; // Gives wrong processing of the initials JR
-//    check_test(author == bp.parse("author", input), input, author);
+    //    input = "Aaaaaaa, JR"; // Gives wrong processing of the initials JR
+    //    check_test(author == bp.parse("author", input), input, author);
 
     author = "J. Pi";
     input = "Joan Pi";
@@ -744,7 +771,7 @@ void c2bTests::author_parser()
     input = "Carr Lourtau, AM";
     check_test(author == bp.parse("author", input), input, author);
     input = "Carr Lourtau AM"; // Gives 'L. A. Carr' (rare AU formatting)
-//    check_test(author == bp.parse("author", author::fromMedline(input)), input, author);
+    //    check_test(author == bp.parse("author", author::fromMedline(input)), input, author);
 
     author = "B. de Rivas";
     input = "de Rivas, Beatriz";
@@ -1090,17 +1117,21 @@ void c2bTests::heuristic(bibParser& bp, const bibReference& reference, const QSt
     bp.guessFields(text);
     const bool passed(bp.toBibTeX() == bp.toBibTeX(reference));
     ++_test_count;
-    if (!passed) ++_failed_test_count;
-    cout << QString("[%1]\t'%2'\n").arg(boolToStr(passed)).arg(text);
-    if (!passed) qDebug() << "Guessed:\n" << bp.toBibTeX();
+    if (!passed)
+        ++_failed_test_count;
+    cout << QString("[%1]\t'%2'\n").arg(boolToStr(passed), text);
+    if (!passed)
+        qDebug() << "Guessed:\n" << bp.toBibTeX();
 }
 
 void c2bTests::check_test(const bool passed, const QString& input, const QString& output)
 {
     ++_test_count;
-    if (!passed) ++_failed_test_count;
-    cout << QString("[%1]\t'%2'\n").arg(boolToStr(passed)).arg(input);
-    if (!passed) qDebug() << output;
+    if (!passed)
+        ++_failed_test_count;
+    cout << QString("[%1]\t'%2'\n").arg(boolToStr(passed), input);
+    if (!passed)
+        qDebug() << output;
 }
 
 void c2bTests::write(const bibParser& bp, const bibReference& reference)
@@ -1153,8 +1184,8 @@ void c2bTests::heuristic_check_patterns()
                 adictionary.insert(as.at(i), 1 + adictionary.value(as.at(i), 0));
         }
     }
-    QStringList word_prefix_lexicon(c2bUtils::fileToString(":/txt/txt/word_prefix_lexicon.txt").split(c2bUtils::nonLetter,
-                                    QString::SkipEmptyParts));
+    QStringList word_prefix_lexicon(
+        c2bUtils::fileToString(":/txt/txt/word_prefix_lexicon.txt").split(c2bUtils::nonLetter, QString::SkipEmptyParts));
     for (int i = 0; i < word_prefix_lexicon.count(); ++i)
         word_prefix_lexicon[i].replace('_', "\\b");
 
