@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BTESTS_H
@@ -29,7 +29,6 @@ public:
 
 private:
     QString _bibliographic_dir;
-    QString decomposition(const QChar& c);
     QTextStream& cout;
     int _failed_test_count;
     int _test_count;
@@ -46,14 +45,15 @@ private:
     void write(const bibParser& bp, const bibReference& reference);
     void write_information();
 
-    inline const char* boolToStr(bool b)
+    static QString decomposition(const QChar& c);
+
+    inline static const char* boolToStr(bool b)
     {
         if (b)
             return "passed";
         else
             return "failed";
     }
-
 };
 
 #endif
