@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bTextBrowser.h"
@@ -18,12 +18,10 @@ c2bTextBrowser::c2bTextBrowser(QWidget* parentw) : QTextBrowser(parentw)
     setFrameShadow(QTextBrowser::Raised);
 }
 
-c2bTextBrowser::~c2bTextBrowser()
-{}
+c2bTextBrowser::~c2bTextBrowser() {}
 
 
-void c2bTextBrowser::setSource(const QUrl& /* dummy_name */)
-{}
+void c2bTextBrowser::setSource(const QUrl& /* dummy_name */) {}
 
 void c2bTextBrowser::contextMenuEvent(QContextMenuEvent* qevent)
 {
