@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bTextEdit.h"
@@ -26,7 +26,7 @@ c2bTextEdit::c2bTextEdit(QWidget* parentw) : QPlainTextEdit(parentw)
     _line_number_area_color = palette().color(QPalette::Active, QPalette::Base).darker(110);
     _line_number_color_p = &_settingsP->colors.comment_color;
     connect(this, SIGNAL(blockCountChanged(int)), this, SLOT(updateLineNumberAreaWidth()));
-    connect(this, SIGNAL(updateRequest(const QRect&, int)), this, SLOT(updateLineNumberArea(const QRect&, int)));
+    connect(this, SIGNAL(updateRequest(QRect,int)), this, SLOT(updateLineNumberArea(QRect,int)));
     updateLineNumberAreaWidth();
 
     c2bUtils::addSeparator(this);
@@ -143,21 +143,19 @@ void c2bTextEdit::updatePlainText(const QString& text)
     const int cursorColumn(textCursor().columnNumber());
     setPlainText(text);
 
-    QTextBlock p = document()->begin();
-    int i(0);
-    while (p.isValid())
-    {
-        if (cursorBlock == i)
-            break;
-        i++;
-        p = p.next();
-    }
-    QTextCursor tcursor = textCursor();
-    tcursor.setPosition(p.position() + cursorColumn, QTextCursor::MoveAnchor);
+    const int lposition(document()->findBlockByNumber(cursorBlock).position());
+    QTextCursor tcursor(textCursor());
+    tcursor.setPosition(lposition + cursorColumn, QTextCursor::MoveAnchor);
     setTextCursor(tcursor);
     verticalScrollBar()->setValue(scrollPosition);
 }
 
+void c2bTextEdit::cursorPosition(int* line_number, int* line_position) const
+{
+    *line_number = textCursor().blockNumber() + 1;
+    *line_position = textCursor().positionInBlock() + 1;
+}
+
 void c2bTextEdit::convert2LaTeX()
 {
     QString txt(textCursor().selectedText());
