@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bUpdateMetadata.h"
@@ -51,7 +51,7 @@ void c2bUpdateMetadata::update()
     if (exiftool_bin.isEmpty())
     {
         ui.Log->appendPlainText(tr("[cb2bib] ExifTool location has not been specified."));
-        return ;
+        return;
     }
     const QFileInfo exiftool_bin_fi(exiftool_bin);
     if (exiftool_bin_fi.isAbsolute())
@@ -85,7 +85,7 @@ void c2bUpdateMetadata::update()
         QFileInfo fi(file);
         if (!fi.exists())
         {
-            ui.Log->appendPlainText(tr("[cb2bib] %1: Warning: File %2 does not exist.").arg(ref.citeidName).arg(file));
+            ui.Log->appendPlainText(tr("[cb2bib] %1: Warning: File %2 does not exist.").arg(ref.citeidName, file));
             continue;
         }
         ++doc_counter;
@@ -96,7 +96,7 @@ void c2bUpdateMetadata::update()
         if (!fi.isWritable())
         {
             ++error_counter;
-            ui.Log->appendPlainText(tr("[cb2bib] %1: Error: File %2 is not writable.").arg(ref.citeidName).arg(file));
+            ui.Log->appendPlainText(tr("[cb2bib] %1: Error: File %2 is not writable.").arg(ref.citeidName, file));
             continue;
         }
         QString error_str;
@@ -106,17 +106,18 @@ void c2bUpdateMetadata::update()
                 if (!needsUpdating(ref, mref))
                 {
                     ++updated_counter;
-                    ui.Log->appendPlainText(tr("[cb2bib] %1: File %2 successfully updated.").arg(ref.citeidName).arg(file));
+                    ui.Log->appendPlainText(tr("[cb2bib] %1: File %2 successfully updated.").arg(ref.citeidName, file));
                     continue;
                 }
             ++error_counter;
-            ui.Log->appendPlainText(tr("[cb2bib] %1: Warning: File %2 was not properly updated.").arg(ref.citeidName).arg(file));
+            ui.Log->appendPlainText(
+                tr("[cb2bib] %1: Warning: File %2 was not properly updated.").arg(ref.citeidName, file));
             writeDifferences(ref, mref);
         }
         else
         {
             ++error_counter;
-            ui.Log->appendPlainText(tr("[cb2bib] %1: Error: File %2 could not be updated.").arg(ref.citeidName).arg(file));
+            ui.Log->appendPlainText(tr("[cb2bib] %1: Error: File %2 could not be updated.").arg(ref.citeidName, file));
             ui.Log->appendPlainText(tr("[exiftool] '%1'.").arg(error_str));
         }
         QCoreApplication::processEvents();
@@ -161,9 +162,9 @@ bool c2bUpdateMetadata::needsUpdating(const bibReference& ref, const bibReferenc
 
 void c2bUpdateMetadata::writeDifferences(const bibReference& ref, const bibReference& mref)
 {
-    QString diff("  [Key] '%1'\n  [In Reference] '%2'\n  [In Document]  '%3'");
+    const QString diff("  [Key] '%1'\n  [In Reference] '%2'\n  [In Document]  '%3'");
     if (ref.typeName != mref.typeName)
-        ui.Log->appendPlainText(diff.arg("type").arg(ref.typeName).arg(mref.typeName));
+        ui.Log->appendPlainText(diff.arg("type", ref.typeName, mref.typeName));
     const QStringList& bibliographicFields = _bpP->bibliographicFields();
     for (int i = 0; i < bibliographicFields.count(); ++i)
     {
@@ -177,7 +178,7 @@ void c2bUpdateMetadata::writeDifferences(const bibReference& ref, const bibRefer
         if (key == "title" || key == "booktitle")
             c2bUtils::cleanTitle(value);
         if (value != mref.value(key))
-            ui.Log->appendPlainText(diff.arg(key).arg(value).arg(mref.value(key)));
+            ui.Log->appendPlainText(diff.arg(key, value, mref.value(key)));
     }
 }
 
