@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "c2bUtils.h"
@@ -22,15 +22,15 @@ bool openFile(const QString& fn, QWidget* w)
     {
         if (w)
             QMessageBox::warning(w, QObject::tr("Warning - cb2Bib"),
-                                 QObject::tr("Unable to open file.\nError: URL '%1' is not valid.").
-                                 arg(url.toString()), QMessageBox::Ok);
+                                 QObject::tr("Unable to open file.\nError: URL '%1' is not valid.").arg(url.toString()),
+                                 QMessageBox::Ok);
         return false;
     }
     if (!QDesktopServices::openUrl(url))
     {
         if (w)
-            QMessageBox::warning(w, QObject::tr("Warning - cb2Bib"), QObject::tr("Unable to open file '%1'.").
-                                 arg(fn), QMessageBox::Ok);
+            QMessageBox::warning(w, QObject::tr("Warning - cb2Bib"), QObject::tr("Unable to open file '%1'.").arg(fn),
+                                 QMessageBox::Ok);
         return false;
     }
     return true;
