@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef C2BUTILS_H
@@ -32,7 +32,7 @@ inline QUrl stringToUrl(const QString& fn)
 {
     // Avoid cross-platform pitfalls regarding string to url conversions
     // Avoid possible issues regarding QUrl and local files not starting with 'file://'
-    if (QFileInfo(fn).exists())
+    if (QFileInfo::exists(fn))
         return QUrl::fromLocalFile(fn);
     else
         return QUrl(fn, QUrl::TolerantMode);
