@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #ifndef CB2BIB_H
@@ -57,7 +57,7 @@ private:
     bool _connected;
     bool _is_check_repeated_done;
     bool _modified;
-    bool _taggedViewMode;
+    bool _tagged_view_mode;
     bool isReferenceRepeated();
     c2bBibMenu* _bib_menu;
     c2bBibParser* _bpP;
@@ -134,7 +134,6 @@ private slots:
     void updateCheckRepeatedAction();
     void updateOpenDocuments(QObject* obj);
     void updateOpenDocuments(const QString& old_name, const QString& new_name);
-
 };
 
 #endif
