@@ -1,7 +1,7 @@
 /***************************************************************************
  *   clipboardPoll, modified by Pere Constans for cb2Bib, 2005
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *
  *
  *   Author and Copyright (C) 2003 by Lubos Lunak <l.lunak@kde.org>
@@ -29,8 +29,8 @@
 #include "clipboardPoll.h"
 
 
-#include <QX11Info>
 #include <QClipboard>
+#include <QX11Info>
 #include <X11/Xatom.h>
 
 
@@ -61,23 +61,17 @@ clipboardPoll::clipboardPoll(QWidget* parentw) : QWidget(parentw)
     timer = new QTimer(this);
     connect(timer, SIGNAL(timeout()), this, SLOT(timeout()));
 
-    const char* names[ 6 ] =
-    {
-        "_QT_SELECTION_SENTINEL",
-        "_QT_CLIPBOARD_SENTINEL",
-        "CLIPBOARD",
-        "TIMESTAMP",
-        "KLIPPER_SELECTION_TIMESTAMP",
-        "KLIPPER_CLIPBOARD_TIMESTAMP"
-    };
-    Atom atoms[ 6 ];
-    XInternAtoms(QX11Info::display(), const_cast< char** >(names), 6, False, atoms);
-    selection.sentinel_atom = atoms[ 0 ];
-    clipboard.sentinel_atom = atoms[ 1 ];
-    xa_clipboard = atoms[ 2 ];
-    xa_timestamp = atoms[ 3 ];
-    selection.timestamp_atom = atoms[ 4 ];
-    clipboard.timestamp_atom = atoms[ 5 ];
+    const char* names[6] = { "_QT_SELECTION_SENTINEL",      "_QT_CLIPBOARD_SENTINEL",     "CLIPBOARD", "TIMESTAMP",
+                             "KLIPPER_SELECTION_TIMESTAMP", "KLIPPER_CLIPBOARD_TIMESTAMP"
+                           };
+    Atom atoms[6];
+    XInternAtoms(QX11Info::display(), const_cast<char**>(names), 6, False, atoms);
+    selection.sentinel_atom = atoms[0];
+    clipboard.sentinel_atom = atoms[1];
+    xa_clipboard = atoms[2];
+    xa_timestamp = atoms[3];
+    selection.timestamp_atom = atoms[4];
+    clipboard.timestamp_atom = atoms[5];
     selection.atom = XA_PRIMARY;
     clipboard.atom = xa_clipboard;
     selection.last_change = clipboard.last_change = QX11Info::appTime(); // don't trigger right after startup
@@ -121,16 +115,16 @@ void clipboardPoll::updateQtOwnership(SelectionData& sData)
     unsigned long nitems;
     unsigned long after;
     unsigned char* prop = NULL;
-    if (XGetWindowProperty(QX11Info::display(), QX11Info::appRootWindow(0), sData.sentinel_atom, 0, 2, False,
-                           XA_WINDOW, &type, &format, &nitems, &after, &prop) != Success
-        || type != XA_WINDOW || format != 32 || nitems != 2 || prop == NULL)
+    if (XGetWindowProperty(QX11Info::display(), QX11Info::appRootWindow(0), sData.sentinel_atom, 0, 2, False, XA_WINDOW,
+                           &type, &format, &nitems, &after, &prop) != Success ||
+        type != XA_WINDOW || format != 32 || nitems != 2 || prop == NULL)
     {
         sData.owner_is_qt = false;
         if (prop != NULL)
             XFree(prop);
         return;
     }
-    Window owner = reinterpret_cast< long* >(prop)[ 0 ];   // [0] is new owner, [1] is previous
+    Window owner = reinterpret_cast<long*>(prop)[0]; // [0] is new owner, [1] is previous
     XFree(prop);
     Window current_owner = XGetSelectionOwner(QX11Info::display(), sData.atom);
     sData.owner_is_qt = (owner == current_owner);
@@ -160,7 +154,7 @@ bool clipboardPoll::checkTimestamp(SelectionData& sData)
         sData.waiting_for_timestamp = false;
         return false;
     }
-    if (current_owner != sData.last_owner)  // owner has changed
+    if (current_owner != sData.last_owner) // owner has changed
     {
         sData.last_owner = current_owner;
         sData.waiting_for_timestamp = false;
@@ -177,8 +171,8 @@ bool clipboardPoll::checkTimestamp(SelectionData& sData)
         return false;
     }
     XDeleteProperty(QX11Info::display(), winId(), sData.timestamp_atom);
-    XConvertSelection(QX11Info::display(), sData.atom, xa_timestamp,
-                      sData.timestamp_atom, winId(), QX11Info::appTime());
+    XConvertSelection(QX11Info::display(), sData.atom, xa_timestamp, sData.timestamp_atom, winId(),
+                      QX11Info::appTime());
     sData.waiting_for_timestamp = true;
     sData.waiting_x_time = QX11Info::appTime();
     return false;
@@ -186,9 +180,8 @@ bool clipboardPoll::checkTimestamp(SelectionData& sData)
 
 bool clipboardPoll::changedTimestamp(SelectionData& sData, const XEvent& ev)
 {
-    if (ev.xselection.requestor != winId()
-        || ev.xselection.selection != sData.atom
-        || ev.xselection.time != sData.waiting_x_time)
+    if (ev.xselection.requestor != winId() || ev.xselection.selection != sData.atom ||
+        ev.xselection.time != sData.waiting_x_time)
     {
         return false;
     }
@@ -202,16 +195,15 @@ bool clipboardPoll::changedTimestamp(SelectionData& sData, const XEvent& ev)
     unsigned long nitems;
     unsigned long after;
     unsigned char* prop = NULL;
-    if (XGetWindowProperty(QX11Info::display(), winId(), ev.xselection.property, 0, 1, False,
-                           AnyPropertyType, &type, &format,
-                           &nitems, &after, &prop) != Success
-        || format != 32 || nitems != 1 || prop == NULL)
+    if (XGetWindowProperty(QX11Info::display(), winId(), ev.xselection.property, 0, 1, False, AnyPropertyType, &type,
+                           &format, &nitems, &after, &prop) != Success ||
+        format != 32 || nitems != 1 || prop == NULL)
     {
         if (prop != NULL)
             XFree(prop);
         return true;
     }
-    Time timestamp = reinterpret_cast< long* >(prop)[ 0 ];
+    Time timestamp = reinterpret_cast<long*>(prop)[0];
     XFree(prop);
     if (timestamp != sData.last_change || timestamp == CurrentTime)
     {
