@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  *   findDialog was originally adapted from Qt Designer
  *   Copyright (C) 2001 Trolltech AS.  All rights reserved.
@@ -48,8 +48,7 @@ findDialog::findDialog(QWidget* parentw) : QDialog(parentw)
     connect(findPreviousAction, SIGNAL(triggered()), this, SLOT(findPrevious()));
 }
 
-findDialog::~findDialog()
-{}
+findDialog::~findDialog() {}
 
 
 void findDialog::init()
@@ -95,8 +94,8 @@ void findDialog::accept()
         return;
     if (_editor)
     {
-        if (findText(ui.comboFind->currentText(), ui.radioForward->isChecked(),
-                     ui.checkCase->isChecked(), ui.checkWords->isChecked()))
+        if (findText(ui.comboFind->currentText(), ui.radioForward->isChecked(), ui.checkCase->isChecked(),
+                     ui.checkWords->isChecked()))
             QDialog::accept();
         else
             ui.notFound->show();
