@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  *   findDialog is adapted from Qt Designer
  *   Copyright (C) 2001 Trolltech AS.  All rights reserved.
@@ -52,11 +52,11 @@ private:
     QPointer<QWidget> _editor;
     QString m_find_pattern;
     Ui::findDialog ui;
-    bool findText(const QString& pattern, bool do_forward = true, bool do_case_sensitive = false, bool do_whole_words = false);
+    bool findText(const QString& pattern, bool do_forward = true, bool do_case_sensitive = false,
+                  bool do_whole_words = false);
     bool m_find_case;
     bool m_find_words;
     void init();
-
 };
 
 #endif
