@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "qtsingleapplication/src/qtsingleapplication.h"
@@ -57,12 +57,13 @@ int main(int argc, char* argv[])
         app.setQuitOnLastWindowClosed(false);
         app.setOrganizationName(C2B_ORGANIZATION);
         app.setApplicationName(C2B_APPLICATION);
+        app.setWindowIcon(QIcon(":/icons/icons/cb2bib.ico"));
         c2b_settings = c2bSettings::initSettings();
         if (c2b_settings->loaded())
         {
             cb2Bib c2B;
             c2B.show();
-            QObject::connect(&app, SIGNAL(messageReceived(const QString&)), &c2B, SLOT(show()));
+            QObject::connect(&app, SIGNAL(messageReceived(QString)), &c2B, SLOT(show()));
             code = app.exec();
         }
         delete c2b_settings;
@@ -72,6 +73,7 @@ int main(int argc, char* argv[])
         QApplication app(argc, argv);
         app.setOrganizationName(C2B_ORGANIZATION);
         app.setApplicationName(C2B_APPLICATION);
+        app.setWindowIcon(QIcon(":/icons/icons/cb2bib.ico"));
         c2b_settings = c2bSettings::initSettings();
         if (c2b_settings->loaded())
         {
