@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
  *
  *   See the LICENSE file that comes with this distribution.
@@ -19,7 +19,7 @@
 
 c2bWebBrowser::c2bWebBrowser(QWidget* parentw) : QWebEngineView(parentw)
 {
-    // Set default background to application
+// Set default background to application
 #if QT_VERSION >= 0x050600
     page()->setBackgroundColor(qApp->palette().color(QPalette::Window));
 #endif
@@ -63,13 +63,12 @@ c2bWebBrowser::c2bWebBrowser(QWidget* parentw) : QWebEngineView(parentw)
 
     QShortcut* copy_shortcut = new QShortcut(QKeySequence(QKeySequence::Copy), this);
     connect(copy_shortcut, SIGNAL(activated()), this, SLOT(copy()));
-    connect(page(), SIGNAL(linkHovered(const QString&)), this, SLOT(linkHovered(const QString&)));
+    connect(page(), SIGNAL(linkHovered(QString)), this, SLOT(linkHovered(QString)));
 
-    connect(this, SIGNAL(titleChanged(const QString&)), this, SLOT(setWindowTitle(const QString&)));
+    connect(this, SIGNAL(titleChanged(QString)), this, SLOT(setWindowTitle(QString)));
 }
 
-c2bWebBrowser::~c2bWebBrowser()
-{}
+c2bWebBrowser::~c2bWebBrowser() {}
 
 
 void c2bWebBrowser::setHomePage(const QString& hp_url)
@@ -126,7 +125,8 @@ QWebEngineView* c2bWebBrowser::createWindow(QWebEnginePage::WebWindowType /* typ
     return 0;
 }
 
-template<typename Arg, typename R, typename C> struct InvokeWrapper
+template <typename Arg, typename R, typename C>
+struct InvokeWrapper
 {
     R* receiver;
     void (C::*memberFun)(Arg);
@@ -136,9 +136,10 @@ template<typename Arg, typename R, typename C> struct InvokeWrapper
     }
 };
 
-template<typename Arg, typename R, typename C> InvokeWrapper<Arg, R, C> invoke(R* receiver, void (C::*memberFun)(Arg))
+template <typename Arg, typename R, typename C>
+InvokeWrapper<Arg, R, C> invoke(R* receiver, void (C::*memberFun)(Arg))
 {
-    InvokeWrapper<Arg, R, C> wrapper = {receiver, memberFun};
+    InvokeWrapper<Arg, R, C> wrapper = { receiver, memberFun };
     return wrapper;
 }
 
@@ -158,7 +159,8 @@ void c2bWebBrowser::linkHovered(const QString& link)
     else if (_hovered_link.contains(".tex.html#"))
     {
         const QString q(QFileInfo(link).fileName().split('#').last());
-        page()->runJavaScript("document.querySelector('a[id*=\"" + q + "\"]').text", invoke(this, &c2bWebBrowser::showTitle));
+        page()->runJavaScript("document.querySelector('a[id*=\"" + q + "\"]').text",
+                              invoke(this, &c2bWebBrowser::showTitle));
     }
     else
     {
