@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
  *
  *   See the LICENSE file that comes with this distribution.
@@ -65,15 +65,13 @@ c2bWebBrowser::c2bWebBrowser(QWidget* parentw) : QWebView(parentw)
 
     QShortcut* copy_shortcut = new QShortcut(QKeySequence(QKeySequence::Copy), this);
     connect(copy_shortcut, SIGNAL(activated()), this, SLOT(copy()));
-    connect(page(), SIGNAL(linkHovered(const QString&, const QString&, const QString&)),
-            this, SLOT(linkHovered(const QString&)));
+    connect(page(), SIGNAL(linkHovered(QString,QString,QString)), this, SLOT(linkHovered(QString)));
+    connect(page(), SIGNAL(statusBarMessage(QString)), this, SIGNAL(statusMessage(QString)));
 
-    connect(this, SIGNAL(titleChanged(const QString&)), this, SLOT(setWindowTitle(const QString&)));
-    connect(page(), SIGNAL(statusBarMessage(const QString&)), this, SIGNAL(statusMessage(const QString&)));
+    connect(this, SIGNAL(titleChanged(QString)), this, SLOT(_set_window_title(QString)));
 }
 
-c2bWebBrowser::~c2bWebBrowser()
-{}
+c2bWebBrowser::~c2bWebBrowser() {}
 
 
 void c2bWebBrowser::setHomePage(const QString& hp_url)
@@ -130,6 +128,23 @@ QWebView* c2bWebBrowser::createWindow(QWebPage::WebWindowType /* type */)
     return 0;
 }
 
+void c2bWebBrowser::mousePressEvent(QMouseEvent* qevent)
+{
+    if (qevent->button() == Qt::BackButton)
+    {
+        back();
+        qevent->accept();
+    }
+    QWebView::mousePressEvent(qevent);
+}
+
+void c2bWebBrowser::_set_window_title(const QString& pagetitle)
+{
+    // This fixes anchor clicked cases where titleChanged signal emits an empty document title
+    if (!pagetitle.isEmpty())
+        setWindowTitle(pagetitle);
+}
+
 void c2bWebBrowser::linkHovered(const QString& link)
 {
     _hovered_link = link;
@@ -138,7 +153,8 @@ void c2bWebBrowser::linkHovered(const QString& link)
     else if (_hovered_link.contains(".tex.html#"))
     {
         const QString q(QFileInfo(link).fileName().split('#').last());
-        const QVariant v(page()->mainFrame()->evaluateJavaScript("document.querySelector('a[id*=\"" + q + "\"]').text"));
+        const QVariant v(
+            page()->mainFrame()->evaluateJavaScript("document.querySelector('a[id*=\"" + q + "\"]').text"));
         if (!v.isValid())
             emit statusMessage(QString());
         else
