@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
  *
  *   See the LICENSE file that comes with this distribution.
@@ -41,6 +41,7 @@ public slots:
 
 protected:
     virtual QWebView* createWindow(QWebPage::WebWindowType type);
+    virtual void mousePressEvent(QMouseEvent* qevent);
 
 
 protected slots:
@@ -56,8 +57,8 @@ private:
 
 
 private slots:
+    void _set_window_title(const QString& pagetitle);
     void linkHovered(const QString& link);
-
 };
 
 #endif
