@@ -1,7 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2004-2018 by Pere Constans
+ *   Copyright (C) 2004-2019 by Pere Constans
  *   constans@molspaces.com
- *   cb2Bib version 1.9.9. Licensed under the GNU GPL version 3.
+ *   cb2Bib version 2.0.0. Licensed under the GNU GPL version 3.
  *   See the LICENSE file that comes with this distribution.
  ***************************************************************************/
 #include "WinConsole.h"
@@ -15,11 +15,11 @@
 
 WinConsole::WinConsole(QObject* parento) : QObject(parento)
 {
+    // Remove _setmode on older Windows consoles
     _setmode(_fileno(stdout), _O_U16TEXT);
 }
 
-WinConsole::~WinConsole()
-{}
+WinConsole::~WinConsole() {}
 
 
 int WinConsole::execute(const QString& program, const QStringList& arguments)
@@ -28,7 +28,7 @@ int WinConsole::execute(const QString& program, const QStringList& arguments)
     _process.setProcessChannelMode(QProcess::MergedChannels);
 
     connect(&_process, SIGNAL(readyReadStandardOutput()), this, SLOT(output()));
-    connect(&_process, SIGNAL(finished(int, QProcess::ExitStatus)), &eventloop, SLOT(quit()));
+    connect(&_process, SIGNAL(finished(int,QProcess::ExitStatus)), &eventloop, SLOT(quit()));
 
     _process.start(program, arguments);
     if (_process.waitForStarted())
